clear
clc

%% A closed-form solution for the ground response when tunnelling through thinly alternating weak and competent rocks
%% lying perpendicularly to the tunnel axis
% F. Mezger and G. Anagnostou
% ETH Zurich, Switzerland
% April 2018. 

%% Rock parameters (i.e., input parameters)

sigma0=10;                                              %Initial stress [MPa]
sigmaa=0;                                               %Support pressure [MPa]
a= 4;                                                   %Tunnel radius [m]

Eh=10000;                                               %Young's Modulus hard layers [MPa]
nuh=0.3;                                                %Poisson's Ratio hard layers [-]
phih=25;  %(=phihR)                                     %(Residual) angle of internal friction hard layers []
phihH=phih;                                             %(Peak) angle of internal friction hard layers []
psih=5;                                                 %Dilatancy angle hard layers []
ch=5;     %(=chR)                                       %(Residual) cohesion hard layers [MPa]
chH=ch;                                                 %(Peak) cohesion hard layers [MPa]

Ew=1000;                                                %Young's Modulus weak layers [MPa]
nuw=0.3;                                                %Poisson's Ratio weak layers [-]
phiw=25;                                                %Angle of internal friction weak layers []
psiw=5;                                                 %Dilatancy angle weak layers []
cw=0.5;                                                 %Cohesion weak layers [MPa]

xh=1/3;                                                 %thickness fraction of the hard layers in the REV [-]


%% Calculation of all constants
phiw=phiw/180*pi;                                       %Angle of internal friction weak layers [rad]
psiw=psiw./180*pi;                                      %Dilatancy angle weak layers [rad]
sigmadw=2*cw*cos(phiw)/(1-sin(phiw));                   %Uniaxial compressive strength weak layers [MPa]
mw=(1+sin(phiw))/(1-sin(phiw));                         %Inclination of the failure surface weak layers [-]
kw=(1+sin(psiw))/(1-sin(psiw));                         %Constant of the flow rule weak layers [-]
lamdaw=Ew*nuw/((1+nuw)*(1-2*nuw));                      %Lame-constant of the weak layers [MPa]
muw=Ew/(2*(1+nuw));                                     %Lame-constant of the weak layers [MPa]

phih=phih/180*pi;                                       %Angle of internal friction hard layers [rad]
phihH=phihH/180*pi;                                     %Angle of internal friction hard layers [rad]
psih=psih./180*pi;                                      %Dilatancy angle hard layers [rad]
sigmadh=2*ch*cos(phih)/(1-sin(phih));                   %Uniaxial compressive strength hard layers [MPa]
sigmadhH=2*chH*cos(phihH)/(1-sin(phihH));               %Uniaxial compressive strength hard layers [MPa]
mh=(1+sin(phih))/(1-sin(phih));                         %Inclination of the failure surface hard layers [-]
mhH=(1+sin(phihH))/(1-sin(phihH));                      %Inclination of the failure surface hard layers [-]
kh=(1+sin(psih))/(1-sin(psih));                         %constant of the flow rule hard layers [-]
lamdah=Eh*nuh/((1+nuh)*(1-2*nuh));                      %Lame-constant of the hard layers [MPa]
muh=Eh/(2*(1+nuh));                                     %Lame-constant of the hard layers [MPa]

xw=1-xh;                                                %thickness fraction of the weak layers in the REV [-]

%% Calculation of the constants for the incremental stress-strain relations (cf. Appendix A and D)

% Constants for the purely elastic case:
muStar=xh*muh+xw*muw; % Eq. (A-6)
lambdaStar=(xw^2*lamdaw*(lamdah + 2*muh) + xh^2*lamdah*(lamdaw + 2*muw) + 2*xh*xw*(lamdah*(lamdaw + muh) + ...
    lamdaw*muw))/(xw*(lamdah + 2*muh) + xh*(lamdaw + 2*muw)); % Eq. (A-7)
B1i=(xw*lamdaw*(lamdah + 2*muh) + xh*lamdah*(lamdaw + 2*muw))/(xw*(lamdah + 2*muh) + xh*(lamdaw + 2*muw)); % Factor of Eq. (A-8)
B2i=(xw*lamdaw*(lamdah + 2*muh) + xh*lamdah*(lamdaw + 2*muw))/(xw*(lamdah + 2*muh) + xh*(lamdaw + 2*muw)); % Factor of Eq. (A-8)

% Constants for the case ii (weak layers behave elasto-plastically, hard
% layers linear elastically)
A1ii=(2*(2*xw^2*(lamdah + 2*muh)*muw*(lamdaw + muw) + xh^2*(lamdah + 2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw ...
    + 2*(muw + kw*mw*muw)) + xh*xw*(lamdah*(4*(1 + kw*mw)*muh*muw + lamdaw*(2*(-1 + kw)*(-1 + mw)*muh + ...
    (2 + kw + mw)*muw)) + 2*(2*muw*((1 + kw*mw)*muh^2 + muw^2) + lamdaw*((-1 + kw)*(-1 + mw)*muh^2 + ...
    3*muw^2)))))/ (xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) +  ...
    2*xh*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))); % Eq. (A-8)
A2ii=-((2*(2*kw*xw^2*(lamdah + 2*muh)*muw*(lamdaw + muw) + xh^2*lamdah*muw*((2 - kw - mw + 2*kw*mw)*lamdaw + ...
    2*(muw + kw*mw*muw)) + xh*xw*(2*kw*muw^2*(3*lamdaw + 2*muw) + lamdah* (2*(1 + kw*mw)*muh*muw + ...
    lamdaw*((-1 + kw)*(-1 + mw)*muh + (1 + kw*(2 + mw))*muw)))))/ (xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + ...
    2*(muw + kw*mw*muw)) + 2*xh*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)))); % Eq. (A-9)
A3ii=(2*(2*mw*xw^2*(lamdah + 2*muh)*muw*(lamdaw + muw) + xh^2*lamdah*muw*((2 - kw - mw + 2*kw*mw)*lamdaw + ...
    2*(muw + kw*mw*muw)) + xh*xw*(2*mw*muw^2*(3*lamdaw + 2*muw) + lamdah* (2*(1 + kw*mw)*muh*muw + ...
    lamdaw*((-1 + kw)*(-1 + mw)*muh + (1 + (2 + kw)*mw)*muw)))))/ (xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + ...
    2*(muw + kw*mw*muw)) + 2*xh*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))); % Eq. (A-10)
A4ii=-((2*(2*kw*mw*xw^2*(lamdah + 2*muh)*muw*(lamdaw + muw) + xh^2*(lamdah + 2*muh)*muw*((2 - mw + kw*(-1 + ...
    2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + xh*xw*(lamdah*(4*(1 + kw*mw)*muh*muw + lamdaw*(2*(-1 + kw)*(-1 + ...
    mw)*muh + (kw + mw + 2*kw*mw)*muw)) + 2*(2*muw*((1 + kw*mw)*muh^2 + kw*mw*muw^2) + lamdaw*((-1 + kw)*(-1 + ...
    mw)*muh^2 + 3*kw*mw*muw^2)))))/ (xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + ...
    2*xh*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)))); % Eq. (A-11)

Zii=xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + 2*xh*muw*((2 - mw + kw*(-1 + ...
    2*mw))*lamdaw + 2*(muw + kw*mw*muw)); % Eq. (A-122)
K1ii=2/Zii*(xh*(lamdah + 2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xw*(2*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + lamdah*(4*(1 + kw*mw)*muh*muw + ...
    lamdaw*(2*(-1 + kw)*(-1 + mw)*muh + (1 + mw)*muw)))); % Eq. (A-14)
K2ii=2/Zii*lamdah*(xh*muw*((2 - kw - mw + 2*kw*mw)*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xw*(2*(1 + kw*mw)*muh*muw + lamdaw*((-1 + kw)*(-1 + mw)*muh + kw*(1 + mw)*muw))); % Eq. (A-15)
K3ii=2/Zii*lamdah*(xh*muw*((2 - kw - mw + 2*kw*mw)*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xw*(2*(1 + kw*mw)*muh*muw + lamdaw*((-1 + kw)*(-1 + mw)*muh + (1 + mw)*muw))); % Eq. (A-22)
K4ii=2/Zii*(xh*(lamdah + 2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xw*(2*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + lamdah*(4*(1 + kw*mw)*muh*muw + ...
    lamdaw*(2*(-1 + kw)*(-1 + mw)*muh + kw*(1 + mw)*muw)))); % Eq. (A-17)
K5ii=2/Zii*muw*(2*xw*(lamdah + 2*muh)*(lamdaw + muw) + xh*((1 + kw)*lamdah*lamdaw + ...
    2*muw*(3*lamdaw + 2*muw))); % Eq. (A-18)
K6ii=2/Zii*muw*(2*kw*xw*(lamdah + 2*muh)*(lamdaw + muw) + xh*((1 + kw)*lamdah*lamdaw + ...
    2*kw*muw*(3*lamdaw + 2*muw))); % Eq. (A-19)
K7ii=2/Zii*mw*muw*(2*xw*(lamdah + 2*muh)*(lamdaw + muw) + xh*((1 + kw)*lamdah*lamdaw + ...
    2*muw*(3*lamdaw + 2*muw))); % Eq. (A-20)
K8ii=2/Zii*mw*muw*(2*kw*xw*(lamdah + 2*muh)*(lamdaw + muw) + xh*((1 + kw)*lamdah*lamdaw + ...
    2*kw*muw*(3*lamdaw + 2*muw))); % Eq. (A-21)

B1ii=(2*muw*((1 + mw)*xw*lamdaw*(lamdah + 2*muh) + xh*lamdah*((2 - kw - mw + 2*kw*mw)*lamdaw + ...
    2*(muw + kw*mw*muw))))/ (xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) ...
    + 2*xh*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))); % Eq. (A-12)
B2ii=(2*muw*(kw*(1 + mw)*xw*lamdaw*(lamdah + 2*muh) + xh*lamdah*((2 - kw - mw + 2*kw*mw)*lamdaw + ...
    2*(muw + kw*mw*muw))))/ (xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + ...
    2*xh*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))); % Eq. (A-13)

% Constants for the case iii (hard layers behave elasto-plastically, weak
% layers linear-elastically)
A1iii=(2*(2*xh^2*muh*(lamdah + muh)*(lamdaw + 2*muw) + xw^2*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + ...
    2*(muh + kh*mh*muh))*(lamdaw + 2*muw) + xh*xw*(4*muh*(muh^2 + (1 + kh*mh)*muw*(lamdaw + muw)) + ...
    lamdah*(lamdaw*((2 + kh + mh)*muh + 2*(-1 + kh)*(-1 + mh)*muw) + 2*(3*muh^2 + (-1 + kh)*(-1 + ...
    mh)*muw^2)))))/ (2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh)) + xh*((-1 + ...
    kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*(lamdaw + 2*muw)); % Eq. (A-23)
A2iii=-((2*(xw*lamdaw*(xw*muh*((2 - mh)*lamdah + 2*muh) + xh*(2*muh*muw + lamdah*(muh + muw - ...
    mh*muw))) + kh*(xw^2*lamdaw*muh*((-1 + 2*mh)*lamdah + 2*mh*muh) + 2*xh^2*muh*(lamdah + muh)*(lamdaw + ...
    2*muw) + xh*xw*(4*muh^3 + 2*mh*lamdaw*muh*muw + lamdah*(6*muh^2 + lamdaw*((2 + mh)*muh + (-1 + ...
    mh)*muw))))))/ (2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh)) + xh*((-1 + ...
    kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*(lamdaw + 2*muw))); % Eq. (A-24)
A3iii=(2*(xw*lamdaw*(xw*muh*((2 - kh)*lamdah + 2*muh) + xh*(2*muh*muw + lamdah*(muh + muw - kh*muw))) + ...
    mh*(xw^2*lamdaw*muh*((-1 + 2*kh)*lamdah + 2*kh*muh) + 2*xh^2*muh*(lamdah + muh)*(lamdaw + 2*muw) + ...
    xh*xw*(4*muh^3 + 2*kh*lamdaw*muh*muw + lamdah*(6*muh^2 + lamdaw*((2 + kh)*muh + (-1 + ...
    kh)*muw))))))/ (2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh)) + ...
    xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*(lamdaw + 2*muw)); % Eq. (A-25)
A4iii=-((2*(xw*(2*(xh*(lamdah + 2*muh)*muw*(lamdaw + muw) + xw*muh*(lamdah + muh)*(lamdaw + 2*muw)) + ...
    mh*lamdah*(-(xw*muh*(lamdaw + 2*muw)) + xh*(lamdaw*muh - 2*lamdaw*muw - 2*muw^2))) + ...
    kh*(-(xw*lamdah*(xw*muh*(lamdaw + 2*muw) + xh*(-(lamdaw*muh) + 2*lamdaw*muw + 2*muw^2))) + ...
    2*mh*(xh^2*muh*(lamdah + muh)*(lamdaw + 2*muw) + xw^2*muh*(lamdah + muh)*(lamdaw + 2*muw) + ...
    xh*xw*(2*muh*(muh^2 + muw*(lamdaw + muw)) + lamdah*(3*muh^2 + muw^2 + lamdaw*(muh + ...
    muw)))))))/ (2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh)) + xh*((-1 + ...
    kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*(lamdaw + 2*muw))); % Eq. (A-26)

Ziii=2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh)) + xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    2*(muh + kh*mh*muh))*(lamdaw + 2*muw); % Eq. (A-37)
K1iii=2/Ziii*muh*(xw*(4*muh^2 + lamdah*(lamdaw + kh*lamdaw + 6*muh)) + 2*xh*(lamdah + ...
    muh)*(lamdaw + 2*muw)); % Eq. (A-29)
K2iii=2/Ziii*muh*(xw*lamdah*lamdaw + kh*(xw*(lamdah*lamdaw + 6*lamdah*muh + 4*muh^2) + 2*xh*(lamdah + ...
    muh)*(lamdaw + 2*muw))); % Eq. (A-30)
K3iii=2/Ziii*mh*muh*(xw*(4*muh^2 + lamdah*(lamdaw + kh*lamdaw + 6*muh)) + 2*xh*(lamdah + ...
    muh)*(lamdaw + 2*muw)); % Eq. (A-31)
K4iii=2/Ziii*mh*muh*(xw*lamdah*lamdaw + kh*(xw*(lamdah*lamdaw + 6*lamdah*muh + 4*muh^2) + ...
    2*xh*(lamdah + muh)*(lamdaw + 2*muw))); % Eq. (A-32)
K5iii=2/Ziii*(xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*(lamdaw + 2*muw) + ...
    xh*(4*(1 + kh*mh)*muh*muw*(lamdaw + muw) + lamdah* (2*(-1 + kh)*(-1 + mh)*muw^2 + lamdaw*((1 + mh)*muh + ...
    2*(-1 + kh)*(-1 + mh)*muw)))); % Eq. (A-33)
K6iii=2/Ziii*lamdaw*(xw*muh*(2*lamdah - mh*lamdah + 2*muh) + xh*(lamdah - mh*lamdah + 2*muh)*muw + ...
    kh*(xw*muh*((-1 + 2*mh)*lamdah + 2*mh*muh) + xh*(2*mh*muh*muw + lamdah*(muh + mh*muh - ...
    muw + mh*muw)))); % Eq. (A-34)
K7iii=2/Ziii*lamdaw*(xw*muh*((2 - kh - mh + 2*kh*mh)*lamdah + 2*(muh + kh*mh*muh)) + ...
    xh*(2*(1 + kh*mh)*muh*muw + lamdah*((1 + mh)*muh + (-1 + kh)*(-1 + mh)*muw))); % Eq. (A-35)
K8iii=2/Ziii*(-2*xh*((-1 + mh)*lamdah - 2*muh)*muw*(lamdaw + muw) - xw*((-2 + mh)*lamdah - ...
    2*muh)*muh*(lamdaw + 2*muw) + kh*(xw*muh*((-1 + 2*mh)*lamdah + 2*mh*muh)*(lamdaw + 2*muw) + ...
    xh*(4*mh*muh*muw*(lamdaw + muw) + lamdah*(2*(-1 + mh)*muw^2 + lamdaw*(muh + mh*muh - 2*muw + 2*mh*muw))))); % Eq. (A-36)

B1iii=(2*muh*(xw*lamdaw*((2 - kh - mh + 2*kh*mh)*lamdah + 2*(muh + kh*mh*muh)) + (1 + mh)*xh*lamdah*(lamdaw + ...
    2*muw)))/ (2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh)) + xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    2*(muh + kh*mh*muh))*(lamdaw + 2*muw)); % Eq. (A-27)
B2iii=(2*muh*(xw*lamdaw*((2 - mh)*lamdah + 2*muh) + kh*(xw*lamdaw*(-lamdah + 2*mh*lamdah + 2*mh*muh) + (1 + ...
    mh)*xh*lamdah*(lamdaw + 2*muw))))/ (2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh)) + ...
    xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*(lamdaw + 2*muw)); % Eq. (A-28)

% Constants for the case iv (hard and weak layers behave
% elasto-plastically)
A1iv=(2*(2*xw^2*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*muw*(lamdaw + muw) + ...
    2*xh^2*muh*(lamdah + muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xh*xw*(lamdah*(2*muw*(3*(1 + kw*mw)*muh^2 + (-1 + kh)*(-1 + mh)*muw^2) + lamdaw*(3*(-1 + kw)*(-1 + mw)*muh^2 + ...
    (2 + kh + kw + mh + kw*mh + mw + kh*mw)*muh*muw + 3*(-1 + kh)*(-1 + mh)*muw^2)) + ...
    2*muh*(2*muw*((1 + kw*mw)*muh^2 + (1 + kh*mh)*muw^2) + lamdaw*((-1 + kw)*(-1 + mw)*muh^2 + ...
    3*(1 + kh*mh)*muw^2)))))/ (xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + ...
    mw)*lamdaw + 2*(muw + kw*mw*muw)) + xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*((2 - mw + ...
    kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))); % Eq. (A-38)
A2iv=-((2*(kw*xw*muw*(-2*xw*((-2 + mh)*lamdah - 2*muh)*muh*(lamdaw + muw) + xh*(2*muh*muw*(3*lamdaw + 2*muw) + ...
    lamdah*(-2*(-1 + mh)*muw^2 + lamdaw*(muh + mw*muh + 3*muw - 3*mh*muw)))) + kh*(2*kw*xw^2*muh*((-1 + ...
    2*mh)*lamdah + 2*mh*muh)*muw*(lamdaw + muw) + 2*xh^2*muh*(lamdah + muh)*muw*((2 - mw + kw*(-1 + ...
    2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + xh*xw*(lamdah*(2*muw*(3*(1 + kw*mw)*muh^2 + kw*(-1 + mh)*muw^2) + ...
    lamdaw*(3*(-1 + kw)*(-1 + mw)*muh^2 + (1 + mh + kw*(2 + mh + mw))*muh*muw + 3*kw*(-1 + mh)*muw^2)) + ...
    2*muh*(2*muw*((1 + kw*mw)*muh^2 + kw*mh*muw^2) + lamdaw*((-1 + kw)*(-1 + mw)*muh^2 + ...
    3*kw*mh*muw^2))))))/ (xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + ...
    mw)*lamdaw + 2*(muw + kw*mw*muw)) + xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*((2 - mw + ...
    kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)))); % Eq. (A-39)
A3iv=(2*(mw*xw*muw*(-2*xw*((-2 + kh)*lamdah - 2*muh)*muh*(lamdaw + muw) + xh*(2*muh*muw*(3*lamdaw + 2*muw) + ...
    lamdah*(-2*(-1 + kh)*muw^2 + lamdaw*(muh + kw*muh + 3*muw - 3*kh*muw)))) + mh*(2*mw*xw^2*muh*((-1 + ...
    2*kh)*lamdah + 2*kh*muh)*muw*(lamdaw + muw) + 2*xh^2*muh*(lamdah + muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw ...
    + 2*(muw + kw*mw*muw)) + xh*xw*(lamdah*(2*muw*(3*(1 + kw*mw)*muh^2 + (-1 + kh)*mw*muw^2) + lamdaw*(3*(-1 + ...
    kw)*(-1 + mw)*muh^2 + (1 + kh + 2*mw + kh*mw + kw*mw)*muh*muw + 3*(-1 + kh)*mw*muw^2)) + 2*muh*(2*muw*((1 + ...
    kw*mw)*muh^2 + kh*mw*muw^2) + lamdaw*((-1 + kw)*(-1 + mw)*muh^2 + 3*kh*mw*muw^2))))))/(xw*muh*((2 - mh + ...
    kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))* ((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw ...
    + kw*mw*muw))); % Eq. (A-40)
A4iv=-((2*(kw*xw*muw*(mw*(4*xw*muh*(lamdah + muh)*(lamdaw + muw) + xh*(lamdah + 2*muh)*muw*(3*lamdaw + ...
    2*muw)) + mh*lamdah*(-2*mw*xw*muh*(lamdaw + muw) + xh*(-2*mw*muw^2 + lamdaw*(muh + mw*muh - 3*mw*muw)))) + ...
    kh*(mw*xw*lamdah*muw*(-2*kw*xw*muh*(lamdaw + muw) + xh*(-2*kw*muw^2 + lamdaw*(muh + kw*muh - 3*kw*muw))) + ...
    mh*(4*kw*mw*xw^2*muh*(lamdah + muh)*muw*(lamdaw + muw) + 2*xh^2*muh*(lamdah + muh)*muw*((2 - mw + ...
    kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + xh*xw*(2*muh*(2*muw*((1 + kw*mw)*muh^2 + kw*mw*muw^2) + ...
    lamdaw*((-1 + kw)*(-1 + mw)*muh^2 + 3*kw*mw*muw^2)) + lamdah*(2*muw*(3*(1 + kw*mw)*muh^2 + kw*mw*muw^2) + ...
    lamdaw*(3*(-1 + kw)*(-1 + mw)*muh^2 + (kw + mw + 2*kw*mw)*muh*muw + 3*kw*mw*muw^2)))))))/ (xw*muh*((2 - mh + ...
    kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + ...
    2*(muw + kw*mw*muw)))); % Eq. (A-41)

Ziv=xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + ...
    2*(muw + kw*mw*muw)) + xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*((2 - mw + kw*(-1 + ...
    2*mw))*lamdaw + 2*(muw + kw*mw*muw)); % Eq. (A-52)
K1iv=2/Ziv*muh*(2*xh*(lamdah + muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xw*(2*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + lamdah*(6*(1 + kw*mw)*muh*muw + ...
    lamdaw*(3*(-1 + kw)*(-1 + mw)*muh + (1 + kh)*(1 + mw)*muw)))); % Eq. (A-44)
K2iv=2/Ziv*muh*(kw*(1 + mw)*xw*lamdah*lamdaw*muw + kh*(2*xh*(lamdah + muh)*muw* ((2 - mw + kw*(-1 + ...
    2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + xw*(2*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + ...
    lamdah*(6*(1 + kw*mw)*muh*muw + lamdaw*(3*(-1 + kw)*(-1 + mw)*muh + kw*(1 + mw)*muw))))); % Eq. (A-45)
K3iv=2/Ziv*mh*muh*(2*xh*(lamdah + muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xw*(2*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + lamdah*(6*(1 + kw*mw)*muh*muw + ...
    lamdaw*(3*(-1 + kw)*(-1 + mw)*muh + (1 + kh)*(1 + mw)*muw)))); % Eq. (A-46)
K4iv=2/Ziv*mh*muh*(kw*(1 + mw)*xw*lamdah*lamdaw*muw + kh* (2*xh*(lamdah + muh)*muw*((2 - mw + kw*(-1 + ...
    2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + xw*(2*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + ...
    lamdah*(6*(1 + kw*mw)*muh*muw + lamdaw*(3*(-1 + kw)*(-1 + mw)*muh + kw*(1 + mw)*muw))))); % Eq. (A-47)
K5iv=2/Ziv*muw*(2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*(lamdaw + muw) + ...
    xh*(2*(1 + kh*mh)*muh*muw*(3*lamdaw + 2*muw) + lamdah*(2*(-1 + kh)*(-1 + mh)*muw^2 + lamdaw*((1 + kw)*(1 + ...
    mh)*muh + 3*(-1 + kh)*(-1 + mh)*muw)))); % Eq. (A-48)
K6iv=2/Ziv*muw*(kw*(-2*xw*((-2 + mh)*lamdah - 2*muh)*muh*(lamdaw + muw) - xh*((-1 + mh)*lamdah - ...
    2*muh)*muw*(3*lamdaw + 2*muw)) + kh*(2*kw*xw*muh*((-1 + 2*mh)*lamdah + 2*mh*muh)*(lamdaw + muw) + ...
    xh*(2*kw*mh*muh*muw*(3*lamdaw + 2*muw) + lamdah*(2*kw*(-1 + mh)*muw^2 + lamdaw*((1 + kw)*(1 + mh)*muh + ...
    3*kw*(-1 + mh)*muw))))); % Eq. (A-49)
K7iv=2/Ziv*mw*muw*(2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*(lamdaw + muw) + ...
    xh*(2*(1 + kh*mh)*muh*muw*(3*lamdaw + 2*muw) + lamdah*(2*(-1 + kh)*(-1 + mh)*muw^2 + lamdaw*((1 + ...
    kw)*(1 + mh)*muh + 3*(-1 + kh)*(-1 + mh)*muw)))); % Eq. (A-50)
K8iv=2/Ziv*mw*muw*(kw*(-2*xw*((-2 + mh)*lamdah - 2*muh)*muh*(lamdaw + muw) - xh*((-1 + mh)*lamdah - ...
    2*muh)*muw*(3*lamdaw + 2*muw)) + kh*(2*kw*xw*muh*((-1 + 2*mh)*lamdah + 2*mh*muh)*(lamdaw + muw) + ...
    xh*(2*kw*mh*muh*muw*(3*lamdaw + 2*muw) + lamdah*(2*kw*(-1 + mh)*muw^2 + lamdaw*((1 + kw)*(1 + mh)*muh + ...
    3*kw*(-1 + mh)*muw))))); % Eq. (A-51)

B1iv=(2*muh*muw*((1 + mw)*xw*lamdaw*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh)) + ...
    (1 + mh)*xh*lamdah*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))/ (xw*muh*((2 - mh + kh*(-1 +...
    2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + xh*((-1 + kh)*(-1 + ...
    mh)*lamdah + 2*(muh + kh*mh*muh))*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))); % Eq. (A-42)
B2iv=(2*muh*muw*(-(kw*(1 + mw)*xw*lamdaw*((-2 + mh)*lamdah - 2*muh)) + kh*(kw*(1 + mw)*xw*lamdaw*((-1 + ...
    2*mh)*lamdah + 2*mh*muh) + (1 + mh)*xh*lamdah*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + ...
    kw*mw*muw)))))/ (xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + ...
    mw)*lamdaw + 2*(muw + kw*mw*muw)) + xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*((2 - ...
    mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))); % Eq. (A-43)

% Constants for the case iio (weak layers: out-of-plane failure (in triaxial extension),
% hard layers: elastic)

A1iio=(kw*mw*xh^2*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + xw^2*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + ...
    xh*xw*(4*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw) + lamdah*(2*muw*((2 + 4*kw*mw)*muh + ...
    (kw + mw)*muw) + lamdaw*(4*(-1 + kw)*(-1 + mw)*muh + 3*(kw + mw)*muw))))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + ...
    xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-53)
A2iio=-((kw*mw*xh^2*lamdah*muw*(3*lamdaw + 2*muw) + kw*xw^2*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + ...
    xh*xw*lamdah*(2*muw*(muh + 2*kw*mw*muh + kw*(1 + mw)*muw) + lamdaw*(2*(-1 + kw)*(-1 + mw)*muh + 3*kw*(1 + ...
    mw)*muw)))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + ...
    2*kw*mw*muw))); % Eq. (A-54)
A3iio=(kw*mw*xh^2*lamdah*muw*(3*lamdaw + 2*muw) + mw*xw^2*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + ...
    xh*xw*lamdah*(2*muw*(muh + 2*kw*mw*muh + (1 + kw)*mw*muw) + lamdaw*(2*(-1 + kw)*(-1 + mw)*muh + 3*(1 + ...
    kw)*mw*muw)))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + ...
    2*kw*mw*muw)); % Eq. (A-55)
A4iio=-((kw*mw*xh^2*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + kw*mw*xw^2*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + ...
    2*xh*xw*(2*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw) + lamdah*(2*muw*(muh + 2*kw*mw*muh + kw*mw*muw) + ...
    lamdaw*(2*(-1 + kw)*(-1 + mw)*muh + 3*kw*mw*muw))))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + xw*(lamdah + ...
    2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw))); % Eq. (A-56)

K1iio=(kw*mw*xh*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + xw*(4*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + muw + ...
    2*kw*mw*muw) + lamdah*(2*muw*((2 + 4*kw*mw)*muh + mw*muw) + lamdaw*(4*(-1 + kw)*(-1 + mw)*muh + ...
    3*mw*muw))))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + ...
    2*kw*mw*muw)); % Eq. (A-59)
K2iio=(lamdah*(kw*mw*xh*muw*(3*lamdaw + 2*muw) + xw*(2*muw*(muh + 2*kw*mw*muh + kw*mw*muw) + lamdaw*(2*(-1 + ...
    kw)*(-1 + mw)*muh + 3*kw*mw*muw))))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + ...
    mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-60)
K3iio=(lamdah*(kw*mw*xh*muw*(3*lamdaw + 2*muw) + xw*(2*muw*(muh + 2*kw*mw*muh + mw*muw) + lamdaw*(2*(-1 + ...
    kw)*(-1 + mw)*muh + 3*mw*muw))))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + ...
    mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-61)
K4iio=(kw*mw*xh*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + xw*(4*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + muw + ...
    2*kw*mw*muw) + lamdah*(2*muw*((2 + 4*kw*mw)*muh + kw*mw*muw) + lamdaw*(4*(-1 + kw)*(-1 + mw)*muh + ...
    3*kw*mw*muw))))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + ...
    muw + 2*kw*mw*muw)); % Eq. (A-62)
K5iio=((kw*xh*lamdah + xw*(lamdah + 2*muh))*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + ...
    xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-63)
K6iio=(kw*(xh*lamdah + xw*(lamdah + 2*muh))*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + ...
    xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-64)
K7iio=(mw*(kw*xh*lamdah + xw*(lamdah + 2*muh))*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + ...
    xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-65)
K8iio=(kw*mw*(xh*lamdah + xw*(lamdah + 2*muh))*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + ...
    xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-66)

B1iio=(mw*(kw*xh*lamdah + xw*(lamdah + 2*muh))*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + ...
    xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-57)
B2iio=(kw*mw*(xh*lamdah + xw*(lamdah + 2*muh))*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*muw*(3*lamdaw + 2*muw) + ...
    xw*(lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-58)


% Constants for the case iiio (hard layers: out-of-plane failure (in triaxial extension),
% weak layers: elastic)

A1iiio=(xh^2*muh*(3*lamdah + 2*muh)*(lamdaw + 2*muw) + kh*mh*xw^2*muh*(3*lamdah + 2*muh)*(lamdaw + 2*muw) + ...
    xh*xw*(4*(lamdah + muh)*muw*(lamdaw + muw) + mh*(3*lamdah*lamdaw*muh + 2*lamdaw*muh^2 - 4*lamdah*lamdaw*muw - ...
    4*lamdah*muw^2) + kh*(lamdah*(4*(-1 + mh)*muw^2 + lamdaw*(3*muh + 4*(-1 + mh)*muw)) + 2*muh*(4*mh*muw^2 + ...
    lamdaw*(muh + 4*mh*muw)))))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + xh*((-1 + kh)*(-1 + mh)*lamdah + muh + ...
    2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-68)
A2iiio=  -((2*xh*xw*lamdaw*(lamdah - mh*lamdah + muh)*muw + kh* (mh*xw^2*lamdaw*muh*(3*lamdah + 2*muh) + ...
    xh^2*muh*(3*lamdah + 2*muh)*(lamdaw + 2*muw) + xh*xw*lamdaw*(lamdah*(3*(1 + mh)*muh + 2*(-1 + mh)*muw) + ...
    2*muh*(muh + mh*muh + 2*mh*muw))))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + xh*((-1 + kh)*(-1 + mh)*lamdah + muh + ...
    2*kh*mh*muh)*(lamdaw + 2*muw))); % Eq. (A-69)
A3iiio=(2*xh*xw*lamdaw*(lamdah - kh*lamdah + muh)*muw + mh*(kh*xw^2*lamdaw*muh*(3*lamdah + 2*muh) + ...
    xh^2*muh*(3*lamdah + 2*muh)*(lamdaw + 2*muw) + xh*xw*lamdaw*(lamdah*(3*(1 + kh)*muh + 2*(-1 + kh)*muw) + ...
    2*muh*(muh + kh*muh + 2*kh*muw))))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + xh*((-1 + kh)*(-1 + mh)*lamdah + muh + ...
    2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-70)
A4iiio=-((-4*xh*xw*((-1 + mh)*lamdah - muh)*muw*(lamdaw + muw) + kh*(-4*xh*xw*lamdah*muw*(lamdaw + muw) + ...
    mh*(xh^2*muh*(3*lamdah + 2*muh)*(lamdaw + 2*muw) + xw^2*muh*(3*lamdah + 2*muh)*(lamdaw + 2*muw) + ...
    2*xh*xw*(2*muh*(lamdaw*muh + 2*lamdaw*muw + 2*muw^2) + lamdah*(3*lamdaw*muh + 2*lamdaw*muw + ...
    2*muw^2)))))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + xh*((-1 + kh)*(-1 + mh)*lamdah + muh + 2*kh*mh*muh)*(lamdaw + ...
    2*muw))); % Eq. (A-71)

K1iiio=(muh*(3*lamdah + 2*muh)*(kh*xw*lamdaw + xh*(lamdaw + 2*muw)))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + ...
    xh*((-1 + kh)*(-1 + mh)*lamdah + muh + 2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-74)
K2iiio=(kh*muh*(3*lamdah + 2*muh)*(xw*lamdaw + xh*(lamdaw + 2*muw)))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + ...
    xh*((-1 + kh)*(-1 + mh)*lamdah + muh + 2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-75)
K3iiio=(mh*muh*(3*lamdah + 2*muh)*(kh*xw*lamdaw + xh*(lamdaw + 2*muw)))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + ...
    xh*((-1 + kh)*(-1 + mh)*lamdah + muh + 2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-76)
K4iiio=(kh*mh*muh*(3*lamdah + 2*muh)*(xw*lamdaw + xh*(lamdaw + 2*muw)))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + ...
    xh*((-1 + kh)*(-1 + mh)*lamdah + muh + 2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-77)
K5iiio=(-4*xh*((-1 + kh)*lamdah - muh)*muw*(lamdaw + muw) + mh*(kh*xw*muh*(3*lamdah + 2*muh)*(lamdaw + 2*muw) + ...
    xh*(lamdah*(4*(-1 + kh)*muw^2 + lamdaw*(3*muh + 4*(-1 + kh)*muw)) + 2*muh*(4*kh*muw^2 + ...
    lamdaw*(muh + 4*kh*muw)))))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + xh*((-1 + kh)*(-1 + mh)*lamdah + muh + ...
    2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-78)
K6iiio=(lamdaw*(2*xh*(lamdah - mh*lamdah + muh)*muw + kh*(-2*xh*lamdah*muw + mh*(xw*muh*(3*lamdah + 2*muh) + ...
    xh*(3*lamdah*muh + 2*muh^2 + 2*lamdah*muw + 4*muh*muw)))))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + ...
    xh*((-1 + kh)*(-1 + mh)*lamdah + muh + 2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-79)
K7iiio=(lamdaw*(2*xh*(lamdah - kh*lamdah + muh)*muw + mh*(kh*xw*muh*(3*lamdah + 2*muh) + xh*(lamdah*(3*muh + ...
    2*(-1 + kh)*muw) + 2*muh*(muh + 2*kh*muw)))))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + xh*((-1 + kh)*(-1 + ...
    mh)*lamdah + muh + 2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-80)
K8iiio=(-4*xh*((-1 + mh)*lamdah - muh)*muw*(lamdaw + muw) + kh*(-4*xh*lamdah*muw*(lamdaw + muw) + ...
    mh*(xw*muh*(3*lamdah + 2*muh)*(lamdaw + 2*muw) + xh*(2*muh*(lamdaw*muh + 4*lamdaw*muw + 4*muw^2) + ...
    lamdah*(3*lamdaw*muh + 4*lamdaw*muw + 4*muw^2)))))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + xh*((-1 + kh)*(-1 + ...
    mh)*lamdah + muh + 2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-81)

B1iiio=(mh*muh*(3*lamdah + 2*muh)*(kh*xw*lamdaw + xh*(lamdaw + 2*muw)))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + ...
    xh*((-1 + kh)*(-1 + mh)*lamdah + muh + 2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-72)
B2iiio=(kh*mh*muh*(3*lamdah + 2*muh)*(xw*lamdaw + xh*(lamdaw + 2*muw)))/ (kh*mh*xw*muh*(3*lamdah + 2*muh) + ...
    xh*((-1 + kh)*(-1 + mh)*lamdah + muh + 2*kh*mh*muh)*(lamdaw + 2*muw)); % Eq. (A-73)


% Constants for the case ivo1 (hard layers: in-plane failure,
% weak layers: out-of-plane failure (in triaxial extension))

A1ivo1=(2*muh*(2*kw*mw*xh^2*(lamdah + muh)*muw*(3*lamdaw + 2*muw) + xw^2*((2 - mh + kh*(-1 + ...
    2*mh))*lamdah + 2*(muh + kh*mh*muh))*muw*(3*lamdaw + 2*muw) + xh*xw*(4*muh^2*((-1 + kw)*(-1 + ...
    mw)*lamdaw + muw + 2*kw*mw*muw) + lamdah*(3*lamdaw*(2*(-1 + kw)*(-1 + mw)*muh + (kw + kw*mh + mw + ...
    kh*mw)*muw) + 2*muw*((3 + 6*kw*mw)*muh + (kw + kw*mh + mw + kh*mw)*muw)))))/ (kw*mw*xh*((-1 + kh)*(-1 + ...
    mh)*lamdah + 2*(muh + kh*mh*muh))*muw*(3*lamdaw + 2*muw) + 2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + ...
    2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-83)
A2ivo1= (-2*muh*(kw*xw*(mw*xh*lamdah + xw*((2 - mh)*lamdah + 2*muh))*muw*(3*lamdaw + 2*muw) + ...
    kh*(2*kw*mw*xh^2*(lamdah + muh)*muw*(3*lamdaw + 2*muw) + kw*xw^2*((-1 + 2*mh)*lamdah + 2*mh*muh)*muw*(3*lamdaw + ...
    2*muw) + xh*xw*(4*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw) + lamdah*(3*lamdaw*(2*(-1 + ...
    kw)*(-1 + mw)*muh + kw*(1 + mh + mw)*muw) + 2*muw*((3 + 6*kw*mw)*muh + kw*(1 + mh + ...
    mw)*muw))))))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*(3*lamdaw + ...
    2*muw) + 2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + ...
    muw + 2*kw*mw*muw)); % Eq. (A-84)
A3ivo1=(2*muh*(mw*xw*(kw*xh*lamdah + xw*((2 - kh)*lamdah + 2*muh))*muw*(3*lamdaw + 2*muw) + ...
    mh*(2*kw*mw*xh^2*(lamdah + muh)*muw*(3*lamdaw + 2*muw) + mw*xw^2*((-1 + 2*kh)*lamdah + 2*kh*muh)*muw*(3*lamdaw + ...
    2*muw) + xh*xw*(4*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw) + lamdah*(3*lamdaw*(2*(-1 + kw)*(-1 + ...
    mw)*muh + (1 + kh + kw)*mw*muw) + 2*muw*((3 + 6*kw*mw)*muh + (1 + kh + kw)*mw*muw))))))/ (kw*mw*xh*((-1 + ...
    kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*(3*lamdaw + 2*muw) + 2*xw*muh*((2 - mh + kh*(-1 + ...
    2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-85)
A4ivo1=(-2*muh*(kw*mw*xw*(mh*(xh - xw)*lamdah + 2*xw*(lamdah + muh))*muw*(3*lamdaw + 2*muw) + kh*(kw*mw*(xh - ...
    xw)*xw*lamdah*muw*(3*lamdaw + 2*muw) + 2*mh*(kw*mw*xh^2*(lamdah + muh)*muw*(3*lamdaw + 2*muw) + ...
    kw*mw*xw^2*(lamdah + muh)*muw*(3*lamdaw + 2*muw) + xh*xw*(2*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + muw + ...
    2*kw*mw*muw) + lamdah*(3*lamdaw*((-1 + kw)*(-1 + mw)*muh + kw*mw*muw) + muw*((3 + 6*kw*mw)*muh + ...
    2*kw*mw*muw)))))))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*(3*lamdaw + 2*muw) + ...
    2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-86)

K1ivo1=(2*muh*(2*kw*mw*xh*(lamdah + muh)*muw*(3*lamdaw + 2*muw) + xw*(4*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + ...
    muw + 2*kw*mw*muw) + lamdah*(3*lamdaw*(2*(-1 + kw)*(-1 + mw)*muh + (1 + kh)*mw*muw) + 2*muw*((3 + ...
    6*kw*mw)*muh + (1 + kh)*mw*muw)))))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*(3*lamdaw + ...
    2*muw) + 2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + ...
    2*kw*mw*muw)); % Eq. (A-89)
K2ivo1=(2*muh*(kw*mw*xw*lamdah*muw*(3*lamdaw + 2*muw) + kh* (2*kw*mw*xh*(lamdah + muh)*muw*(3*lamdaw + 2*muw) + ...
    xw*(4*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw) + lamdah*(3*lamdaw*(2*(-1 + kw)*(-1 + mw)*muh + ...
    kw*mw*muw) + 2*muw*((3 + 6*kw*mw)*muh + kw*mw*muw))))))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    2*(muh + kh*mh*muh))*muw*(3*lamdaw + 2*muw) + 2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + ...
    kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-90)
K3ivo1=(2*mh*muh*(2*kw*mw*xh*(lamdah + muh)*muw*(3*lamdaw + 2*muw) + xw*(4*muh^2*((-1 + kw)*(-1 + ...
    mw)*lamdaw + muw + 2*kw*mw*muw) + lamdah*(3*lamdaw*(2*(-1 + kw)*(-1 + mw)*muh + (1 + kh)*mw*muw) + ...
    2*muw*((3 + 6*kw*mw)*muh + (1 + kh)*mw*muw)))))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    2*(muh + kh*mh*muh))*muw*(3*lamdaw + 2*muw) + 2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + ...
    2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-91)
K4ivo1=(2*mh*muh*(kw*mw*xw*lamdah*muw*(3*lamdaw + 2*muw) + kh*(2*kw*mw*xh*(lamdah + muh)*muw*(3*lamdaw + ...
    2*muw) + xw*(4*muh^2*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw) + lamdah*(3*lamdaw*(2*(-1 + ...
    kw)*(-1 + mw)*muh + kw*mw*muw) + 2*muw*((3 + 6*kw*mw)*muh + kw*mw*muw))))))/ (kw*mw*xh*((-1 + kh)*(-1 + ...
    mh)*lamdah + 2*(muh + kh*mh*muh))*muw*(3*lamdaw + 2*muw) + 2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + ...
    2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-92)
K5ivo1=(2*muh*(kw*(1 + mh)*xh*lamdah + xw*((2 - kh - mh + 2*kh*mh)*lamdah + 2*(muh + kh*mh*muh)))*muw*(3*lamdaw + ...
    2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*(3*lamdaw + 2*muw) + 2*xw*muh*((2 - ...
    mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-93)
K6ivo1=(2*kw*muh*(xw*((2 - mh)*lamdah + 2*muh) + kh*((1 + mh)*xh*lamdah + xw*(-lamdah + 2*mh*lamdah + ...
    2*mh*muh)))*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + ...
    kh*mh*muh))*muw*(3*lamdaw + 2*muw) + 2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + ...
    kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-94)
K7ivo1=(2*mw*muh*(kw*(1 + mh)*xh*lamdah + xw*((2 - kh - mh + 2*kh*mh)*lamdah + 2*(muh + kh*mh*muh)))*muw*(3*lamdaw + ...
    2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + kh*mh*muh))*muw*(3*lamdaw + 2*muw) + ...
    2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-95)
K8ivo1=(2*kw*mw*muh*(xw*((2 - mh)*lamdah + 2*muh) + kh*((1 + mh)*xh*lamdah + xw*(-lamdah + 2*mh*lamdah + ...
    2*mh*muh)))*muw* (3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + ...
    kh*mh*muh))*muw*(3*lamdaw + 2*muw) + 2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + kh*mh*muh))*((-1 + ...
    kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-96)

B1ivo1=  (2*mw*muh*(kw*(1 + mh)*xh*lamdah + xw*((2 - kh - mh + 2*kh*mh)*lamdah + 2*(muh + ...
    kh*mh*muh)))*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + ...
    kh*mh*muh))*muw*(3*lamdaw + 2*muw) + 2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + ...
    kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-87)
B2ivo1=(2*kw*mw*muh*(xw*((2 - mh)*lamdah + 2*muh) + kh*((1 + mh)*xh*lamdah + xw*(-lamdah + 2*mh*lamdah + ...
    2*mh*muh)))*muw* (3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + 2*(muh + ...
    kh*mh*muh))*muw*(3*lamdaw + 2*muw) + 2*xw*muh*((2 - mh + kh*(-1 + 2*mh))*lamdah + 2*(muh + ...
    kh*mh*muh))*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-88)


% Constants for the case ivo2 (hard layers: out-of-plane failure (in triaxial extension),
% weak layers: in-plane failure)

A1ivo2=(2*muw*(2*kh*mh*xw^2*muh*(3*lamdah + 2*muh)*(lamdaw + muw) + xh^2*muh*(3*lamdah + 2*muh)*((2 - mw + ...
    kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + xh*xw*(2*(lamdah + muh)*muw*(3*lamdaw + 2*muw) + mh*(2*(1 + ...
    kw)*lamdaw*muh^2 + lamdah*(3*lamdaw*(muh + kw*muh - 2*muw) - 4*muw^2)) + kh*(lamdah*(4*(-1 + mh)*muw^2 + ...
    3*lamdaw*(muh + mw*muh - 2*muw + 2*mh*muw)) + 2*muh*(4*mh*muw^2 + lamdaw*(muh + mw*muh + ...
    6*mh*muw))))))/ (-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + ...
    kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - 2*(muw + kw*mw*muw)) + ...
    mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + 2*xh*(lamdah + ...
    2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-98)
A2ivo2=(-2*muw*(-2*kw*xh*xw*((-1 + mh)*lamdah - muh)*muw*(3*lamdaw + 2*muw) + kh*(2*kw*mh*xw^2*muh*(3*lamdah + ...
    2*muh)*(lamdaw + muw) + xh^2*muh*(3*lamdah + 2*muh)*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xh*xw*(mh*lamdaw*muh*(3*lamdah + 2*muh) + kw*(lamdah*(4*(-1 + mh)*muw^2 + 3*lamdaw*((1 + mh + mw)*muh + ...
    2*(-1 + mh)*muw)) + 2*muh*(4*mh*muw^2 + lamdaw*((1 + mh + mw)*muh + 6*mh*muw)))))))/ (-2*xh*((-1 + mh)*lamdah - ...
    muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - ...
    2*kw*mw)*lamdaw - 2*(muw + kw*mw*muw)) + mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + ...
    kw*mw*muw)) + 2*xh*(lamdah + 2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-99)
A3ivo2=(2*muw*(-2*mw*xh*xw*((-1 + kh)*lamdah - muh)*muw*(3*lamdaw + 2*muw) + mh*(2*kh*mw*xw^2*muh*(3*lamdah + ...
    2*muh)*(lamdaw + muw) + xh^2*muh*(3*lamdah + 2*muh)*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xh*xw*(mw*(2*(1 + kw)*lamdaw*muh^2 + lamdah*(3*lamdaw*(muh + kw*muh - 2*muw) - 4*muw^2)) + ...
    kh*(lamdah*(4*mw*muw^2 + 3*lamdaw*(muh + mw*muh + 2*mw*muw)) + 2*muh*(4*mw*muw^2 + lamdaw*(muh + mw*muh + ...
    6*mw*muw)))))))/(-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + ...
    kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - 2*(muw + kw*mw*muw)) + mh*(xw*muh*(3*lamdah + ...
    2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + 2*xh*(lamdah + 2*muh)*muw*((2 - mw + kw*(-1 + ...
    2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-100)
A4ivo2=(-2*muw*(-2*kw*mw*xh*xw*((-1 + mh)*lamdah - muh)*muw*(3*lamdaw + 2*muw) + ...
    kh*(-2*kw*mw*xh*xw*lamdah*muw*(3*lamdaw + 2*muw) + mh*(2*kw*mw*xw^2*muh*(3*lamdah + 2*muh)*(lamdaw + ...
    muw) + xh^2*muh*(3*lamdah + 2*muh)*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + ...
    xh*xw*(mw*lamdaw*muh*(3*lamdah + 2*muh) + kw*(lamdah*(4*mw*muw^2 + 3*lamdaw*(muh + 2*mw*muh + 2*mw*muw)) + ...
    2*muh*(4*mw*muw^2 + lamdaw*(muh + 2*mw*muh + 6*mw*muw))))))))/ (-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + ...
    kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - ...
    2*(muw + kw*mw*muw)) + mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + ...
    2*xh*(lamdah + 2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-101)

K1ivo2=(2*muh*(3*lamdah + 2*muh)*muw*(kh*(1 + mw)*xw*lamdaw + xh*((2 - kw - mw + 2*kw*mw)*lamdaw + ...
    2*(muw + kw*mw*muw))))/ (-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + ...
    2*(muw + kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - 2*(muw + kw*mw*muw)) + ...
    mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + 2*xh*(lamdah + ...
    2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-104)
K2ivo2=(2*kh*muh*(3*lamdah + 2*muh)*muw*(kw*(1 + mw)*xw*lamdaw + xh*((2 - kw - mw + 2*kw*mw)*lamdaw + ...
    2*(muw + kw*mw*muw))))/ (-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + ...
    kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - 2*(muw + kw*mw*muw)) + ...
    mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + 2*xh*(lamdah + ...
    2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-105)
K3ivo2=(2*mh*muh*(3*lamdah + 2*muh)*muw*(kh*(1 + mw)*xw*lamdaw + xh*((2 - kw - mw + 2*kw*mw)*lamdaw + ...
    2*(muw + kw*mw*muw))))/ (-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + ...
    kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - 2*(muw + kw*mw*muw)) + ...
    mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + 2*xh*(lamdah + ...
    2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-106)
K4ivo2=(2*kh*mh*muh*(3*lamdah + 2*muh)*muw*(kw*(1 + mw)*xw*lamdaw + xh*((2 - kw - mw + 2*kw*mw)*lamdaw + ...
    2*(muw + kw*mw*muw))))/ (-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + ...
    kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - 2*(muw + kw*mw*muw)) + ...
    mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + 2*xh*(lamdah + ...
    2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-107)
K5ivo2=(2*muw*(-2*xh*((-1 + kh)*lamdah - muh)*muw*(3*lamdaw + 2*muw) + mh*(2*kh*xw*muh*(3*lamdah + ...
    2*muh)*(lamdaw + muw) + xh*(lamdah*(4*(-1 + kh)*muw^2 + 3*lamdaw*(muh + kw*muh - 2*muw + 2*kh*muw)) + ...
    2*muh*(4*kh*muw^2 + lamdaw*(muh + kw*muh + 6*kh*muw))))))/ (-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + ...
    kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - ...
    2*(muw + kw*mw*muw)) + mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + ...
    2*xh*(lamdah + 2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-108)
K6ivo2=(2*muw*(-2*kw*xh*((-1 + mh)*lamdah - muh)*muw*(3*lamdaw + 2*muw) + kh*(-2*kw*xh*lamdah*muw*(3*lamdaw + 2*muw) + ...
    mh*(2*kw*xw*muh*(3*lamdah + 2*muh)*(lamdaw + muw) + xh*(lamdah*(4*kw*muw^2 + 3*lamdaw*(muh + kw*muh + 2*kw*muw)) + ...
    2*muh*(4*kw*muw^2 + lamdaw*(muh + kw*muh + 6*kw*muw)))))))/(-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + ...
    kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - 2*(muw + ...
    kw*mw*muw)) + mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + 2*xh*(lamdah + ...
    2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-109)
K7ivo2=(2*mw*muw*(-2*xh*((-1 + kh)*lamdah - muh)*muw*(3*lamdaw + 2*muw) + mh*(2*kh*xw*muh*(3*lamdah + 2*muh)*(lamdaw + ...
    muw) + xh*(lamdah*(4*(-1 + kh)*muw^2 + 3*lamdaw*(muh + kw*muh - 2*muw + 2*kh*muw)) + 2*muh*(4*kh*muw^2 + ...
    lamdaw*(muh + kw*muh + 6*kh*muw))))))/ (-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + ...
    2*(muw + kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - 2*(muw + kw*mw*muw)) + ...
    mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + 2*xh*(lamdah + ...
    2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-110)
K8ivo2=(2*mw*muw*(-2*kw*xh*((-1 + mh)*lamdah - muh)*muw*(3*lamdaw + 2*muw) + kh*(-2*kw*xh*lamdah*muw*(3*lamdaw + ...
    2*muw) + mh*(2*kw*xw*muh*(3*lamdah + 2*muh)*(lamdaw + muw) + xh*(lamdah*(4*kw*muw^2 + 3*lamdaw*(muh + kw*muh + ...
    2*kw*muw)) + 2*muh*(4*kw*muw^2 + lamdaw*(muh + kw*muh + 6*kw*muw)))))))/(-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - ...
    mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - ...
    2*(muw + kw*mw*muw)) + mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + ...
    2*xh*(lamdah + 2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-111)

B1ivo2=(2*mh*muh*(3*lamdah + 2*muh)*muw*(kh*(1 + mw)*xw*lamdaw + xh*((2 - kw - mw + 2*kw*mw)*lamdaw + ...
    2*(muw + kw*mw*muw))))/ (-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + ...
    2*(muw + kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - 2*(muw + kw*mw*muw)) + ...
    mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + 2*xh*(lamdah + ...
    2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-102)
B2ivo2=(2*kh*mh*muh*(3*lamdah + 2*muh)*muw*(kw*(1 + mw)*xw*lamdaw + xh*((2 - kw - mw + 2*kw*mw)*lamdaw + ...
    2*(muw + kw*mw*muw))))/ (-2*xh*((-1 + mh)*lamdah - muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + ...
    kw*mw*muw)) + kh*(2*xh*lamdah*muw*((-2 + kw + mw - 2*kw*mw)*lamdaw - 2*(muw + kw*mw*muw)) + ...
    mh*(xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + 2*(muw + kw*mw*muw)) + 2*xh*(lamdah + ...
    2*muh)*muw*((2 - mw + kw*(-1 + 2*mw))*lamdaw + 2*(muw + kw*mw*muw))))); % Eq. (A-103)


% Constants for the case ivo3 (hard and weak layers: out-of-plane failure
% (in triaxial extension))

A1ivo3=((kw*xh + kh*xw)*(mw*xh + mh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + ...
    mh)*lamdah - muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + ...
    mh*(kw*mw*xh*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + ...
    mw)*lamdaw + muw + 2*kw*mw*muw)))); % Eq. (A-113)
A2ivo3=-((kh*kw*(xh + xw)*(mw*xh + mh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + ...
    mh)*lamdah - muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + ...
    mh*(kw*mw*xh*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + ...
    mw)*lamdaw + muw + 2*kw*mw*muw))))); % Eq. (A-114)
A3ivo3=(mh*mw*(xh + xw)*(kw*xh + kh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + ...
    mh)*lamdah - muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + ...
    mh*(kw*mw*xh*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + ...
    mw)*lamdaw + muw + 2*kw*mw*muw)))); % Eq. (A-115)
A4ivo3=-((kh*kw*mh*mw*(xh + xw)^2*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(kw*mw*xh*(lamdah + ...
    2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw))))); % Eq. (A-116)

K1ivo3=(mw*(kw*xh + kh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(kw*mw*xh*(lamdah + ...
    2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)))); % Eq. (A-119)
K2ivo3=(kh*kw*mw*(xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(kw*mw*xh*(lamdah + ...
    2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)))); % Eq. (A-120)
K3ivo3=(mh*mw*(kw*xh + kh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(kw*mw*xh*(lamdah + ...
    2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)))); % Eq. (A-121)
K4ivo3= (kh*kw*mh*mw*(xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(kw*mw*xh*(lamdah + ...
    2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)))); % Eq. (A-122)
K5ivo3=(mh*(kw*xh + kh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(kw*mw*xh*(lamdah + ...
    2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)))); % Eq. (A-123)
K6ivo3=(kh*kw*mh*(xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(kw*mw*xh*(lamdah + ...
    2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw))));% Eq. (A-124)
K7ivo3=(mh*mw*(kw*xh + kh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/(-(kw*mw*xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(kw*mw*xh*(lamdah + ...
    2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)))); % Eq. (A-125)
K8ivo3=(kh*kw*mh*mw*(xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(kw*mw*xh*(lamdah + ...
    2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)))); % Eq. (A-126)

B1ivo3=(mh*mw*(kw*xh + kh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(kw*mw*xh*(lamdah + ...
    2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)))); % Eq. (A-117)
B2ivo3=(kh*kw*mh*mw*(xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(kw*mw*xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(kw*mw*xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(kw*mw*xh*(lamdah + ...
    2*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)))); % Eq. (A-118)

% Constants for the case ivo4 (hard layers: out-of-plane failure (triaxial extension),
% weak layers: out-of-plane failure (triaxial compression))

A1ivo4=((xh + kh*xw)*(xh + mh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + ...
    2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-128)
A2ivo4=-((kh*(xh + kw*xw)*(xh + mh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + ...
    2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw))))); % Eq. (A-129)
A3ivo4=(mh*(xh + kh*xw)*(xh + mw*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + ...
    2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-130)
A4ivo4=-((kh*mh*(xh + kw*xw)*(xh + mw*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + ...
    2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw))))); % Eq. (A-131)

K1ivo4=((xh + kh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - muh)*muw*(3*lamdaw + ...
    2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + ...
    xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-134)
K2ivo4=(kh*(xh + kw*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - muh)*muw*(3*lamdaw + ...
    2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + ...
    xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-135)
K3ivo4=(mh*(xh + kh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + ...
    2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-136)
K4ivo4=(kh*mh*(xh + kw*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + ...
    2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-137)
K5ivo4=(mh*(xh + kh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - muh)*muw*(3*lamdaw + ...
    2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + ...
    xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-138)
K6ivo4=(kh*mh*(xh + kw*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + ...
    2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-139)
K7ivo4=(mh*mw*(xh + kh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + ...
    2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-140)
K8ivo4=(kh*mh*mw*(xh + kw*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + ...
    2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-141)

B1ivo4=(mh*(xh + kh*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - muh)*muw*(3*lamdaw + ...
    2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + 2*muw) + ...
    xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-132)
B2ivo4=(kh*mh*(xh + kw*xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (-(xh*((-1 + mh)*lamdah - ...
    muh)*muw*(3*lamdaw + 2*muw)) + kh*(-(xh*lamdah*muw*(3*lamdaw + 2*muw)) + mh*(xh*(lamdah + 2*muh)*muw*(3*lamdaw + ...
    2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + (2 + kw*mw)*muw)))); % Eq. (A-133)


% Constants for the case ivo5 (hard layers: out-of-plane failure (triaxial compression),
% weak layers: out-of-plane failure (triaxial extension))

A1ivo5=((kw*xh + xw)*(mw*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + ...
    mh)*lamdah + (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + ...
    muw + 2*kw*mw*muw)); % Eq. (A-143)
A2ivo5=-((kw*(kh*xh + xw)*(mw*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + ...
    mh)*lamdah + (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + ...
    muw + 2*kw*mw*muw))); % Eq. (A-144)
A3ivo5=(mw*(kw*xh + xw)*(mh*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + ...
    mh)*lamdah + (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + ...
    muw + 2*kw*mw*muw)); % Eq. (A-145)
A4ivo5=-((kw*mw*(kh*xh + xw)*(mh*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + ...
    mh)*lamdah + (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + ...
    muw + 2*kw*mw*muw))); % Eq. (A-146)

K1ivo5=(mw*(kw*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-149)
K2ivo5=(kw*mw*(kh*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-150)
K3ivo5=(mh*mw*(kw*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-151)
K4ivo5=(kw*mh*mw*(kh*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-152)
K5ivo5=((kw*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-153)
K6ivo5=(kw*(kh*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-154)
K7ivo5=(mw*(kw*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-155)
K8ivo5=(kw*mw*(kh*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-156)

B1ivo5=(mw*(kw*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-147)
B2ivo5=(kw*mw*(kh*xh + xw)*muh*(3*lamdah + 2*muh)*muw*(3*lamdaw + 2*muw))/ (kw*mw*xh*((-1 + kh)*(-1 + mh)*lamdah + ...
    (2 + kh*mh)*muh)*muw*(3*lamdaw + 2*muw) + xw*muh*(3*lamdah + 2*muh)*((-1 + kw)*(-1 + mw)*lamdaw + muw + 2*kw*mw*muw)); % Eq. (A-148)


%% Calculation of boundary conditions for r=Rho1 (cf. Appendix C) for Case A

sigmarRho1A=(muStar*sigma0 - mw*muStar*sigma0 + muw*sigma0 + mw*muw*sigma0 - ...
    muStar*sigmadw)/((1 + mw)*muw); % Eq. (24)
sigmatRho1A=2*sigma0-sigmarRho1A; % Eq. (5.46)
sigmarwRho1A=sigma0-muw/muStar*(sigma0-sigmarRho1A); % Eq. (5.48)
sigmatwRho1A=sigma0+muw/muStar*(sigma0-sigmarRho1A); % Eq. (5.49)
sigmarhRho1A=sigma0-muh/muStar*(sigma0-sigmarRho1A); % Eq. (5.50)
sigmathRho1A=sigma0+muh/muStar*(sigma0-sigmarRho1A); % Eq. (5.51)
epsilonrRho1A=-1/(2*muStar)*(sigma0-sigmarRho1A); % Eq. (5.52)
epsilontRho1A=1/(2*muStar)*(sigma0-sigmarRho1A); % Eq. (5.53)
sigmazRho1A=B1i*epsilonrRho1A+B2i*epsilontRho1A+sigma0; % Eq. (A-87)

%% Calculation of boundary conditions for r=Rho1 (cf. Appendix C) for Case B

sigmarRho1B=(muStar*sigma0 - mhH*muStar*sigma0 + muh*sigma0 + mhH*muh*sigma0 - ...
    muStar*sigmadhH)/((1 + mhH)*muh); % Eq. (25)
sigmarwRho1B=sigma0-muw/muStar*(sigma0-sigmarRho1B); % Eq. (5.46)
sigmatwRho1B=sigma0+muw/muStar*(sigma0-sigmarRho1B); % Eq. (5.49)
sigmarhRho1B=sigma0-muh/muStar*(sigma0-sigmarRho1B); % Eq. (5.50)
epsilonrRho1B=-1/(2*muStar)*(sigma0-sigmarRho1B); % Eq. (5.52)
epsilontRho1B=1/(2*muStar)*(sigma0-sigmarRho1B); % Eq. (5.53)
sigmazRho1B=B1i*epsilonrRho1B+B2i*epsilontRho1B+sigma0; % Eq. (A-87)

%considering a brittle behaviour of the hard layers:
sigmathRho1B=mh*sigmarhRho1B+sigmadh; % Eq. (5.83)
sigmatRho1B=xh*sigmathRho1B+xw*sigmatwRho1B; % Eq. (5.84)

%% Calculation of boundary conditions for r=Rho2 (cf. Appendix C) for Case A

% Required constants:
A1 =A1ii;
A2 =A2ii;
A3 =A3ii;
A4 =A4ii;
A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
K1=K1ii;
K2=K2ii;
K3=K3ii;
K4=K4ii;
K5=K5ii;
K6=K6ii;
K7=K7ii;
K8=K8ii;
sigmarRho=sigmarRho1A;
sigmatRho=sigmatRho1A;
sigmarwRho=sigmarwRho1A;
sigmatwRho=sigmatwRho1A;
sigmarhRho=sigmarhRho1A;
sigmathRho=sigmathRho1A;
epsilonrRho=epsilonrRho1A;
epsilontRho=epsilontRho1A;
B1=B1ii;
B2=B2ii;
sigmazRho=sigmazRho1A;

reset(symengine)
clear Rho
syms Rho
% Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
    A3)/(2*A1)));

% epsilonr(r=a) and epsilont(r=a) with Eqs. (5.57) and (5.58) in function of Rho=Rho1:
epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + ...
    A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;

% sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
% in function of Rho = Rho1:
sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);

% Solving Eq. (5.80), in order to obtain Rho=Rho1:
eqn=sigmatha==mhH*sigmarha+sigmadhH;
SolRho = vpasolve(eqn,Rho,a);
[sz1,sz2]=size(SolRho);
Rho=double(SolRho(sz1));

% Calculating all factors again with Rho=Rho1:
C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
    A3)/(2*A1)));
epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
    A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
    A3)/(2*A1))*C2)/(2*A1);
epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;

% Calculating the boundary conditions with Rho=Rho1 (Eqs. (5.57) to (5.71)):
sigmarRho2A=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
    (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
sigmarhRho2A=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
sigmarwRho2A=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
sigmatwRho2A=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
epsilonrRho2A=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + ...
    A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
epsilontRho2A=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
sigmazRho2A=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);

%considering a brittle behaviour of the hard layers:
sigmathRho2A=mh*sigmarhRho2A+sigmadh; % Eq. (5.85)
sigmatRho2A=xh*sigmathRho2A+xw*sigmatwRho2A; % Eq. (5.86)

% Verification that sigmarRho2A < sigmarRho1A:
if sigmarRho2A > sigmarRho1A
    sigmarRho2A=0;
else
    sigmarRho2A=sigmarRho2A;
end


%% Calculation of boundary conditions for r=Rho2 (cf. Appendix C) for Case B

% Required constants:
A1 =A1iii;
A2 =A2iii;
A3 =A3iii;
A4 =A4iii;
A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
K1=K1iii;
K2=K2iii;
K3=K3iii;
K4=K4iii;
K5=K5iii;
K6=K6iii;
K7=K7iii;
K8=K8iii;
sigmarRho=sigmarRho1B;
sigmatRho=sigmatRho1B;
sigmarwRho=sigmarwRho1B;
sigmatwRho=sigmatwRho1B;
sigmarhRho=sigmarhRho1B;
sigmathRho=sigmathRho1B;
epsilonrRho=epsilonrRho1B;
epsilontRho=epsilontRho1B;
B1=B1iii;
B2=B2iii;
sigmazRho=sigmazRho1B;

reset(symengine)
clear Rho
syms Rho
% Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
    A3)/(2*A1)));

% epsilonr(r=a) and epsilont(r=a) with Eqs. (5.57) and (5.58) in function of Rho=Rho1:
epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
    ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;

% sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
% in function of Rho = Rho1:
sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);

% Solving Eq. (5.73), in order to obtain Rho=Rho1:
eqn=sigmatwa==mw*sigmarwa+sigmadw;
SolRho = vpasolve(eqn,Rho,a);
[sz1,sz2]=size(SolRho);
Rho=double(SolRho(sz1));

% Calculating all factors again with Rho=Rho1:
C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
    A3)/(2*A1)));
epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
    ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;

% Calculating the boundary conditions with Rho=Rho1 (Eqs. (5.57) to (5.71)):
sigmarRho2B=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
    (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
sigmatRho2B=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(-(A*A3*(C1 - a^(A/A1)*C2)) + ...
    (A2*A3 + A3^2 - 2*A1*A4)*(C1 + a^(A/A1)*C2)))/(2*A1);
sigmarhRho2B=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
sigmathRho2B=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
sigmarwRho2B=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
sigmatwRho2B=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
epsilonrRho2B=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
    ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
epsilontRho2B=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
sigmazRho2B=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);

% Verification that sigmarRho2B < sigmarRho1B:
if sigmarRho2B > sigmarRho1B
    sigmarRho2B=0;
else
    sigmarRho2B=sigmarRho2B;
end

%% Calculation of boundary conditions for r=Rho1o for Case A

% Required constants:
A1 =A1ii;
A2 =A2ii;
A3 =A3ii;
A4 =A4ii;
A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
K1=K1ii;
K2=K2ii;
K3=K3ii;
K4=K4ii;
K5=K5ii;
K6=K6ii;
K7=K7ii;
K8=K8ii;
sigmarRho=sigmarRho1A;
sigmatRho=sigmatRho1A;
sigmarwRho=sigmarwRho1A;
sigmatwRho=sigmatwRho1A;
sigmarhRho=sigmarhRho1A;
sigmathRho=sigmathRho1A;
epsilonrRho=epsilonrRho1A;
epsilontRho=epsilontRho1A;
B1=B1ii;
B2=B2ii;
sigmazRho=sigmazRho1A;

reset(symengine)
clear Rho
syms Rho
% Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
    A3)/(2*A1)));

% epsilonr(r=a) and epsilont(r=a) with Eqs. (5.576) and (5.58) in function of Rho=Rho1:
epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + ...
    A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;

% sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
% in function of Rho = Rho1:
sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
sigmaza=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);

% Solving Eq. (sigmatw(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho1:
eqn=sigmatwa==sigmaza;
SolRho = vpasolve(eqn,Rho,a);

if isempty(SolRho)
    
    sigmarRho1oA=0;
    
else
    
    [sz1,sz2]=size(SolRho);
    Rho=double(SolRho(sz1));
    
    % Calculating all factors again with Rho=Rho1:
    C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
        2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
        epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
        4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
    C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
        A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
        sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
        A3)/(2*A1)));
    epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
        A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
        A3)/(2*A1))*C2)/(2*A1);
    epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
        sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
    
    % Calculating the boundary conditions with Rho=Rho1 (Eqs. (5.57) to (5.71)):
    sigmarRho1oA=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
        A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
        (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
    sigmatRho1oA=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
        A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(-(A*A3*(C1 - a^(A/A1)*C2)) + ...
        (A2*A3 + A3^2 - 2*A1*A4)*(C1 + a^(A/A1)*C2)))/(2*A1);
    sigmarhRho1oA=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
    sigmathRho1oA=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
    sigmarwRho1oA=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
    sigmatwRho1oA=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
    epsilonrRho1oA=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
        sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
        ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
    epsilontRho1oA=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
        sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
    sigmazRho1oA=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
    
end

% Verification that sigmarRho1oA < sigmarRho1A:
if sigmarRho1oA > sigmarRho1A
    sigmarRho1oA=0;
else
    sigmarRho1oA=sigmarRho1oA;
end

%% Calculation of boundary conditions for r=Rho1o for Case B

% Required constants:
A1 =A1iii;
A2 =A2iii;
A3 =A3iii;
A4 =A4iii;
A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
K1=K1iii;
K2=K2iii;
K3=K3iii;
K4=K4iii;
K5=K5iii;
K6=K6iii;
K7=K7iii;
K8=K8iii;
sigmarRho=sigmarRho1B;
sigmatRho=sigmatRho1B;
sigmarwRho=sigmarwRho1B;
sigmatwRho=sigmatwRho1B;
sigmarhRho=sigmarhRho1B;
sigmathRho=sigmathRho1B;
epsilonrRho=epsilonrRho1B;
epsilontRho=epsilontRho1B;
B1=B1iii;
B2=B2iii;
sigmazRho=sigmazRho1B;

reset(symengine)
clear Rho
syms Rho
% Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
    A3)/(2*A1)));

% epsilonr(r=a) and epsilont(r=a) with Eqs. (5.57) and (5.58) in function of Rho=Rho1:
epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
    ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;

% sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
% in function of Rho = Rho1:
sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
sigmaza=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);

% Solving Eq. (sigmath(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho1:
eqn=sigmatha==sigmaza;
SolRho = vpasolve(eqn,Rho,a);

if isempty(SolRho)
    
    sigmarRho1oB=0;
    
else
    
    [sz1,sz2]=size(SolRho);
    Rho=double(SolRho(sz1));
    if isreal(Rho)
        Rho=Rho;
        
        % Calculating all factors again with Rho=Rho1:
        C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
            2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
            epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
            4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
        C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
            A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
            sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
            A3)/(2*A1)));
        epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
            sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
            ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
        epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
            sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
        
        % Calculating the boundary conditions with Rho=Rho1 (Eqs. (5.57) to (5.71)):
        sigmarRho1oB=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
            A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
            (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
        sigmatRho1oB=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
            A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(-(A*A3*(C1 - a^(A/A1)*C2)) + ...
            (A2*A3 + A3^2 - 2*A1*A4)*(C1 + a^(A/A1)*C2)))/(2*A1);
        sigmarhRho1oB=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
        sigmathRho1oB=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
        sigmarwRho1oB=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
        sigmatwRho1oB=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
        epsilonrRho1oB=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
            sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
            ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
        epsilontRho1oB=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
            sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
        sigmazRho1oB=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
        
    else
        sigmarRho1oB=0;
    end
end

% Verification that sigmarRho1oB < sigmarRho1B:
if sigmarRho1oB > sigmarRho1B
    sigmarRho1oB=0;
else
    sigmarRho1oB=sigmarRho1oB;
end


if sigmarRho1A > sigmarRho1B
    %% Case A:
    
    if (sigmarRho2A > sigmarRho1oA)
        %% Case A(I):
        
        %% GRC for the purely elastic case (Section 2.3 and Appendix B)
        if (sigmaa >= sigmarRho1A)
            Rho1=a
            Rho2=a
            ua = 1/(2*muStar)*(sigma0-sigmaa)*a
            fprintf("Case A: purely elastic case")
            
            % stress, strain and displacement field (Eqs. 5.24 to 5.33):
            rel=a:0.01:50;
            uel=1/(2*muStar)*(sigma0-sigmaa)*a^2./rel;
            sigmarel=sigma0-(sigma0-sigmaa)*(a./rel).^2;
            sigmatel=sigma0+(sigma0-sigmaa)*(a./rel).^2;
            epsilonrel=(a^2*(sigmaa-sigma0))./(2.*rel.^2*muStar);
            epsilontel=(a^2*(sigma0-sigmaa))./(2.*rel.^2*muStar);
            sigmarwel=sigma0-a^2./rel.^2*muw/muStar*(sigma0-sigmaa);
            sigmatwel=sigma0+a^2./rel.^2*muw/muStar*(sigma0-sigmaa);
            sigmarhel=sigma0-a^2./rel.^2*muh/muStar*(sigma0-sigmaa);
            sigmathel=sigma0+a^2./rel.^2*muh/muStar*(sigma0-sigmaa);
            sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
            
            % Plot stress, strain and displacement field:
            figure
            set(figure,'units','normalized','outerposition',[0 0 1 1]);
            subplot(2,3,1)
            plot(rel,uel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('u [m]');
            
            subplot(2,3,2)
            plot(rel,epsilonrel);
            hold on
            plot(rel,epsilontel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\epsilon [-]');
            
            subplot(2,3,3)
            plot(rel,sigmarel);
            axis([a inf -inf inf])
            hold on
            plot(rel,sigmatel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigma [MPa]');
            
            subplot(2,3,4)
            plot(rel,sigmarhel);
            hold on
            plot(rel,sigmathel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmah [MPa]');
            
            subplot(2,3,5)
            plot(rel,sigmarwel);
            hold on
            plot(rel,sigmatwel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmaw [MPa]');
            
        elseif (sigmaa < sigmarRho1A) && (sigmaa >= sigmarRho2A)
            %% GRC for the elasto-plastic behaviour of the weak layers (no out-of-plane failure)
            %%% Plastic zone (a < r < Rho1)
            % Required constants:
            A1 =A1ii;
            A2 =A2ii;
            A3 =A3ii;
            A4 =A4ii;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1ii;
            K2=K2ii;
            K3=K3ii;
            K4=K4ii;
            K5=K5ii;
            K6=K6ii;
            K7=K7ii;
            K8=K8ii;
            sigmarRho=sigmarRho1A;
            sigmatRho=sigmatRho1A;
            sigmarwRho=sigmarwRho1A;
            sigmatwRho=sigmatwRho1A;
            sigmarhRho=sigmarhRho1A;
            sigmathRho=sigmathRho1A;
            epsilonrRho=epsilonrRho1A;
            epsilontRho=epsilontRho1A;
            B1=B1ii;
            B2=B2ii;
            sigmazRho=sigmazRho1A;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
            
            % sigmar(r=a) with Eq. (5.59):
            sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
            
            % Solving Eq. (5.66), in order to obtain Rho=Rho1:
            eqn=sigmara==sigmaa;
            SolRho = vpasolve(eqn,Rho,a);
            [sz1,sz2]=size(SolRho);
            Rho=double(SolRho(sz1));
            Rho1=Rho
            Rho2=a
            
            % Calculating all factors again with Rho=Rho1:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
            
            % ua with C[1] and C[2] (Eq. 5.56):
            ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
            fprintf("Case A (I): weak layers reach failure (no out-of-plane failure)")
            
            % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho1:
            rpl=a:0.01:Rho;
            upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
            epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
            epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                A3)/(2.*A1))*C2)./rpl;
            sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
            sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
            
            sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
            sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
            sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
            sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
            sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
            
            %%% Elastic zone (r > Rho1)
            
            % stress, strain and displacement field (Eqs. 5.24 to 5.33):
            rel=Rho:0.01:(Rho+40);
            uel=1/(2*muStar)*(sigma0-sigmarRho1A)*Rho^2./rel;
            sigmarel=sigma0-(sigma0-sigmarRho1A)*(Rho./rel).^2;
            sigmatel=sigma0+(sigma0-sigmarRho1A)*(Rho./rel).^2;
            epsilonrel=(Rho^2*(sigmarRho1A-sigma0))./(2.*rel.^2*muStar);
            epsilontel=(Rho^2*(sigma0-sigmarRho1A))./(2.*rel.^2*muStar);
            sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
            sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
            sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
            sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
            sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
            
            %%% Plot stress, strain and displacement field:
            figure
            set(figure,'units','normalized','outerposition',[0 0 1 1]);
            subplot(2,3,1)
            plot(rel,uel);
            hold on
            plot(rpl,upl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('u [m]');
            
            subplot(2,3,2)
            plot(rel,epsilonrel);
            hold on
            plot(rel,epsilontel);
            hold on
            plot(rpl,epsilonrpl);
            hold on
            plot(rpl,epsilontpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\epsilon [-]');
            
            subplot(2,3,3)
            plot(rel,sigmarel);
            axis([a inf -inf inf])
            hold on
            plot(rel,sigmatel);
            hold on
            plot(rpl,sigmarpl);
            hold on
            plot(rpl,sigmatpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigma [MPa]');
            
            subplot(2,3,4)
            plot(rel,sigmarhel);
            hold on
            plot(rel,sigmathel);
            hold on
            plot(rpl,sigmarhpl);
            hold on
            plot(rpl,sigmathpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmah [MPa]');
            
            subplot(2,3,5)
            plot(rel,sigmarwel);
            hold on
            plot(rel,sigmatwel);
            hold on
            plot(rpl,sigmarwpl);
            hold on
            plot(rpl,sigmatwpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmaw [MPa]');
            
            %% GRC for the elasto-plastic behaviour of the weak and the hard layers
        elseif (sigmaa < sigmarRho2A)
            
            %% Calculation of boundary conditions for r=Rho1o
            % Required constants:
            A1 =A1iv;
            A2 =A2iv;
            A3 =A3iv;
            A4 =A4iv;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1iv;
            K2=K2iv;
            K3=K3iv;
            K4=K4iv;
            K5=K5iv;
            K6=K6iv;
            K7=K7iv;
            K8=K8iv;
            sigmarRho=sigmarRho2A;
            sigmatRho=sigmatRho2A;
            sigmarwRho=sigmarwRho2A;
            sigmatwRho=sigmatwRho2A;
            sigmarhRho=sigmarhRho2A;
            sigmathRho=sigmathRho2A;
            epsilonrRho=epsilonrRho2A;
            epsilontRho=epsilontRho2A;
            B1=B1iv;
            B2=B2iv;
            sigmazRho=sigmazRho2A;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                A3)/(2*A1)));
            
            % epsilonr(r=a) and epsilont(r=a) with Eqs. (5.57) and (5.58) in function of Rho=Rho2:
            epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + ...
                A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
            epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            
            % sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
            % in function of Rho = Rho2:
            sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
            sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
            sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
            sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
            sigmaza=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
            
            % Solving Eq. (sigmatw(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho2 (Case A(I),(b) in Fig. 14):
            eqn=sigmatwa==sigmaza;
            SolRho = vpasolve(eqn,Rho,a);
            if isempty(SolRho)
                Rho1o=inf;
            else
                [sz1,sz2]=size(SolRho);
                Rho1o=double(SolRho(sz1));
                if isreal(Rho1o)
                    Rho1o=Rho1o;
                else
                    Rho1o=inf;
                end
            end
            
            % Solving Eq. (sigmath(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho2 (Case A(I),(a) in Fig. 14):
            clear Rho
            syms Rho
            eqn=sigmatha==sigmaza;
            SolRho = vpasolve(eqn,Rho,a);
            if isempty(SolRho)
                Rho2o=inf;
            else
                [sz1,sz2]=size(SolRho);
                Rho2o=double(SolRho(sz1));
                if isreal(Rho2o)
                    Rho2o=Rho2o;
                else
                    Rho2o=inf;
                end
            end
            
            % Case A(I),(b)
            if Rho1o < Rho2o
                Rho=Rho1o; % i.e. weak layers reach first out-of-plane failure
                A1ivo =A1ivo1;
                A2ivo =A2ivo1;
                A3ivo =A3ivo1;
                A4ivo =A4ivo1;
                K1ivo=K1ivo1;
                K2ivo=K2ivo1;
                K3ivo=K3ivo1;
                K4ivo=K4ivo1;
                K5ivo=K5ivo1;
                K6ivo=K6ivo1;
                K7ivo=K7ivo1;
                K8ivo=K8ivo1;
                B1ivo=B1ivo1;
                B2ivo=B2ivo1;
                % Case A(I),(a)
            else
                Rho=Rho2o; % i.e. hard layers reach first out-of-plane failure
                A1ivo =A1ivo2;
                A2ivo =A2ivo2;
                A3ivo =A3ivo2;
                A4ivo =A4ivo2;
                K1ivo=K1ivo2;
                K2ivo=K2ivo2;
                K3ivo=K3ivo2;
                K4ivo=K4ivo2;
                K5ivo=K5ivo2;
                K6ivo=K6ivo2;
                K7ivo=K7ivo2;
                K8ivo=K8ivo2;
                B1ivo=B1ivo2;
                B2ivo=B2ivo2;
            end
            
            if isinf(Rho)
                sigmarRho1oB = 0;
            else
                
                % Calculating all factors again with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                    A3)/(2*A1)));
                epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                    A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                    A3)/(2*A1))*C2)/(2*A1);
                epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                
                % Calculating the boundary conditions with Rho=Rho2 (Eqs. (5.57) to (5.71)):
                sigmarRho1oA=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                    (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                sigmatRho1oA=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(-(A*A3*(C1 - a^(A/A1)*C2)) + ...
                    (A2*A3 + A3^2 - 2*A1*A4)*(C1 + a^(A/A1)*C2)))/(2*A1);
                sigmarhRho1oA=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
                sigmathRho1oA=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
                sigmarwRho1oA=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
                sigmatwRho1oA=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
                epsilonrRho1oA=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
                    ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
                epsilontRho1oA=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                sigmazRho1oA=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
                
            end
            
            % Verification that sigmarRho1oA < sigmarRho2A
            if sigmarRho1oA > sigmarRho2A
                sigmarRho1oA=0;
            else
                sigmarRho1oA=sigmarRho1oA;
            end
            
            %% Calculation of boundary conditions for r=Rho2o
            % Required constants:
            A1 =A1ivo;
            A2 =A2ivo;
            A3 =A3ivo;
            A4 =A4ivo;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1ivo;
            K2=K2ivo;
            K3=K3ivo;
            K4=K4ivo;
            K5=K5ivo;
            K6=K6ivo;
            K7=K7ivo;
            K8=K8ivo;
            sigmarRho=sigmarRho1oA;
            sigmatRho=sigmatRho1oA;
            sigmarwRho=sigmarwRho1oA;
            sigmatwRho=sigmatwRho1oA;
            sigmarhRho=sigmarhRho1oA;
            sigmathRho=sigmathRho1oA;
            epsilonrRho=epsilonrRho1oA;
            epsilontRho=epsilontRho1oA;
            B1=B1ivo;
            B2=B2ivo;
            sigmazRho=sigmazRho1oA;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                A3)/(2*A1)));
            
            % epsilonr(r=a) and epsilont(r=a) with Eqs. (5.57) and (5.58) in function of Rho=Rho1o:
            epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + ...
                A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
            epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            
            % sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
            % in function of Rho = Rho1o:
            sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
            sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
            sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
            sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
            sigmaza=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
            
            % Solving Eq. (sigmath(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho1o (for Case A(I),(b)):
            if Rho1o < Rho2o
                eqn=sigmatha==sigmaza;
                SolRho = vpasolve(eqn,Rho,a);
                sigmarRho2oA3=0;
                if isempty(SolRho)
                    Rho3o=inf;
                else
                    [sz1,sz2]=size(SolRho);
                    Rho3o=double(SolRho(sz1));
                    if isreal(Rho3o)
                        Rho3o=Rho3o;
                        
                        Rho = Rho3o;
                        
                        % Calculating all factors again with Rho=Rho1o:
                        C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                            2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                            epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                            4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                        C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                            A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                            sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                            A3)/(2*A1)));
                        epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                            A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                            A3)/(2*A1))*C2)/(2*A1);
                        epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                            sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                        
                        % Calculating sigmar,Rho2o with Rho=Rho1o (Eq. A-98):
                        sigmarRho2oA3=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                            A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                            (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                        
                    else
                        Rho3o=inf;
                    end
                end
                
                % Solving Eq. (sigmarh(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho1o (for Case A(I),(b)):
                clear Rho
                syms Rho
                eqn=sigmarha==sigmaza;
                SolRho = vpasolve(eqn,Rho,a);
                sigmarRho2oA4=0;
                if isempty(SolRho)
                    Rho4o=inf;
                else
                    [sz1,sz2]=size(SolRho);
                    Rho4o=double(SolRho(sz1));
                    if isreal(Rho4o)
                        Rho4o=Rho4o;
                        
                        Rho = Rho4o;
                        
                        % Calculating all factors again with Rho=Rho1o:
                        C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                            2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                            epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                            4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                        C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                            A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                            sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                            A3)/(2*A1)));
                        epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                            A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                            A3)/(2*A1))*C2)/(2*A1);
                        epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                            sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                        
                        % Calculating sigmar,Rho2o with Rho=Rho1o (Eq. A-98):
                        sigmarRho2oA4=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                            A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                            (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                        
                    else
                        Rho4o=inf;
                    end
                end
                
                % Verification that sigmarRho2oA < sigmarRho1oA:
                if sigmarRho2oA3 > sigmarRho1oA
                    sigmarRho2oA3=0;
                    Rho3o=inf;
                else
                    sigmarRho2oA3=sigmarRho2oA3;
                end
                
                % Verification that sigmarRho2oA < sigmarRho1oA:
                if sigmarRho2oA4 > sigmarRho1oA
                    sigmarRho2oA4=0;
                    Rho4o=inf;
                else
                    sigmarRho2oA4=sigmarRho2oA4;
                end
                
                % Out-of-plane failure of the hard layers in triaxial
                % extension:
                if sigmarRho2oA3 > sigmarRho2oA4
                    Rho=Rho3o; % i.e. both layers out-of-plane failure (sigmat=sigmaz)
                    A1iv2o =A1ivo3;
                    A2iv2o =A2ivo3;
                    A3iv2o =A3ivo3;
                    A4iv2o =A4ivo3;
                    K1iv2o=K1ivo3;
                    K2iv2o=K2ivo3;
                    K3iv2o=K3ivo3;
                    K4iv2o=K4ivo3;
                    K5iv2o=K5ivo3;
                    K6iv2o=K6ivo3;
                    K7iv2o=K7ivo3;
                    K8iv2o=K8ivo3;
                    B1iv2o=B1ivo3;
                    B2iv2o=B2ivo3;
                else
                    % Out-of-plane failure of the hard layers in triaxial
                    % compression:
                    Rho=Rho4o;
                    A1iv2o =A1ivo5;
                    A2iv2o =A2ivo5;
                    A3iv2o =A3ivo5;
                    A4iv2o =A4ivo5;
                    K1iv2o=K1ivo5;
                    K2iv2o=K2ivo5;
                    K3iv2o=K3ivo5;
                    K4iv2o=K4ivo5;
                    K5iv2o=K5ivo5;
                    K6iv2o=K6ivo5;
                    K7iv2o=K7ivo5;
                    K8iv2o=K8ivo5;
                    B1iv2o=B1ivo5;
                    B2iv2o=B2ivo5;
                end
                
            else
                % Solving Eq. (sigmatw(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho1o (for Case A(I),(a)):
                eqn=sigmatwa==sigmaza;
                SolRho = vpasolve(eqn,Rho,a);
                sigmarRho2oA3=0;
                if isempty(SolRho)
                    Rho3o=inf;
                else
                    [sz1,sz2]=size(SolRho);
                    Rho3o=double(SolRho(sz1));
                    
                    if isreal(Rho3o)
                        Rho3o=Rho3o;
                        
                        Rho = Rho3o;
                        
                        % Calculating all factors again with Rho=Rho1o:
                        C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                            2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                            epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                            4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                        C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                            A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                            sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                            A3)/(2*A1)));
                        epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                            A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                            A3)/(2*A1))*C2)/(2*A1);
                        epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                            sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                        
                        % Calculating sigmar,Rho2o with Rho=Rho1o (Eq. 5.59):
                        sigmarRho2oA3=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                            A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                            (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                        
                    else
                        Rho3o=inf;
                    end
                end
                
                % Solving Eq. (sigmarw(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho1o (for Case A(I),(a)):
                clear Rho
                syms Rho
                eqn=sigmarwa==sigmaza;
                SolRho = vpasolve(eqn,Rho,a);
                sigmarRho2oA4=0;
                if isempty(SolRho)
                    Rho4o=inf;
                else
                    [sz1,sz2]=size(SolRho);
                    Rho4o=double(SolRho(sz1));
                    
                    if isreal(Rho4o)
                        Rho4o=Rho4o;
                        
                        Rho = Rho4o;
                        
                        % Calculating all factors again with Rho=Rho1o:
                        C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                            2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                            epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                            4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                        C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                            A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                            sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                            A3)/(2*A1)));
                        epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                            A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                            A3)/(2*A1))*C2)/(2*A1);
                        epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                            sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                        
                        % Calculating sigmar,Rho2o with Rho=Rho1o (Eq. 5.59):
                        sigmarRho2oA4=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                            A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                            (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                        
                    else
                        Rho4o=inf;
                    end
                end
                
                % Verification that sigmarRho2oA < sigmarRho1oA:
                if sigmarRho2oA3 > sigmarRho1oA
                    sigmarRho2oA3=0;
                    Rho3o=inf;
                else
                    sigmarRho2oA3=sigmarRho2oA3;
                end
                
                % Verification that sigmarRho2oA < sigmarRho1oA:
                if sigmarRho2oA4 > sigmarRho1oA
                    sigmarRho2oA4=0;
                    Rho4o=inf;
                else
                    sigmarRho2oA4=sigmarRho2oA4;
                end
                
                % Out-of-plane failure of the weak layers in triaxial
                % extension:
                if sigmarRho2oA3 > sigmarRho2oA4
                    Rho=Rho3o; % i.e. both layers out-of-plane failure (sigmat=sigmaz)
                    A1iv2o =A1ivo3;
                    A2iv2o =A2ivo3;
                    A3iv2o =A3ivo3;
                    A4iv2o =A4ivo3;
                    K1iv2o=K1ivo3;
                    K2iv2o=K2ivo3;
                    K3iv2o=K3ivo3;
                    K4iv2o=K4ivo3;
                    K5iv2o=K5ivo3;
                    K6iv2o=K6ivo3;
                    K7iv2o=K7ivo3;
                    K8iv2o=K8ivo3;
                    B1iv2o=B1ivo3;
                    B2iv2o=B2ivo3;
                else
                    % Out-of-plane failure of the weak layers in triaxial
                    % compression:
                    Rho=Rho4o;
                    A1iv2o =A1ivo4;
                    A2iv2o =A2ivo4;
                    A3iv2o =A3ivo4;
                    A4iv2o =A4ivo4;
                    K1iv2o=K1ivo4;
                    K2iv2o=K2ivo4;
                    K3iv2o=K3ivo4;
                    K4iv2o=K4ivo4;
                    K5iv2o=K5ivo4;
                    K6iv2o=K6ivo4;
                    K7iv2o=K7ivo4;
                    K8iv2o=K8ivo4;
                    B1iv2o=B1ivo4;
                    B2iv2o=B2ivo4;
                end
                
            end
            
            if isinf(Rho)
                sigmarRho2oA = 0;
            else
                
                % Calculating all factors again with Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                    A3)/(2*A1)));
                epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                    A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                    A3)/(2*A1))*C2)/(2*A1);
                epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                
                % Calculating the boundary conditions with Rho=Rho1 (Eqs. (5.56) to (5.71)):
                sigmarRho2oA=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                    (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                sigmatRho2oA=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(-(A*A3*(C1 - a^(A/A1)*C2)) + ...
                    (A2*A3 + A3^2 - 2*A1*A4)*(C1 + a^(A/A1)*C2)))/(2*A1);
                sigmarhRho2oA=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
                sigmathRho2oA=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
                sigmarwRho2oA=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
                sigmatwRho2oA=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
                epsilonrRho2oA=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
                    ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
                epsilontRho2oA=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                sigmazRho2oA=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
                
            end
            
            if (sigmaa < sigmarRho2A) && (sigmaa >= sigmarRho1oA)
                %% GRC for the elasto-plastic behaviour of both, the weak and the hard layers (no out-of-plane failure)
                
                %%% Plastic zone (a < r < Rho2)
                % Required constants:
                A1 =A1iv;
                A2 =A2iv;
                A3 =A3iv;
                A4 =A4iv;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iv;
                K2=K2iv;
                K3=K3iv;
                K4=K4iv;
                K5=K5iv;
                K6=K6iv;
                K7=K7iv;
                K8=K8iv;
                sigmarRho=sigmarRho2A;
                sigmatRho=sigmatRho2A;
                sigmarwRho=sigmarwRho2A;
                sigmatwRho=sigmatwRho2A;
                sigmarhRho=sigmarhRho2A;
                sigmathRho=sigmathRho2A;
                epsilonrRho=epsilonrRho2A;
                epsilontRho=epsilontRho2A;
                B1=B1iv;
                B2=B2iv;
                sigmazRho=sigmazRho2A;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.78), in order to obtain Rho=Rho2:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                fprintf("Case A (I): weak and hard layers reach failure (no out-of-plane failure)")
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2:
                rpl2=a:0.01:Rho;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho2 < r < Rho1)
                
                % Required constants:
                A1 =A1ii;
                A2 =A2ii;
                A3 =A3ii;
                A4 =A4ii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ii;
                K2=K2ii;
                K3=K3ii;
                K4=K4ii;
                K5=K5ii;
                K6=K6ii;
                K7=K7ii;
                K8=K8ii;
                sigmarRho=sigmarRho1A;
                sigmatRho=sigmatRho1A;
                sigmarwRho=sigmarwRho1A;
                sigmatwRho=sigmatwRho1A;
                sigmarhRho=sigmarhRho1A;
                sigmathRho=sigmathRho1A;
                epsilonrRho=epsilonrRho1A;
                epsilontRho=epsilontRho1A;
                B1=B1ii;
                B2=B2ii;
                sigmazRho=sigmazRho1A;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2) with Eq. (5.59):
                sigmarRho2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.74), in order to obtain Rho=Rho1:
                eqn=sigmarRho2==sigmarRho2A;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1 :
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho2:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1A)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1A)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1A)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1A-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1A))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
            elseif (sigmaa < sigmarRho1oA) && (sigmaa >= sigmarRho2oA)
                %% GRC for the elasto-plastic behaviour of both, the weak and the hard layers (out-of-plane failure of hard or weak layers)
                %%% Plastic zone (a < r < Rho1o)
                % Required constants:
                A1 =A1ivo;
                A2 =A2ivo;
                A3 =A3ivo;
                A4 =A4ivo;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ivo;
                K2=K2ivo;
                K3=K3ivo;
                K4=K4ivo;
                K5=K5ivo;
                K6=K6ivo;
                K7=K7ivo;
                K8=K8ivo;
                sigmarRho=sigmarRho1oA;
                sigmatRho=sigmatRho1oA;
                sigmarwRho=sigmarwRho1oA;
                sigmatwRho=sigmatwRho1oA;
                sigmarhRho=sigmarhRho1oA;
                sigmathRho=sigmathRho1oA;
                epsilonrRho=epsilonrRho1oA;
                epsilontRho=epsilontRho1oA;
                B1=B1ivo;
                B2=B2ivo;
                sigmazRho=sigmazRho1oA;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                if Rho1o < Rho2o
                    fprintf("Case A (I): weak and hard layers reach failure (weak layers: out-of-plane failure)")
                else
                    fprintf("Case A (I): weak and hard layers reach failure (hard layers: out-of-plane failure)")
                end
                
                % Solving Eq. (5.78), in order to obtain Rho1o:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1o=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1o:
                rpl1o=a:0.01:Rho1o;
                upl1o=(rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl1o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl1o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl1o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl1o=((rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl1o;
                sigmarpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl1o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl1o.^(A/A1)*C2)))/2;
                sigmatpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl1o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl1o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl1o=sigmarhRho+K1*(epsilonrpl1o-epsilonrRho)+K2*(epsilontpl1o-epsilontRho);
                sigmathpl1o=sigmathRho+K3*(epsilonrpl1o-epsilonrRho)+K4*(epsilontpl1o-epsilontRho);
                sigmarwpl1o=sigmarwRho+K5*(epsilonrpl1o-epsilonrRho)+K6*(epsilontpl1o-epsilontRho);
                sigmatwpl1o=sigmatwRho+K7*(epsilonrpl1o-epsilonrRho)+K8*(epsilontpl1o-epsilontRho);
                sigmazpl1o=sigmazRho+B1.*(epsilonrpl1o-epsilonrRho)+B2.*(epsilontpl1o-epsilontRho);
                
                
                %%% Plastic zone (Rho1o < r < Rho2)
                % Required constants:
                A1 =A1iv;
                A2 =A2iv;
                A3 =A3iv;
                A4 =A4iv;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iv;
                K2=K2iv;
                K3=K3iv;
                K4=K4iv;
                K5=K5iv;
                K6=K6iv;
                K7=K7iv;
                K8=K8iv;
                sigmarRho=sigmarRho2A;
                sigmatRho=sigmatRho2A;
                sigmarwRho=sigmarwRho2A;
                sigmatwRho=sigmatwRho2A;
                sigmarhRho=sigmarhRho2A;
                sigmathRho=sigmathRho2A;
                epsilonrRho=epsilonrRho2A;
                epsilontRho=epsilontRho2A;
                B1=B1iv;
                B2=B2iv;
                sigmazRho=sigmazRho2A;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho1o) with Eq. (5.59):
                sigmarRho1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho1o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho1o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho1o^(A/A1)*C2)))/2;
                
                % Solving (sigmar(r=Rho1o)=sigmarRho1o), in order to obtain Rho=Rho2:
                eqn=sigmarRho1o==sigmarRho1oA;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2:
                rpl2=Rho1o:0.01:Rho;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho2 < r < Rho1)
                
                % Required constants:
                A1 =A1ii;
                A2 =A2ii;
                A3 =A3ii;
                A4 =A4ii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ii;
                K2=K2ii;
                K3=K3ii;
                K4=K4ii;
                K5=K5ii;
                K6=K6ii;
                K7=K7ii;
                K8=K8ii;
                sigmarRho=sigmarRho1A;
                sigmatRho=sigmatRho1A;
                sigmarwRho=sigmarwRho1A;
                sigmatwRho=sigmatwRho1A;
                sigmarhRho=sigmarhRho1A;
                sigmathRho=sigmathRho1A;
                epsilonrRho=epsilonrRho1A;
                epsilontRho=epsilontRho1A;
                B1=B1ii;
                B2=B2ii;
                sigmazRho=sigmazRho1A;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2) with Eq. (5.59):
                sigmarRho2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.74), in order to obtain Rho=Rho1:
                eqn=sigmarRho2==sigmarRho2A;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho2:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1A)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1A)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1A)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1A-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1A))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                hold on
                plot(rpl1o,upl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                hold on
                plot(rpl1o,epsilonrpl1o);
                hold on
                plot(rpl1o,epsilontpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarpl1o);
                hold on
                plot(rpl1o,sigmatpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarhpl1o);
                hold on
                plot(rpl1o,sigmathpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarwpl1o);
                hold on
                plot(rpl1o,sigmatwpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
            elseif (sigmaa < sigmarRho2oA)
                %% GRC for the elasto-plastic behaviour of both, the weak and the hard layers (both: out-of-plane failure)
                
                %%% Plastic zone (a < r < Rho2o)
                % Required constants:
                A1 =A1iv2o;
                A2 =A2iv2o;
                A3 =A3iv2o;
                A4 =A4iv2o;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iv2o;
                K2=K2iv2o;
                K3=K3iv2o;
                K4=K4iv2o;
                K5=K5iv2o;
                K6=K6iv2o;
                K7=K7iv2o;
                K8=K8iv2o;
                sigmarRho=sigmarRho2oA;
                sigmatRho=sigmatRho2oA;
                sigmarwRho=sigmarwRho2oA;
                sigmatwRho=sigmatwRho2oA;
                sigmarhRho=sigmarhRho2oA;
                sigmathRho=sigmathRho2oA;
                epsilonrRho=epsilonrRho2oA;
                epsilontRho=epsilontRho2oA;
                B1=B1iv2o;
                B2=B2iv2o;
                sigmazRho=sigmazRho2oA;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.78), in order to obtain Rho=Rho2o:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2o=Rho
                fprintf("Case A (I): weak and hard layers reach failure (both: out-of-plane failure)")
                
                % Calculating again C[1] and C[2] with Rho=Rho2o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2o:
                rpl2o=a:0.01:Rho2o;
                upl2o=(rpl2o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2o=((rpl2o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2o;
                sigmarpl2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2o.^(A/A1)*C2)))/2;
                sigmatpl2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2o=sigmarhRho+K1*(epsilonrpl2o-epsilonrRho)+K2*(epsilontpl2o-epsilontRho);
                sigmathpl2o=sigmathRho+K3*(epsilonrpl2o-epsilonrRho)+K4*(epsilontpl2o-epsilontRho);
                sigmarwpl2o=sigmarwRho+K5*(epsilonrpl2o-epsilonrRho)+K6*(epsilontpl2o-epsilontRho);
                sigmatwpl2o=sigmatwRho+K7*(epsilonrpl2o-epsilonrRho)+K8*(epsilontpl2o-epsilontRho);
                sigmazpl2o=sigmazRho+B1.*(epsilonrpl2o-epsilonrRho)+B2.*(epsilontpl2o-epsilontRho);
                
                
                %%% Plastic zone (Rho2o < r < Rho1o)
                % Required constants:
                A1 =A1ivo;
                A2 =A2ivo;
                A3 =A3ivo;
                A4 =A4ivo;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ivo;
                K2=K2ivo;
                K3=K3ivo;
                K4=K4ivo;
                K5=K5ivo;
                K6=K6ivo;
                K7=K7ivo;
                K8=K8ivo;
                sigmarRho=sigmarRho1oA;
                sigmatRho=sigmatRho1oA;
                sigmarwRho=sigmarwRho1oA;
                sigmatwRho=sigmatwRho1oA;
                sigmarhRho=sigmarhRho1oA;
                sigmathRho=sigmathRho1oA;
                epsilonrRho=epsilonrRho1oA;
                epsilontRho=epsilontRho1oA;
                B1=B1ivo;
                B2=B2ivo;
                sigmazRho=sigmazRho1oA;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2o) with Eqs. (5.59):
                sigmarRho2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2o^(A/A1)*C2)))/2;
                
                % Solving Eq. (sigmar(r=Rho2o)=sigmarRho2o), in order to obtain Rho=Rho1o:
                eqn=sigmarRho2o==sigmarRho2oA;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1o=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1o:
                rpl1o=Rho2o:0.01:Rho1o;
                upl1o=(rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl1o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl1o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl1o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl1o=((rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl1o;
                sigmarpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl1o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl1o.^(A/A1)*C2)))/2;
                sigmatpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl1o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl1o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl1o=sigmarhRho+K1*(epsilonrpl1o-epsilonrRho)+K2*(epsilontpl1o-epsilontRho);
                sigmathpl1o=sigmathRho+K3*(epsilonrpl1o-epsilonrRho)+K4*(epsilontpl1o-epsilontRho);
                sigmarwpl1o=sigmarwRho+K5*(epsilonrpl1o-epsilonrRho)+K6*(epsilontpl1o-epsilontRho);
                sigmatwpl1o=sigmatwRho+K7*(epsilonrpl1o-epsilonrRho)+K8*(epsilontpl1o-epsilontRho);
                sigmazpl1o=sigmazRho+B1.*(epsilonrpl1o-epsilonrRho)+B2.*(epsilontpl1o-epsilontRho);
                
                
                %%% Plastic zone (Rho1o < r < Rho2)
                % Required constants:
                A1 =A1iv;
                A2 =A2iv;
                A3 =A3iv;
                A4 =A4iv;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iv;
                K2=K2iv;
                K3=K3iv;
                K4=K4iv;
                K5=K5iv;
                K6=K6iv;
                K7=K7iv;
                K8=K8iv;
                sigmarRho=sigmarRho2A;
                sigmatRho=sigmatRho2A;
                sigmarwRho=sigmarwRho2A;
                sigmatwRho=sigmatwRho2A;
                sigmarhRho=sigmarhRho2A;
                sigmathRho=sigmathRho2A;
                epsilonrRho=epsilonrRho2A;
                epsilontRho=epsilontRho2A;
                B1=B1iv;
                B2=B2iv;
                sigmazRho=sigmazRho2A;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho1o) with Eq. (5.59):
                sigmarRho1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho1o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho1o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho1o^(A/A1)*C2)))/2;
                
                % Solving Eq. (sigmar(r=Rho1o)=sigmarRho1o), in order to obtain Rho=Rho2:
                eqn=sigmarRho1o==sigmarRho1oA;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2:
                rpl2=Rho1o:0.01:Rho;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho2 < r < Rho1)
                
                % Required constants:
                A1 =A1ii;
                A2 =A2ii;
                A3 =A3ii;
                A4 =A4ii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ii;
                K2=K2ii;
                K3=K3ii;
                K4=K4ii;
                K5=K5ii;
                K6=K6ii;
                K7=K7ii;
                K8=K8ii;
                sigmarRho=sigmarRho1A;
                sigmatRho=sigmatRho1A;
                sigmarwRho=sigmarwRho1A;
                sigmatwRho=sigmatwRho1A;
                sigmarhRho=sigmarhRho1A;
                sigmathRho=sigmathRho1A;
                epsilonrRho=epsilonrRho1A;
                epsilontRho=epsilontRho1A;
                B1=B1ii;
                B2=B2ii;
                sigmazRho=sigmazRho1A;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2) with Eq. (5.59):
                sigmarRho2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.74), in order to obtain Rho=Rho1:
                eqn=sigmarRho2==sigmarRho2A;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho2:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1A)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1A)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1A)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1A-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1A))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                hold on
                plot(rpl1o,upl1o);
                hold on
                plot(rpl2o,upl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                hold on
                plot(rpl1o,epsilonrpl1o);
                hold on
                plot(rpl1o,epsilontpl1o);
                hold on
                plot(rpl2o,epsilonrpl2o);
                hold on
                plot(rpl2o,epsilontpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarpl1o);
                hold on
                plot(rpl1o,sigmatpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarpl2o);
                hold on
                plot(rpl2o,sigmatpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarhpl1o);
                hold on
                plot(rpl1o,sigmathpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarhpl2o);
                hold on
                plot(rpl2o,sigmathpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarwpl1o);
                hold on
                plot(rpl1o,sigmatwpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarwpl2o);
                hold on
                plot(rpl2o,sigmatwpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
            end
        end
        
        %% Case A(II):
    else
        
        %% GRC for the purely elastic case (Section 2.3 and Appendix B)
        if (sigmaa >= sigmarRho1A)
            Rho1=a
            Rho2=a
            ua = 1/(2*muStar)*(sigma0-sigmaa)*a
            fprintf("Case A: purely elastic case")
            
            % stress, strain and displacement field (Eqs. 5.24 to 5.33)
            rel=a:0.01:50;
            uel=1/(2*muStar)*(sigma0-sigmaa)*a^2./rel;
            sigmarel=sigma0-(sigma0-sigmaa)*(a./rel).^2;
            sigmatel=sigma0+(sigma0-sigmaa)*(a./rel).^2;
            epsilonrel=(a^2*(sigmaa-sigma0))./(2.*rel.^2*muStar);
            epsilontel=(a^2*(sigma0-sigmaa))./(2.*rel.^2*muStar);
            sigmarwel=sigma0-a^2./rel.^2*muw/muStar*(sigma0-sigmaa);
            sigmatwel=sigma0+a^2./rel.^2*muw/muStar*(sigma0-sigmaa);
            sigmarhel=sigma0-a^2./rel.^2*muh/muStar*(sigma0-sigmaa);
            sigmathel=sigma0+a^2./rel.^2*muh/muStar*(sigma0-sigmaa);
            sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
            
            % Plot stress, strain and displacement field:
            figure
            set(figure,'units','normalized','outerposition',[0 0 1 1]);
            subplot(2,3,1)
            plot(rel,uel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('u [m]');
            
            subplot(2,3,2)
            plot(rel,epsilonrel);
            hold on
            plot(rel,epsilontel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\epsilon [-]');
            
            subplot(2,3,3)
            plot(rel,sigmarel);
            axis([a inf -inf inf])
            hold on
            plot(rel,sigmatel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigma [MPa]');
            
            subplot(2,3,4)
            plot(rel,sigmarhel);
            hold on
            plot(rel,sigmathel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmah [MPa]');
            
            subplot(2,3,5)
            plot(rel,sigmarwel);
            hold on
            plot(rel,sigmatwel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmaw [MPa]');
            
            %% GRC for the elasto-plastic behaviour of the weak layers (no out-of-plane failure)
        elseif (sigmaa < sigmarRho1A) && (sigmaa >= sigmarRho1oA)
            
            %%% Plastic zone (a < r < Rho1)
            % Required constants:
            A1 =A1ii;
            A2 =A2ii;
            A3 =A3ii;
            A4 =A4ii;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1ii;
            K2=K2ii;
            K3=K3ii;
            K4=K4ii;
            K5=K5ii;
            K6=K6ii;
            K7=K7ii;
            K8=K8ii;
            sigmarRho=sigmarRho1A;
            sigmatRho=sigmatRho1A;
            sigmarwRho=sigmarwRho1A;
            sigmatwRho=sigmatwRho1A;
            sigmarhRho=sigmarhRho1A;
            sigmathRho=sigmathRho1A;
            epsilonrRho=epsilonrRho1A;
            epsilontRho=epsilontRho1A;
            B1=B1ii;
            B2=B2ii;
            sigmazRho=sigmazRho1A;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eq. (5.63) and (5.64) in function of Rho=Rho1:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
            
            % sigmar(r=a) with Eq. (5.59):
            sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
            
            % Solving Eq. (5.66), in order to obtain Rho1:
            eqn=sigmara==sigmaa;
            SolRho = vpasolve(eqn,Rho,a);
            [sz1,sz2]=size(SolRho);
            Rho=double(SolRho(sz1));
            Rho1=Rho
            
            % Calculating again C[1] and C[2] with Rho=Rho1:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
            
            % ua with C[1] and C[2] (Eq. 5.56):
            ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
            fprintf("Case A (II): weak layers reach failure (no out-of-plane failure)")
            
            % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
            rpl=a:0.01:Rho;
            upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
            epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
            epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                A3)/(2.*A1))*C2)./rpl;
            sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
            sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
            
            sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
            sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
            sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
            sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
            sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
            
            %%% Elastic zone (r > Rho1)
            
            % stress, strain and displacement field (Eqs. 5.24 to 5.33):
            rel=Rho:0.01:(Rho+40);
            uel=1/(2*muStar)*(sigma0-sigmarRho1A)*Rho^2./rel;
            sigmarel=sigma0-(sigma0-sigmarRho1A)*(Rho./rel).^2;
            sigmatel=sigma0+(sigma0-sigmarRho1A)*(Rho./rel).^2;
            epsilonrel=(Rho^2*(sigmarRho1A-sigma0))./(2.*rel.^2*muStar);
            epsilontel=(Rho^2*(sigma0-sigmarRho1A))./(2.*rel.^2*muStar);
            sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
            sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
            sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
            sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
            sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
            
            %%% Plot stress, strain and displacement field:
            figure
            set(figure,'units','normalized','outerposition',[0 0 1 1]);
            subplot(2,3,1)
            plot(rel,uel);
            hold on
            plot(rpl,upl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('u [m]');
            
            subplot(2,3,2)
            plot(rel,epsilonrel);
            hold on
            plot(rel,epsilontel);
            hold on
            plot(rpl,epsilonrpl);
            hold on
            plot(rpl,epsilontpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\epsilon [-]');
            
            subplot(2,3,3)
            plot(rel,sigmarel);
            axis([a inf -inf inf])
            hold on
            plot(rel,sigmatel);
            hold on
            plot(rpl,sigmarpl);
            hold on
            plot(rpl,sigmatpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigma [MPa]');
            
            subplot(2,3,4)
            plot(rel,sigmarhel);
            hold on
            plot(rel,sigmathel);
            hold on
            plot(rpl,sigmarhpl);
            hold on
            plot(rpl,sigmathpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmah [MPa]');
            
            subplot(2,3,5)
            plot(rel,sigmarwel);
            hold on
            plot(rel,sigmatwel);
            hold on
            plot(rpl,sigmarwpl);
            hold on
            plot(rpl,sigmatwpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmaw [MPa]');
            
            Rho2=a
            
            %% GRC for the elasto-plastic behaviour of the weak or the hard layers (at least one layer: out of plane failure)
        elseif (sigmaa < sigmarRho1oA)
            
            %% Calculation of boundary conditions for r=Rho2
            % Required constants:
            A1 =A1iio;
            A2 =A2iio;
            A3 =A3iio;
            A4 =A4iio;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1iio;
            K2=K2iio;
            K3=K3iio;
            K4=K4iio;
            K5=K5iio;
            K6=K6iio;
            K7=K7iio;
            K8=K8iio;
            sigmarRho=sigmarRho1oA;
            sigmatRho=sigmatRho1oA;
            sigmarwRho=sigmarwRho1oA;
            sigmatwRho=sigmatwRho1oA;
            sigmarhRho=sigmarhRho1oA;
            sigmathRho=sigmathRho1oA;
            epsilonrRho=epsilonrRho1oA;
            epsilontRho=epsilontRho1oA;
            B1=B1iio;
            B2=B2iio;
            sigmazRho=sigmazRho1oA;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eq. (5.63) and (5.64) in function of Rho=Rho1o:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                A3)/(2*A1)));
            
            % epsilonr(r=a) and epsilont(r=a) with Eqs. (5.57) and (5.58) in function of Rho=Rho1o:
            epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + ...
                A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
            epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            
            % sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
            % in function of Rho = Rho1o:
            sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
            sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
            sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
            sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
            sigmaza=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
            
            % Solving Eq. (5.80), in order to obtain Rho1o:
            eqn=sigmatha==mhH*sigmarha+sigmadhH;
            SolRho = vpasolve(eqn,Rho,a);
            [sz1,sz2]=size(SolRho);
            Rho=double(SolRho(sz1));
            
            % Calculating all factors again with Rho=Rho1o:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                A3)/(2*A1)));
            epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                A3)/(2*A1))*C2)/(2*A1);
            epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            
            % Calculating the boundary conditions with Rho=Rho1o (Eqs. (5.57) to (5.71)):
            sigmarRho2A=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
            sigmarhRho2A=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
            sigmarwRho2A=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
            sigmatwRho2A=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
            epsilonrRho2A=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
                ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
            epsilontRho2A=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            sigmazRho2A=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
            
            %considering a brittle behaviour of the hard layers:
            sigmathRho2A=mh*sigmarhRho2A+sigmadh; % Eq. (5.85)
            sigmatRho2A=xh*sigmathRho2A+xw*sigmatwRho2A; % Eq. (5.86)
            
            %% Calculation of boundary conditions for r=Rho2o
            % Required constants:
            A1 =A1ivo1;
            A2 =A2ivo1;
            A3 =A3ivo1;
            A4 =A4ivo1;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1ivo1;
            K2=K2ivo1;
            K3=K3ivo1;
            K4=K4ivo1;
            K5=K5ivo1;
            K6=K6ivo1;
            K7=K7ivo1;
            K8=K8ivo1;
            sigmarRho=sigmarRho2A;
            sigmatRho=sigmatRho2A;
            sigmarwRho=sigmarwRho2A;
            sigmatwRho=sigmatwRho2A;
            sigmarhRho=sigmarhRho2A;
            sigmathRho=sigmathRho2A;
            epsilonrRho=epsilonrRho2A;
            epsilontRho=epsilontRho2A;
            B1=B1ivo1;
            B2=B2ivo1;
            sigmazRho=sigmazRho2A;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eq. (5.63) and (5.64) in function of Rho=Rho2:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                A3)/(2*A1)));
            
            % epsilonr(r=a) and epsilont(r=a) with Eq. (5.57) and (5.58) in function of Rho=Rho2:
            epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + ...
                A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
            epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            
            % sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
            % in function of Rho = Rho2:
            sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
            sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
            sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
            sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
            sigmaza=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
            
            % Solving Eq. ((sigmath(r=a)=sigmaz(r=a))), in order to obtain Rho=Rho2:
            eqn=sigmatha==sigmaza;
            SolRho = vpasolve(eqn,Rho,a);
            sigmarRho2oA3=0;
            if isempty(SolRho)
                Rho3o=inf;
            else
                [sz1,sz2]=size(SolRho);
                Rho3o=double(SolRho(sz1));
                
                if isreal(Rho3o)
                    Rho3o=Rho3o;
                    Rho = Rho3o;
                    % Calculating all factors again with Rho=Rho2:
                    C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                        2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                        epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                        4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                    C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                        A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                        sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                        A3)/(2*A1)));
                    epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                        A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                        A3)/(2*A1))*C2)/(2*A1);
                    epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                        sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                    
                    % Calculating sigmar,Rho2o with Rho=Rho2 (Eq. 5.59):
                    sigmarRho2oA3=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                        A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                        (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                else
                    Rho3o=inf;
                end
            end
            
            % Solving Eq. ((sigmarh(r=a)=sigmaz(r=a))), in order to obtain Rho=Rho2:
            clear Rho
            syms Rho
            eqn=sigmarha==sigmaza;
            SolRho = vpasolve(eqn,Rho,a);
            sigmarRho2oA4=0;
            if isempty(SolRho)
                Rho4o=inf;
            else
                [sz1,sz2]=size(SolRho);
                Rho4o=double(SolRho(sz1));
                
                if isreal(Rho4o)
                    Rho4o=Rho4o;
                    Rho = Rho4o;
                    % Calculating all factors again with Rho=Rho2:
                    C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                        2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                        epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                        4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                    C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                        A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                        sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                        A3)/(2*A1)));
                    epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                        A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                        A3)/(2*A1))*C2)/(2*A1);
                    epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                        sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                    
                    % Calculating sigmar,Rho2o with Rho=Rho2 (Eq. 5.59):
                    sigmarRho2oA4=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                        A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                        (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                else
                    Rho4o=inf;
                end
            end
            
            % Verification that sigmarRho2oA < sigmarRho2A:
            if sigmarRho2oA3 > sigmarRho2A
                sigmarRho2oA3=0;
                Rho3o=inf;
            else
                sigmarRho2oA3=sigmarRho2oA3;
            end
            
            % Verification that sigmarRho2oA < sigmarRho2A:
            if sigmarRho2oA4 > sigmarRho2A
                sigmarRho2oA4=0;
                Rho4o=inf;
            else
                sigmarRho2oA4=sigmarRho2oA4;
            end
            
            % Out-of-plane failure of the hard layers in triaxial
            % extension:
            if sigmarRho2oA3 > sigmarRho2oA4
                Rho=Rho3o; % i.e. both layers out-of-plane failure (sigmat=sigmaz)
                A1iv2o =A1ivo3;
                A2iv2o =A2ivo3;
                A3iv2o =A3ivo3;
                A4iv2o =A4ivo3;
                K1iv2o=K1ivo3;
                K2iv2o=K2ivo3;
                K3iv2o=K3ivo3;
                K4iv2o=K4ivo3;
                K5iv2o=K5ivo3;
                K6iv2o=K6ivo3;
                K7iv2o=K7ivo3;
                K8iv2o=K8ivo3;
                B1iv2o=B1ivo3;
                B2iv2o=B2ivo3;
                % Out-of-plane failure of the hard layers in triaxial
                % compression:
            else
                Rho=Rho4o;
                A1iv2o =A1ivo5;
                A2iv2o =A2ivo5;
                A3iv2o =A3ivo5;
                A4iv2o =A4ivo5;
                K1iv2o=K1ivo5;
                K2iv2o=K2ivo5;
                K3iv2o=K3ivo5;
                K4iv2o=K4ivo5;
                K5iv2o=K5ivo5;
                K6iv2o=K6ivo5;
                K7iv2o=K7ivo5;
                K8iv2o=K8ivo5;
                B1iv2o=B1ivo5;
                B2iv2o=B2ivo5;
            end
            
            
            if isinf(Rho)
                sigmarRho2oA = 0;
            else
                
                % Calculating all factors again with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                    A3)/(2*A1)));
                epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                    A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                    A3)/(2*A1))*C2)/(2*A1);
                epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                
                % Calculating the boundary conditions with Rho=Rho2 (Eqs. (5.57) to (5.71)):
                sigmarRho2oA=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                    (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                sigmatRho2oA=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(-(A*A3*(C1 - a^(A/A1)*C2)) + ...
                    (A2*A3 + A3^2 - 2*A1*A4)*(C1 + a^(A/A1)*C2)))/(2*A1);
                sigmarhRho2oA=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
                sigmathRho2oA=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
                sigmarwRho2oA=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
                sigmatwRho2oA=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
                epsilonrRho2oA=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
                    ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
                epsilontRho2oA=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                sigmazRho2oA=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
                
                
            end
            
            if (sigmaa < sigmarRho1oA) && (sigmaa >= sigmarRho2A)
                %% GRC for the elasto-plastic behaviour of the weak layers (out-of-plane failure of the weak layers)
                
                %%% Plastic zone (a < r < Rho1o)
                % Required constants:
                A1 =A1iio;
                A2 =A2iio;
                A3 =A3iio;
                A4 =A4iio;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iio;
                K2=K2iio;
                K3=K3iio;
                K4=K4iio;
                K5=K5iio;
                K6=K6iio;
                K7=K7iio;
                K8=K8iio;
                sigmarRho=sigmarRho1oA;
                sigmatRho=sigmatRho1oA;
                sigmarwRho=sigmarwRho1oA;
                sigmatwRho=sigmatwRho1oA;
                sigmarhRho=sigmarhRho1oA;
                sigmathRho=sigmathRho1oA;
                epsilonrRho=epsilonrRho1oA;
                epsilontRho=epsilontRho1oA;
                B1=B1iio;
                B2=B2iio;
                sigmazRho=sigmazRho1oA;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (0.63) and (5.64) in function of Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.78), in order to obtain Rho=Rho2:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1o=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                fprintf("Case A (II): weak layers reach failure (out-of-plane failure)")
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2:
                rpl2=a:0.01:Rho;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho1o < r < Rho1)
                
                % Required constants:
                A1 =A1ii;
                A2 =A2ii;
                A3 =A3ii;
                A4 =A4ii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ii;
                K2=K2ii;
                K3=K3ii;
                K4=K4ii;
                K5=K5ii;
                K6=K6ii;
                K7=K7ii;
                K8=K8ii;
                sigmarRho=sigmarRho1A;
                sigmatRho=sigmatRho1A;
                sigmarwRho=sigmarwRho1A;
                sigmatwRho=sigmatwRho1A;
                sigmarhRho=sigmarhRho1A;
                sigmathRho=sigmathRho1A;
                epsilonrRho=epsilonrRho1A;
                epsilontRho=epsilontRho1A;
                B1=B1ii;
                B2=B2ii;
                sigmazRho=sigmazRho1A;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho1o) with Eq. (5.59):
                sigmarRho1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho1o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho1o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho1o^(A/A1)*C2)))/2;
                
                % Solving Eq. (sigmar(r=Rho1o)=sigmarRho1o), in order to obtain Rho=Rho1:
                eqn=sigmarRho1o==sigmarRho1oA;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho1o:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1A)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1A)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1A)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1A-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1A))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
            elseif (sigmaa < sigmarRho2A) && (sigmaa >= sigmarRho2oA)
                %% GRC for the elasto-plastic behaviour of both, the weak and the hard layers (weak layers: out-of-plane failure, hard layers: in-plane failure)
                %%% Plastic zone (a < r < Rho2)
                % Required constants:
                A1 =A1ivo1;
                A2 =A2ivo1;
                A3 =A3ivo1;
                A4 =A4ivo1;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ivo1;
                K2=K2ivo1;
                K3=K3ivo1;
                K4=K4ivo1;
                K5=K5ivo1;
                K6=K6ivo1;
                K7=K7ivo1;
                K8=K8ivo1;
                sigmarRho=sigmarRho2A;
                sigmatRho=sigmatRho2A;
                sigmarwRho=sigmarwRho2A;
                sigmatwRho=sigmatwRho2A;
                sigmarhRho=sigmarhRho2A;
                sigmathRho=sigmathRho2A;
                epsilonrRho=epsilonrRho2A;
                epsilontRho=epsilontRho2A;
                B1=B1ivo1;
                B2=B2ivo1;
                sigmazRho=sigmazRho2A;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                fprintf("Case A (II): weak and hard layers reach failure (weak layers: out-of-plane failure)")
                
                % Solving Eq. (5.78), in order to obtain Rho=Rho2:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2:
                rpl1o=a:0.01:Rho2;
                upl1o=(rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl1o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl1o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl1o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl1o=((rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl1o;
                sigmarpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl1o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl1o.^(A/A1)*C2)))/2;
                sigmatpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl1o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl1o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl1o=sigmarhRho+K1*(epsilonrpl1o-epsilonrRho)+K2*(epsilontpl1o-epsilontRho);
                sigmathpl1o=sigmathRho+K3*(epsilonrpl1o-epsilonrRho)+K4*(epsilontpl1o-epsilontRho);
                sigmarwpl1o=sigmarwRho+K5*(epsilonrpl1o-epsilonrRho)+K6*(epsilontpl1o-epsilontRho);
                sigmatwpl1o=sigmatwRho+K7*(epsilonrpl1o-epsilonrRho)+K8*(epsilontpl1o-epsilontRho);
                sigmazpl1o=sigmazRho+B1.*(epsilonrpl1o-epsilonrRho)+B2.*(epsilontpl1o-epsilontRho);
                
                
                %%% Plastic zone (Rho2 < r < Rho1o)
                % Required constants:
                A1 =A1iio;
                A2 =A2iio;
                A3 =A3iio;
                A4 =A4iio;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iio;
                K2=K2iio;
                K3=K3iio;
                K4=K4iio;
                K5=K5iio;
                K6=K6iio;
                K7=K7iio;
                K8=K8iio;
                sigmarRho=sigmarRho1oA;
                sigmatRho=sigmatRho1oA;
                sigmarwRho=sigmarwRho1oA;
                sigmatwRho=sigmatwRho1oA;
                sigmarhRho=sigmarhRho1oA;
                sigmathRho=sigmathRho1oA;
                epsilonrRho=epsilonrRho1oA;
                epsilontRho=epsilontRho1oA;
                B1=B1iio;
                B2=B2iio;
                sigmazRho=sigmazRho1oA;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2) with Eq. (5.59):
                sigmarRho2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.74), in order to obtain Rho1o:
                eqn=sigmarRho2==sigmarRho2A;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1o=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1o:
                rpl2=Rho2:0.01:Rho1o;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho1o < r < Rho1)
                
                % Required constants:
                A1 =A1ii;
                A2 =A2ii;
                A3 =A3ii;
                A4 =A4ii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ii;
                K2=K2ii;
                K3=K3ii;
                K4=K4ii;
                K5=K5ii;
                K6=K6ii;
                K7=K7ii;
                K8=K8ii;
                sigmarRho=sigmarRho1A;
                sigmatRho=sigmatRho1A;
                sigmarwRho=sigmarwRho1A;
                sigmatwRho=sigmatwRho1A;
                sigmarhRho=sigmarhRho1A;
                sigmathRho=sigmathRho1A;
                epsilonrRho=epsilonrRho1A;
                epsilontRho=epsilontRho1A;
                B1=B1ii;
                B2=B2ii;
                sigmazRho=sigmazRho1A;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho1o) with Eq. (5.59):
                sigmarRho1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho1o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho1o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho1o^(A/A1)*C2)))/2;
                
                % Solving Eq. (sigmar(r=Rho1o)=sigmarRho1o), in order to obtain Rho1:
                eqn=sigmarRho1o==sigmarRho1oA;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho1o:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1A)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1A)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1A)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1A-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1A))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                hold on
                plot(rpl1o,upl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                hold on
                plot(rpl1o,epsilonrpl1o);
                hold on
                plot(rpl1o,epsilontpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarpl1o);
                hold on
                plot(rpl1o,sigmatpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarhpl1o);
                hold on
                plot(rpl1o,sigmathpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarwpl1o);
                hold on
                plot(rpl1o,sigmatwpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
            elseif (sigmaa < sigmarRho2oA)
                %% GRC for the elasto-plastic behaviour of both, the weak and the hard layers (both: out-of-plane failure)
                
                %%% Plastic zone (a < r < Rho2o)
                % Required constants:
                A1 =A1iv2o;
                A2 =A2iv2o;
                A3 =A3iv2o;
                A4 =A4iv2o;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iv2o;
                K2=K2iv2o;
                K3=K3iv2o;
                K4=K4iv2o;
                K5=K5iv2o;
                K6=K6iv2o;
                K7=K7iv2o;
                K8=K8iv2o;
                sigmarRho=sigmarRho2oA;
                sigmatRho=sigmatRho2oA;
                sigmarwRho=sigmarwRho2oA;
                sigmatwRho=sigmatwRho2oA;
                sigmarhRho=sigmarhRho2oA;
                sigmathRho=sigmathRho2oA;
                epsilonrRho=epsilonrRho2oA;
                epsilontRho=epsilontRho2oA;
                B1=B1iv2o;
                B2=B2iv2o;
                sigmazRho=sigmazRho2oA;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                % Solving Equation (5.78), in order to obtain Rho=Rho2o:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2o=Rho
                fprintf("Case A (II): weak and hard layers reach failure (both: out-of-plane failure)")
                
                % Calculating again C[1] and C[2] with Rho=Rho2o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2o:
                rpl2o=a:0.01:Rho2o;
                upl2o=(rpl2o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2o=((rpl2o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2o;
                sigmarpl2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2o.^(A/A1)*C2)))/2;
                sigmatpl2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2o=sigmarhRho+K1*(epsilonrpl2o-epsilonrRho)+K2*(epsilontpl2o-epsilontRho);
                sigmathpl2o=sigmathRho+K3*(epsilonrpl2o-epsilonrRho)+K4*(epsilontpl2o-epsilontRho);
                sigmarwpl2o=sigmarwRho+K5*(epsilonrpl2o-epsilonrRho)+K6*(epsilontpl2o-epsilontRho);
                sigmatwpl2o=sigmatwRho+K7*(epsilonrpl2o-epsilonrRho)+K8*(epsilontpl2o-epsilontRho);
                sigmazpl2o=sigmazRho+B1.*(epsilonrpl2o-epsilonrRho)+B2.*(epsilontpl2o-epsilontRho);
                
                
                %%% Plastic zone (Rho2o < r < Rho2)
                % Required constants:
                A1 =A1ivo1;
                A2 =A2ivo1;
                A3 =A3ivo1;
                A4 =A4ivo1;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ivo1;
                K2=K2ivo1;
                K3=K3ivo1;
                K4=K4ivo1;
                K5=K5ivo1;
                K6=K6ivo1;
                K7=K7ivo1;
                K8=K8ivo1;
                sigmarRho=sigmarRho2A;
                sigmatRho=sigmatRho2A;
                sigmarwRho=sigmarwRho2A;
                sigmatwRho=sigmatwRho2A;
                sigmarhRho=sigmarhRho2A;
                sigmathRho=sigmathRho2A;
                epsilonrRho=epsilonrRho2A;
                epsilontRho=epsilontRho2A;
                B1=B1ivo1;
                B2=B2ivo1;
                sigmazRho=sigmazRho2A;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2o) with Eq. (5.59):
                sigmarRho2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2o^(A/A1)*C2)))/2;
                
                % Solving Eq. (sigmar(r=Rho2o)=sigmarRho2o), in order to obtain Rho=Rho2:
                eqn=sigmarRho2o==sigmarRho2oA;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2:
                rpl1o=Rho2o:0.01:Rho2;
                upl1o=(rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl1o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl1o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl1o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl1o=((rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl1o;
                sigmarpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl1o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl1o.^(A/A1)*C2)))/2;
                sigmatpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl1o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl1o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl1o=sigmarhRho+K1*(epsilonrpl1o-epsilonrRho)+K2*(epsilontpl1o-epsilontRho);
                sigmathpl1o=sigmathRho+K3*(epsilonrpl1o-epsilonrRho)+K4*(epsilontpl1o-epsilontRho);
                sigmarwpl1o=sigmarwRho+K5*(epsilonrpl1o-epsilonrRho)+K6*(epsilontpl1o-epsilontRho);
                sigmatwpl1o=sigmatwRho+K7*(epsilonrpl1o-epsilonrRho)+K8*(epsilontpl1o-epsilontRho);
                sigmazpl1o=sigmazRho+B1.*(epsilonrpl1o-epsilonrRho)+B2.*(epsilontpl1o-epsilontRho);
                
                
                %%% Plastic zone (Rho2 < r < Rho1o)
                % Required constants:
                A1 =A1iio;
                A2 =A2iio;
                A3 =A3iio;
                A4 =A4iio;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iio;
                K2=K2iio;
                K3=K3iio;
                K4=K4iio;
                K5=K5iio;
                K6=K6iio;
                K7=K7iio;
                K8=K8iio;
                sigmarRho=sigmarRho1oA;
                sigmatRho=sigmatRho1oA;
                sigmarwRho=sigmarwRho1oA;
                sigmatwRho=sigmatwRho1oA;
                sigmarhRho=sigmarhRho1oA;
                sigmathRho=sigmathRho1oA;
                epsilonrRho=epsilonrRho1oA;
                epsilontRho=epsilontRho1oA;
                B1=B1iio;
                B2=B2iio;
                sigmazRho=sigmazRho1oA;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2) with Eq. (5.59):
                sigmarRho2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.74), in order to obtain Rho=Rho1o:
                eqn=sigmarRho2==sigmarRho2A;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1o=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1o:
                rpl2=Rho2:0.01:Rho1o;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho1o < r < Rho1)
                
                % Required constants:
                A1 =A1ii;
                A2 =A2ii;
                A3 =A3ii;
                A4 =A4ii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ii;
                K2=K2ii;
                K3=K3ii;
                K4=K4ii;
                K5=K5ii;
                K6=K6ii;
                K7=K7ii;
                K8=K8ii;
                sigmarRho=sigmarRho1A;
                sigmatRho=sigmatRho1A;
                sigmarwRho=sigmarwRho1A;
                sigmatwRho=sigmatwRho1A;
                sigmarhRho=sigmarhRho1A;
                sigmathRho=sigmathRho1A;
                epsilonrRho=epsilonrRho1A;
                epsilontRho=epsilontRho1A;
                B1=B1ii;
                B2=B2ii;
                sigmazRho=sigmazRho1A;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho1o) with Eq. (5.59):
                sigmarRho1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho1o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho1o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho1o^(A/A1)*C2)))/2;
                
                % Solving Equation (sigmar(r=Rho1o)=sigmarRho1o), in order to obtain Rho1:
                eqn=sigmarRho1o==sigmarRho1oA;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho1o:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1A)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1A)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1A)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1A-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1A))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1A);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1A);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                hold on
                plot(rpl1o,upl1o);
                hold on
                plot(rpl2o,upl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                hold on
                plot(rpl1o,epsilonrpl1o);
                hold on
                plot(rpl1o,epsilontpl1o);
                hold on
                plot(rpl2o,epsilonrpl2o);
                hold on
                plot(rpl2o,epsilontpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarpl1o);
                hold on
                plot(rpl1o,sigmatpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarpl2o);
                hold on
                plot(rpl2o,sigmatpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarhpl1o);
                hold on
                plot(rpl1o,sigmathpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarhpl2o);
                hold on
                plot(rpl2o,sigmathpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarwpl1o);
                hold on
                plot(rpl1o,sigmatwpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarwpl2o);
                hold on
                plot(rpl2o,sigmatwpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
                
            end
        end
    end
    
    %% Case B:
else
    
    
    if (sigmarRho2B > sigmarRho1oB)
        
        %% Case B(I):
        %% GRC for the purely elastic case (Section 2.3 and Appendix B)
        if (sigmaa >= sigmarRho1B)
            Rho1=a
            Rho2=a
            ua = 1/(2*muStar)*(sigma0-sigmaa)*a
            fprintf("Case B: purely elastic case")
            
            % stress, strain and displacement field (Eqs. 5.24 to 5.33):
            rel=a:0.01:50;
            uel=1/(2*muStar)*(sigma0-sigmaa)*a^2./rel;
            sigmarel=sigma0-(sigma0-sigmaa)*(a./rel).^2;
            sigmatel=sigma0+(sigma0-sigmaa)*(a./rel).^2;
            epsilonrel=(a^2*(sigmaa-sigma0))./(2.*rel.^2*muStar);
            epsilontel=(a^2*(sigma0-sigmaa))./(2.*rel.^2*muStar);
            sigmarwel=sigma0-a^2./rel.^2*muw/muStar*(sigma0-sigmaa);
            sigmatwel=sigma0+a^2./rel.^2*muw/muStar*(sigma0-sigmaa);
            sigmarhel=sigma0-a^2./rel.^2*muh/muStar*(sigma0-sigmaa);
            sigmathel=sigma0+a^2./rel.^2*muh/muStar*(sigma0-sigmaa);
            sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
            
            % Plot stress, strain and displacement field:
            figure
            set(figure,'units','normalized','outerposition',[0 0 1 1]);
            subplot(2,3,1)
            plot(rel,uel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('u [m]');
            
            subplot(2,3,2)
            plot(rel,epsilonrel);
            hold on
            plot(rel,epsilontel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\epsilon [-]');
            
            subplot(2,3,3)
            plot(rel,sigmarel);
            axis([a inf -inf inf])
            hold on
            plot(rel,sigmatel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigma [MPa]');
            
            subplot(2,3,4)
            plot(rel,sigmarhel);
            hold on
            plot(rel,sigmathel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmah [MPa]');
            
            subplot(2,3,5)
            plot(rel,sigmarwel);
            hold on
            plot(rel,sigmatwel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmaw [MPa]');
            
        elseif (sigmaa < sigmarRho1B) && (sigmaa >= sigmarRho2B)
            %% GRC for the elasto-plastic behaviour of the hard layers (no out-of-plane failure)
            %%% Plastic zone (a < r < Rho1)
            % Required constants:
            A1 =A1iii;
            A2 =A2iii;
            A3 =A3iii;
            A4 =A4iii;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1iii;
            K2=K2iii;
            K3=K3iii;
            K4=K4iii;
            K5=K5iii;
            K6=K6iii;
            K7=K7iii;
            K8=K8iii;
            sigmarRho=sigmarRho1B;
            sigmatRho=sigmatRho1B;
            sigmarwRho=sigmarwRho1B;
            sigmatwRho=sigmatwRho1B;
            sigmarhRho=sigmarhRho1B;
            sigmathRho=sigmathRho1B;
            epsilonrRho=epsilonrRho1B;
            epsilontRho=epsilontRho1B;
            B1=B1iii;
            B2=B2iii;
            sigmazRho=sigmazRho1B;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
            
            % sigmar(r=a) with Eq. (5.59):
            sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
            
            % Solving Eq. (5.66), in order to obtain Rho=Rho1:
            eqn=sigmara==sigmaa;
            SolRho = vpasolve(eqn,Rho,a);
            [sz1,sz2]=size(SolRho);
            Rho=double(SolRho(sz1));
            Rho1=Rho
            
            % Calculating all factors again with Rho=Rho1:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
            
            % ua with C[1] and C[2] (Eq. 5.56):
            ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
            fprintf("Case B (I): hard layers reach failure (no out-of-plane failure)")
            
            % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho1:
            rpl=a:0.01:Rho;
            upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
            epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
            epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                A3)/(2.*A1))*C2)./rpl;
            sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
            sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
            
            sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
            sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
            sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
            sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
            sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
            
            %%% Elastic zone (r > Rho1)
            
            % stress, strain and displacement field (Eqs. 5.24 to 5.33):
            rel=Rho:0.01:(Rho+40);
            uel=1/(2*muStar)*(sigma0-sigmarRho1B)*Rho^2./rel;
            sigmarel=sigma0-(sigma0-sigmarRho1B)*(Rho./rel).^2;
            sigmatel=sigma0+(sigma0-sigmarRho1B)*(Rho./rel).^2;
            epsilonrel=(Rho^2*(sigmarRho1B-sigma0))./(2.*rel.^2*muStar);
            epsilontel=(Rho^2*(sigma0-sigmarRho1B))./(2.*rel.^2*muStar);
            sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
            sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
            sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
            sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
            sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
            
            %%% Plot stress, strain and displacement field:
            figure
            set(figure,'units','normalized','outerposition',[0 0 1 1]);
            subplot(2,3,1)
            plot(rel,uel);
            hold on
            plot(rpl,upl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('u [m]');
            
            subplot(2,3,2)
            plot(rel,epsilonrel);
            hold on
            plot(rel,epsilontel);
            hold on
            plot(rpl,epsilonrpl);
            hold on
            plot(rpl,epsilontpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\epsilon [-]');
            
            subplot(2,3,3)
            plot(rel,sigmarel);
            axis([a inf -inf inf])
            hold on
            plot(rel,sigmatel);
            hold on
            plot(rpl,sigmarpl);
            hold on
            plot(rpl,sigmatpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigma [MPa]');
            
            subplot(2,3,4)
            plot(rel,sigmarhel);
            hold on
            plot(rel,sigmathel);
            hold on
            plot(rpl,sigmarhpl);
            hold on
            plot(rpl,sigmathpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmah [MPa]');
            
            subplot(2,3,5)
            plot(rel,sigmarwel);
            hold on
            plot(rel,sigmatwel);
            hold on
            plot(rpl,sigmarwpl);
            hold on
            plot(rpl,sigmatwpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmaw [MPa]');
            
            Rho2=a
            
            %% GRC for the elasto-plastic behaviour of the weak and the hard layers
        elseif (sigmaa < sigmarRho2B)
            
            %% Calculation of boundary conditions for r=Rho1o
            % Required constants:
            A1 =A1iv;
            A2 =A2iv;
            A3 =A3iv;
            A4 =A4iv;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1iv;
            K2=K2iv;
            K3=K3iv;
            K4=K4iv;
            K5=K5iv;
            K6=K6iv;
            K7=K7iv;
            K8=K8iv;
            sigmarRho=sigmarRho2B;
            sigmatRho=sigmatRho2B;
            sigmarwRho=sigmarwRho2B;
            sigmatwRho=sigmatwRho2B;
            sigmarhRho=sigmarhRho2B;
            sigmathRho=sigmathRho2B;
            epsilonrRho=epsilonrRho2B;
            epsilontRho=epsilontRho2B;
            B1=B1iv;
            B2=B2iv;
            sigmazRho=sigmazRho2B;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                A3)/(2*A1)));
            
            % epsilonr(r=a) and epsilont(r=a) with Eqs. (5.57) and (5.58) in function of Rho=Rho2:
            epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + ...
                A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
            epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            
            % sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
            % in function of Rho = Rho2:
            sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
            sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
            sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
            sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
            sigmaza=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
            
            % Solving Eq. (sigmatw(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho2 (Case B(I),(b) in Fig. 14):
            eqn=sigmatwa==sigmaza;
            SolRho = vpasolve(eqn,Rho,a);
            if isempty(SolRho)
                Rho1o=inf;
            else
                [sz1,sz2]=size(SolRho);
                Rho1o=double(SolRho(sz1));
                
                if isreal(Rho1o)
                    Rho1o=Rho1o;
                else
                    Rho1o=inf;
                end
            end
            
            % Solving Eq. (sigmath(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho2 (Case B(I),(a) in Fig. 14):
            clear Rho
            syms Rho
            eqn=sigmatha==sigmaza;
            SolRho = vpasolve(eqn,Rho,a);
            if isempty(SolRho)
                Rho2o=inf;
            else
                [sz1,sz2]=size(SolRho);
                Rho2o=double(SolRho(sz1));
                
                if isreal(Rho2o)
                    Rho2o=Rho2o;
                else
                    Rho2o=inf;
                end
            end
            
            % Case B(I),(b)
            if Rho1o < Rho2o
                Rho=Rho1o; % i.e. weak layers reach first out-of-plane failure 
                A1ivo =A1ivo1;
                A2ivo =A2ivo1;
                A3ivo =A3ivo1;
                A4ivo =A4ivo1;
                K1ivo=K1ivo1;
                K2ivo=K2ivo1;
                K3ivo=K3ivo1;
                K4ivo=K4ivo1;
                K5ivo=K5ivo1;
                K6ivo=K6ivo1;
                K7ivo=K7ivo1;
                K8ivo=K8ivo1;
                B1ivo=B1ivo1;
                B2ivo=B2ivo1;
                % Case B(I),(a)
            else
                Rho=Rho2o; % i.e. hard layers reach first out-of-plane failure
                A1ivo =A1ivo2;
                A2ivo =A2ivo2;
                A3ivo =A3ivo2;
                A4ivo =A4ivo2;
                K1ivo=K1ivo2;
                K2ivo=K2ivo2;
                K3ivo=K3ivo2;
                K4ivo=K4ivo2;
                K5ivo=K5ivo2;
                K6ivo=K6ivo2;
                K7ivo=K7ivo2;
                K8ivo=K8ivo2;
                B1ivo=B1ivo2;
                B2ivo=B2ivo2;
            end
            
            if isinf(Rho)
                sigmarRho1oB = 0;
            else
                
                % Calculating all factors again with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                    A3)/(2*A1)));
                epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                    A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                    A3)/(2*A1))*C2)/(2*A1);
                epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                
                % Calculating the boundary conditions with Rho=Rho2 (Eqs. (5.57) to (5.71)):
                sigmarRho1oB=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                    (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                sigmatRho1oB=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(-(A*A3*(C1 - a^(A/A1)*C2)) + ...
                    (A2*A3 + A3^2 - 2*A1*A4)*(C1 + a^(A/A1)*C2)))/(2*A1);
                sigmarhRho1oB=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
                sigmathRho1oB=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
                sigmarwRho1oB=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
                sigmatwRho1oB=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
                epsilonrRho1oB=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
                    ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
                epsilontRho1oB=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                sigmazRho1oB=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
                
                
            end
            
            % Verification that sigmarRho1oB < sigmarRho2B:
            if sigmarRho1oB > sigmarRho2B
                sigmarRho1oB=0;
            else
                sigmarRho1oB=sigmarRho1oB;
            end
            
            %% Calculation of boundary conditions for r=Rho2o
            % Required constants:
            A1 =A1ivo;
            A2 =A2ivo;
            A3 =A3ivo;
            A4 =A4ivo;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1ivo;
            K2=K2ivo;
            K3=K3ivo;
            K4=K4ivo;
            K5=K5ivo;
            K6=K6ivo;
            K7=K7ivo;
            K8=K8ivo;
            sigmarRho=sigmarRho1oB;
            sigmatRho=sigmatRho1oB;
            sigmarwRho=sigmarwRho1oB;
            sigmatwRho=sigmatwRho1oB;
            sigmarhRho=sigmarhRho1oB;
            sigmathRho=sigmathRho1oB;
            epsilonrRho=epsilonrRho1oB;
            epsilontRho=epsilontRho1oB;
            B1=B1ivo;
            B2=B2ivo;
            sigmazRho=sigmazRho1oB;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                A3)/(2*A1)));
            
            % epsilonr(r=a) and epsilont(r=a) with Eqs. (5.57) and (5.58) in function of Rho=Rho1o:
            epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + ...
                A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
            epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            
            % sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
            % in function of Rho = Rho1o:
            sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
            sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
            sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
            sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
            sigmaza=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
            
            % Solving Eq. (sigmath(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho1o (for Case B(I),(b)):
            if Rho1o < Rho2o
                eqn=sigmatha==sigmaza;
                SolRho = vpasolve(eqn,Rho,a);
                sigmarRho2oB3=0;
                if isempty(SolRho)
                    Rho3o=inf;
                else
                    [sz1,sz2]=size(SolRho);
                    Rho3o=double(SolRho(sz1));
                    
                    if isreal(Rho3o)
                        Rho3o=Rho3o;
                        
                        Rho = Rho3o;
                        
                       % Calculating all factors again with Rho=Rho1o:
                        C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                            2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                            epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                            4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                        C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                            A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                            sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                            A3)/(2*A1)));
                        epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                            A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                            A3)/(2*A1))*C2)/(2*A1);
                        epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                            sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                        
                        % Calculating sigmar,Rho2o with Rho=Rho1o (Eq. A-98):
                        sigmarRho2oB3=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                            A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                            (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                        
                    else
                        Rho3o=inf;
                    end
                end
                
                % Solving Eq. (sigmarh(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho1o (for Case B(I),(b)):
                clear Rho
                syms Rho
                eqn=sigmarha==sigmaza;
                SolRho = vpasolve(eqn,Rho,a);
                sigmarRho2oB4=0;
                if isempty(SolRho)
                    Rho4o=inf;
                else
                    [sz1,sz2]=size(SolRho);
                    Rho4o=double(SolRho(sz1));
                    
                    if isreal(Rho4o)
                        Rho4o=Rho4o;
                        
                        Rho = Rho4o;
                        
                        % Calculating all factors again with Rho=Rho1o:
                        C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                            2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                            epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                            4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                        C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                            A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                            sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                            A3)/(2*A1)));
                        epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                            A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                            A3)/(2*A1))*C2)/(2*A1);
                        epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                            sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                        
                        % Calculating sigmar,Rho2o with Rho=Rho1o (Eq. 5.59):
                        sigmarRho2oB4=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                            A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                            (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                        
                    else
                        Rho4o=inf;
                    end
                end
                
                % Verification that sigmarRho2oB < sigmarRho1oB:
                if sigmarRho2oB3 > sigmarRho1oB
                    sigmarRho2oB3=0;
                    Rho3o=inf;
                else
                    sigmarRho2oB3=sigmarRho2oB3;
                end
                
                % Verification that sigmarRho2oB < sigmarRho1oB:
                if sigmarRho2oB4 > sigmarRho1oB
                    sigmarRho2oB4=0;
                    Rho4o=inf;
                else
                    sigmarRho2oB4=sigmarRho2oB4;
                end
                
                % Out-of-plane failure of the hard layers in triaxial
                % extension:
                if sigmarRho2oB3 > sigmarRho2oB4
                    Rho=Rho3o; % i.e. both layers out-of-plane failure (sigmat=sigmaz)
                    A1iv2o =A1ivo3;
                    A2iv2o =A2ivo3;
                    A3iv2o =A3ivo3;
                    A4iv2o =A4ivo3;
                    K1iv2o=K1ivo3;
                    K2iv2o=K2ivo3;
                    K3iv2o=K3ivo3;
                    K4iv2o=K4ivo3;
                    K5iv2o=K5ivo3;
                    K6iv2o=K6ivo3;
                    K7iv2o=K7ivo3;
                    K8iv2o=K8ivo3;
                    B1iv2o=B1ivo3;
                    B2iv2o=B2ivo3;
                else
                    % Out-of-plane failure of the hard layers in triaxial
                    % compression:
                    Rho=Rho4o; 
                    A1iv2o =A1ivo5;
                    A2iv2o =A2ivo5;
                    A3iv2o =A3ivo5;
                    A4iv2o =A4ivo5;
                    K1iv2o=K1ivo5;
                    K2iv2o=K2ivo5;
                    K3iv2o=K3ivo5;
                    K4iv2o=K4ivo5;
                    K5iv2o=K5ivo5;
                    K6iv2o=K6ivo5;
                    K7iv2o=K7ivo5;
                    K8iv2o=K8ivo5;
                    B1iv2o=B1ivo5;
                    B2iv2o=B2ivo5;
                end
                
            else
                % Solving Eq. (sigmatw(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho1o (for Case B(I),(a)):
                eqn=sigmatwa==sigmaza;
                SolRho = vpasolve(eqn,Rho,a);
                sigmarRho2oB3=0;
                if isempty(SolRho)
                    Rho3o=inf;
                else
                    [sz1,sz2]=size(SolRho);
                    Rho3o=double(SolRho(sz1));
                    
                    if isreal(Rho3o)
                        Rho3o=Rho3o;
                        
                        Rho = Rho3o;
                        
                        % Calculating all factors again with Rho=Rho1o:
                        C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                            2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                            epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                            4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                        C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                            A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                            sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                            A3)/(2*A1)));
                        epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                            A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                            A3)/(2*A1))*C2)/(2*A1);
                        epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                            sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                        
                        % Calculating sigmar,Rho2o with Rho=Rho1o (Eq. 5.59):
                        sigmarRho2oB3=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                            A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                            (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                        
                    else
                        Rho3o=inf;
                    end
                end
                
                % Solving Eq. (sigmarw(r=a)=sigmaz(r=a)), in order to obtain Rho=Rho1o (for Case B(I),(a)):
                clear Rho
                syms Rho
                eqn=sigmarwa==sigmaza;
                SolRho = vpasolve(eqn,Rho,a);
                sigmarRho2oB4=0;
                if isempty(SolRho)
                    Rho4o=inf;
                else
                    [sz1,sz2]=size(SolRho);
                    Rho4o=double(SolRho(sz1));
                    
                    if isreal(Rho4o)
                        Rho4o=Rho4o;
                        
                        Rho = Rho4o;
                        
                        % Calculating all factors again with Rho=Rho1o:
                        C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                            2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                            epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                            4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                        C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                            A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                            sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                            A3)/(2*A1)));
                        epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                            A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                            A3)/(2*A1))*C2)/(2*A1);
                        epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                            sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                        
                        % Calculating sigmar,Rho2o with Rho=Rho1o (Eq. 5.59):
                        sigmarRho2oB4=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                            A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                            (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                        
                    else
                        Rho4o=inf;
                    end
                end
                
                % Verification that sigmarRho2oB < sigmarRho1oB:
                if sigmarRho2oB3 > sigmarRho1oB
                    sigmarRho2oB3=0;
                    Rho3o=inf;
                else
                    sigmarRho2oB3=sigmarRho2oB3;
                end
                
                % Verification that sigmarRho2oA < sigmarRho1oA:
                if sigmarRho2oB4 > sigmarRho1oB
                    sigmarRho2oB4=0;
                    Rho4o=inf;
                else
                    sigmarRho2oB4=sigmarRho2oB4;
                end
                
                % Out-of-plane failure of the weak layers in triaxial
                % extension:
                if sigmarRho2oB3 > sigmarRho2oB4
                    Rho=Rho3o; % i.e. both layers out-of-plane failure (sigmat=sigmaz)
                    A1iv2o =A1ivo3;
                    A2iv2o =A2ivo3;
                    A3iv2o =A3ivo3;
                    A4iv2o =A4ivo3;
                    K1iv2o=K1ivo3;
                    K2iv2o=K2ivo3;
                    K3iv2o=K3ivo3;
                    K4iv2o=K4ivo3;
                    K5iv2o=K5ivo3;
                    K6iv2o=K6ivo3;
                    K7iv2o=K7ivo3;
                    K8iv2o=K8ivo3;
                    B1iv2o=B1ivo3;
                    B2iv2o=B2ivo3;
                else
                    % Out-of-plane failure of the weak layers in triaxial
                    % compression:
                    Rho=Rho4o; 
                    A1iv2o =A1ivo4;
                    A2iv2o =A2ivo4;
                    A3iv2o =A3ivo4;
                    A4iv2o =A4ivo4;
                    K1iv2o=K1ivo4;
                    K2iv2o=K2ivo4;
                    K3iv2o=K3ivo4;
                    K4iv2o=K4ivo4;
                    K5iv2o=K5ivo4;
                    K6iv2o=K6ivo4;
                    K7iv2o=K7ivo4;
                    K8iv2o=K8ivo4;
                    B1iv2o=B1ivo4;
                    B2iv2o=B2ivo4;
                end
                
            end
            
            if isinf(Rho)
                sigmarRho2oB = 0;
            else
                
                % Calculating all factors again with Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                    A3)/(2*A1)));
                epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                    A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                    A3)/(2*A1))*C2)/(2*A1);
                epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                
                % Calculating the boundary conditions with Rho=Rho1 (Eqs. (5.57) to (5.71)):
                sigmarRho2oB=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                    (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                sigmatRho2oB=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(-(A*A3*(C1 - a^(A/A1)*C2)) + ...
                    (A2*A3 + A3^2 - 2*A1*A4)*(C1 + a^(A/A1)*C2)))/(2*A1);
                sigmarhRho2oB=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
                sigmathRho2oB=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
                sigmarwRho2oB=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
                sigmatwRho2oB=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
                epsilonrRho2oB=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
                    ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
                epsilontRho2oB=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                sigmazRho2oB=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
                
            end
            
            
            
            
            if (sigmaa < sigmarRho2B) && (sigmaa >= sigmarRho1oB)
                %% GRC for the elasto-plastic behaviour of both, the weak and the hard layers (no out-of-plane failure)
                
                %%% Plastic zone (a < r < Rho2)
                % Required constants:
                A1 =A1iv;
                A2 =A2iv;
                A3 =A3iv;
                A4 =A4iv;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iv;
                K2=K2iv;
                K3=K3iv;
                K4=K4iv;
                K5=K5iv;
                K6=K6iv;
                K7=K7iv;
                K8=K8iv;
                sigmarRho=sigmarRho2B;
                sigmatRho=sigmatRho2B;
                sigmarwRho=sigmarwRho2B;
                sigmatwRho=sigmatwRho2B;
                sigmarhRho=sigmarhRho2B;
                sigmathRho=sigmathRho2B;
                epsilonrRho=epsilonrRho2B;
                epsilontRho=epsilontRho2B;
                B1=B1iv;
                B2=B2iv;
                sigmazRho=sigmazRho2B;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.78), in order to obtain Rho=Rho2:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                fprintf("Case B (I): weak and hard layers reach failure (no out-of-plane failure)")
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2:
                rpl2=a:0.01:Rho;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho2 < r < Rho1)
                
                % Required constants:
                A1 =A1iii;
                A2 =A2iii;
                A3 =A3iii;
                A4 =A4iii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iii;
                K2=K2iii;
                K3=K3iii;
                K4=K4iii;
                K5=K5iii;
                K6=K6iii;
                K7=K7iii;
                K8=K8iii;
                sigmarRho=sigmarRho1B;
                sigmatRho=sigmatRho1B;
                sigmarwRho=sigmarwRho1B;
                sigmatwRho=sigmatwRho1B;
                sigmarhRho=sigmarhRho1B;
                sigmathRho=sigmathRho1B;
                epsilonrRho=epsilonrRho1B;
                epsilontRho=epsilontRho1B;
                B1=B1iii;
                B2=B2iii;
                sigmazRho=sigmazRho1B;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2) with Eq. (5.59):
                sigmarRho2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2^(A/A1)*C2)))/2;
                
                % Solving Equation (5.74), in order to obtain Rho=Rho1:
                eqn=sigmarRho2==sigmarRho2B;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho2:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1B)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1B)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1B)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1B-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1B))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
            elseif (sigmaa < sigmarRho1oB) && (sigmaa >= sigmarRho2oB)
                %% GRC for the elasto-plastic behaviour of both, the weak and the hard layers (out-of-plane failure of hard or weak layers)
                %%% Plastic zone (a < r < Rho1o)
                % Required constants:
                A1 =A1ivo;
                A2 =A2ivo;
                A3 =A3ivo;
                A4 =A4ivo;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ivo;
                K2=K2ivo;
                K3=K3ivo;
                K4=K4ivo;
                K5=K5ivo;
                K6=K6ivo;
                K7=K7ivo;
                K8=K8ivo;
                sigmarRho=sigmarRho1oB;
                sigmatRho=sigmatRho1oB;
                sigmarwRho=sigmarwRho1oB;
                sigmatwRho=sigmatwRho1oB;
                sigmarhRho=sigmarhRho1oB;
                sigmathRho=sigmathRho1oB;
                epsilonrRho=epsilonrRho1oB;
                epsilontRho=epsilontRho1oB;
                B1=B1ivo;
                B2=B2ivo;
                sigmazRho=sigmazRho1oB;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                if Rho1o < Rho2o
                    fprintf("Case B (I): weak and hard layers reach failure (weak layers: out-of-plane failure)")
                else
                    fprintf("Case B (I): weak and hard layers reach failure (hard layers: out-of-plane failure)")
                end
                
                % Solving Eq. (5.74), in order to obtain Rho1o:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1o=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1o:
                rpl1o=a:0.01:Rho1o;
                upl1o=(rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl1o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl1o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl1o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl1o=((rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl1o;
                sigmarpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl1o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl1o.^(A/A1)*C2)))/2;
                sigmatpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl1o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl1o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl1o=sigmarhRho+K1*(epsilonrpl1o-epsilonrRho)+K2*(epsilontpl1o-epsilontRho);
                sigmathpl1o=sigmathRho+K3*(epsilonrpl1o-epsilonrRho)+K4*(epsilontpl1o-epsilontRho);
                sigmarwpl1o=sigmarwRho+K5*(epsilonrpl1o-epsilonrRho)+K6*(epsilontpl1o-epsilontRho);
                sigmatwpl1o=sigmatwRho+K7*(epsilonrpl1o-epsilonrRho)+K8*(epsilontpl1o-epsilontRho);
                sigmazpl1o=sigmazRho+B1.*(epsilonrpl1o-epsilonrRho)+B2.*(epsilontpl1o-epsilontRho);
                
                
                %%% Plastic zone (Rho1o < r < Rho2)
                % Required constants:
                A1 =A1iv;
                A2 =A2iv;
                A3 =A3iv;
                A4 =A4iv;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iv;
                K2=K2iv;
                K3=K3iv;
                K4=K4iv;
                K5=K5iv;
                K6=K6iv;
                K7=K7iv;
                K8=K8iv;
                sigmarRho=sigmarRho2B;
                sigmatRho=sigmatRho2B;
                sigmarwRho=sigmarwRho2B;
                sigmatwRho=sigmatwRho2B;
                sigmarhRho=sigmarhRho2B;
                sigmathRho=sigmathRho2B;
                epsilonrRho=epsilonrRho2B;
                epsilontRho=epsilontRho2B;
                B1=B1iv;
                B2=B2iv;
                sigmazRho=sigmazRho2B;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho1o) with Eq. (5.59):
                sigmarRho1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho1o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho1o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho1o^(A/A1)*C2)))/2;
                
                % Solving (sigmar(r=Rho1o)=sigmarRho1o), in order to obtain Rho=Rho2:
                eqn=sigmarRho1o==sigmarRho1oB;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2:
                rpl2=Rho1o:0.01:Rho;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho2 < r < Rho1)
                
                % Required constants:
                A1 =A1iii;
                A2 =A2iii;
                A3 =A3iii;
                A4 =A4iii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iii;
                K2=K2iii;
                K3=K3iii;
                K4=K4iii;
                K5=K5iii;
                K6=K6iii;
                K7=K7iii;
                K8=K8iii;
                sigmarRho=sigmarRho1B;
                sigmatRho=sigmatRho1B;
                sigmarwRho=sigmarwRho1B;
                sigmatwRho=sigmatwRho1B;
                sigmarhRho=sigmarhRho1B;
                sigmathRho=sigmathRho1B;
                epsilonrRho=epsilonrRho1B;
                epsilontRho=epsilontRho1B;
                B1=B1iii;
                B2=B2iii;
                sigmazRho=sigmazRho1B;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2) with Eq. (5.59):
                sigmarRho2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.74), in order to obtain Rho=Rho1:
                eqn=sigmarRho2==sigmarRho2B;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho2:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1B)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1B)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1B)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1B-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1B))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                hold on
                plot(rpl1o,upl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                hold on
                plot(rpl1o,epsilonrpl1o);
                hold on
                plot(rpl1o,epsilontpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarpl1o);
                hold on
                plot(rpl1o,sigmatpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarhpl1o);
                hold on
                plot(rpl1o,sigmathpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarwpl1o);
                hold on
                plot(rpl1o,sigmatwpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
            elseif (sigmaa < sigmarRho2oB)
                %% GRC for the elasto-plastic behaviour of both, the weak and the hard layers (both: out-of-plane failure)
                
                %%% Plastic zone (a < r < Rho2o)
                % Required constants:
                A1 =A1iv2o;
                A2 =A2iv2o;
                A3 =A3iv2o;
                A4 =A4iv2o;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iv2o;
                K2=K2iv2o;
                K3=K3iv2o;
                K4=K4iv2o;
                K5=K5iv2o;
                K6=K6iv2o;
                K7=K7iv2o;
                K8=K8iv2o;
                sigmarRho=sigmarRho2oB;
                sigmatRho=sigmatRho2oB;
                sigmarwRho=sigmarwRho2oB;
                sigmatwRho=sigmatwRho2oB;
                sigmarhRho=sigmarhRho2oB;
                sigmathRho=sigmathRho2oB;
                epsilonrRho=epsilonrRho2oB;
                epsilontRho=epsilontRho2oB;
                B1=B1iv2o;
                B2=B2iv2o;
                sigmazRho=sigmazRho2oB;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.78), in order to obtain Rho=Rho2o:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2o=Rho
                fprintf("Case B (I): weak and hard layers reach failure (both: out-of-plane failure)")
                
                % Calculating again C[1] and C[2] with Rho=Rho2o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2o:
                rpl2o=a:0.01:Rho2o;
                upl2o=(rpl2o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2o=((rpl2o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2o;
                sigmarpl2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2o.^(A/A1)*C2)))/2;
                sigmatpl2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2o=sigmarhRho+K1*(epsilonrpl2o-epsilonrRho)+K2*(epsilontpl2o-epsilontRho);
                sigmathpl2o=sigmathRho+K3*(epsilonrpl2o-epsilonrRho)+K4*(epsilontpl2o-epsilontRho);
                sigmarwpl2o=sigmarwRho+K5*(epsilonrpl2o-epsilonrRho)+K6*(epsilontpl2o-epsilontRho);
                sigmatwpl2o=sigmatwRho+K7*(epsilonrpl2o-epsilonrRho)+K8*(epsilontpl2o-epsilontRho);
                sigmazpl2o=sigmazRho+B1.*(epsilonrpl2o-epsilonrRho)+B2.*(epsilontpl2o-epsilontRho);
                
                
                %%% Plastic zone (Rho2o < r < Rho1o)
                % Required constants:
                A1 =A1ivo;
                A2 =A2ivo;
                A3 =A3ivo;
                A4 =A4ivo;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ivo;
                K2=K2ivo;
                K3=K3ivo;
                K4=K4ivo;
                K5=K5ivo;
                K6=K6ivo;
                K7=K7ivo;
                K8=K8ivo;
                sigmarRho=sigmarRho1oB;
                sigmatRho=sigmatRho1oB;
                sigmarwRho=sigmarwRho1oB;
                sigmatwRho=sigmatwRho1oB;
                sigmarhRho=sigmarhRho1oB;
                sigmathRho=sigmathRho1oB;
                epsilonrRho=epsilonrRho1oB;
                epsilontRho=epsilontRho1oB;
                B1=B1ivo;
                B2=B2ivo;
                sigmazRho=sigmazRho1oB;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2o) with Eq. (5.59):
                sigmarRho2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2o^(A/A1)*C2)))/2;
                
                % Solving Eq. (sigmar(r=Rho2o)=sigmarRho2o), in order to obtain Rho=Rho1o:
                eqn=sigmarRho2o==sigmarRho2oB;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1o=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1o:
                rpl1o=Rho2o:0.01:Rho1o;
                upl1o=(rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl1o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl1o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl1o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl1o=((rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl1o;
                sigmarpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl1o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl1o.^(A/A1)*C2)))/2;
                sigmatpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl1o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl1o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl1o=sigmarhRho+K1*(epsilonrpl1o-epsilonrRho)+K2*(epsilontpl1o-epsilontRho);
                sigmathpl1o=sigmathRho+K3*(epsilonrpl1o-epsilonrRho)+K4*(epsilontpl1o-epsilontRho);
                sigmarwpl1o=sigmarwRho+K5*(epsilonrpl1o-epsilonrRho)+K6*(epsilontpl1o-epsilontRho);
                sigmatwpl1o=sigmatwRho+K7*(epsilonrpl1o-epsilonrRho)+K8*(epsilontpl1o-epsilontRho);
                sigmazpl1o=sigmazRho+B1.*(epsilonrpl1o-epsilonrRho)+B2.*(epsilontpl1o-epsilontRho);
                
                
                %%% Plastic zone (Rho1o < r < Rho2)
                % Required constants:
                A1 =A1iv;
                A2 =A2iv;
                A3 =A3iv;
                A4 =A4iv;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iv;
                K2=K2iv;
                K3=K3iv;
                K4=K4iv;
                K5=K5iv;
                K6=K6iv;
                K7=K7iv;
                K8=K8iv;
                sigmarRho=sigmarRho2B;
                sigmatRho=sigmatRho2B;
                sigmarwRho=sigmarwRho2B;
                sigmatwRho=sigmatwRho2B;
                sigmarhRho=sigmarhRho2B;
                sigmathRho=sigmathRho2B;
                epsilonrRho=epsilonrRho2B;
                epsilontRho=epsilontRho2B;
                B1=B1iv;
                B2=B2iv;
                sigmazRho=sigmazRho2B;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
               % sigmar(r=Rho1o) with Eq. (5.59):
                sigmarRho1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho1o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho1o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho1o^(A/A1)*C2)))/2;
                
                % Solving Eq. (sigmar(r=Rho1o)=sigmarRho1o), in order to obtain Rho=Rho2:
                eqn=sigmarRho1o==sigmarRho1oB;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2:
                rpl2=Rho1o:0.01:Rho;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho2 < r < Rho1)
                
                % Required constants:
                A1 =A1iii;
                A2 =A2iii;
                A3 =A3iii;
                A4 =A4iii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iii;
                K2=K2iii;
                K3=K3iii;
                K4=K4iii;
                K5=K5iii;
                K6=K6iii;
                K7=K7iii;
                K8=K8iii;
                sigmarRho=sigmarRho1B;
                sigmatRho=sigmatRho1B;
                sigmarwRho=sigmarwRho1B;
                sigmatwRho=sigmatwRho1B;
                sigmarhRho=sigmarhRho1B;
                sigmathRho=sigmathRho1B;
                epsilonrRho=epsilonrRho1B;
                epsilontRho=epsilontRho1B;
                B1=B1iii;
                B2=B2iii;
                sigmazRho=sigmazRho1B;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2) with Eq. (5.59):
                sigmarRho2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.74), in order to obtain Rho=Rho1:
                eqn=sigmarRho2==sigmarRho2B;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho2:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1B)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1B)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1B)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1B-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1B))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                hold on
                plot(rpl1o,upl1o);
                hold on
                plot(rpl2o,upl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                hold on
                plot(rpl1o,epsilonrpl1o);
                hold on
                plot(rpl1o,epsilontpl1o);
                hold on
                plot(rpl2o,epsilonrpl2o);
                hold on
                plot(rpl2o,epsilontpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarpl1o);
                hold on
                plot(rpl1o,sigmatpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarpl2o);
                hold on
                plot(rpl2o,sigmatpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarhpl1o);
                hold on
                plot(rpl1o,sigmathpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarhpl2o);
                hold on
                plot(rpl2o,sigmathpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarwpl1o);
                hold on
                plot(rpl1o,sigmatwpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarwpl2o);
                hold on
                plot(rpl2o,sigmatwpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
                
            end
        end
        
        %% Case B(II):
    else
        
        %% GRC for the purely elastic case (Section 2.3 and Appendix B)
        if (sigmaa >= sigmarRho1B)
            Rho1=a
            Rho2=a
            ua = 1/(2*muStar)*(sigma0-sigmaa)*a
            fprintf("Case B: purely elastic case")
            
            % stress, strain and displacement field (Eqs. 5.24 to 5.33)
            rel=a:0.01:50;
            uel=1/(2*muStar)*(sigma0-sigmaa)*a^2./rel;
            sigmarel=sigma0-(sigma0-sigmaa)*(a./rel).^2;
            sigmatel=sigma0+(sigma0-sigmaa)*(a./rel).^2;
            epsilonrel=(a^2*(sigmaa-sigma0))./(2.*rel.^2*muStar);
            epsilontel=(a^2*(sigma0-sigmaa))./(2.*rel.^2*muStar);
            sigmarwel=sigma0-a^2./rel.^2*muw/muStar*(sigma0-sigmaa);
            sigmatwel=sigma0+a^2./rel.^2*muw/muStar*(sigma0-sigmaa);
            sigmarhel=sigma0-a^2./rel.^2*muh/muStar*(sigma0-sigmaa);
            sigmathel=sigma0+a^2./rel.^2*muh/muStar*(sigma0-sigmaa);
            sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
            
            % Plot stress, strain and displacement field:
            figure
            set(figure,'units','normalized','outerposition',[0 0 1 1]);
            subplot(2,3,1)
            plot(rel,uel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('u [m]');
            
            subplot(2,3,2)
            plot(rel,epsilonrel);
            hold on
            plot(rel,epsilontel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\epsilon [-]');
            
            subplot(2,3,3)
            plot(rel,sigmarel);
            axis([a inf -inf inf])
            hold on
            plot(rel,sigmatel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigma [MPa]');
            
            subplot(2,3,4)
            plot(rel,sigmarhel);
            hold on
            plot(rel,sigmathel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmah [MPa]');
            
            subplot(2,3,5)
            plot(rel,sigmarwel);
            hold on
            plot(rel,sigmatwel);
            hold on
            plot(rel,sigmazel);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmaw [MPa]');
            
        elseif (sigmaa < sigmarRho1B) && (sigmaa >= sigmarRho1oB)
            %% GRC for the elasto-plastic behaviour of the hard layers (no out-of-plane failure)
            %%% Plastic zone (a < r < Rho1)
            % Required constants:
            A1 =A1iii;
            A2 =A2iii;
            A3 =A3iii;
            A4 =A4iii;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1iii;
            K2=K2iii;
            K3=K3iii;
            K4=K4iii;
            K5=K5iii;
            K6=K6iii;
            K7=K7iii;
            K8=K8iii;
            sigmarRho=sigmarRho1B;
            sigmatRho=sigmatRho1B;
            sigmarwRho=sigmarwRho1B;
            sigmatwRho=sigmatwRho1B;
            sigmarhRho=sigmarhRho1B;
            sigmathRho=sigmathRho1B;
            epsilonrRho=epsilonrRho1B;
            epsilontRho=epsilontRho1B;
            B1=B1iii;
            B2=B2iii;
            sigmazRho=sigmazRho1B;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
            
            % sigmar(r=a) with Eq. (5.59):
            sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
            
            % Solving Eq. (5.66), in order to obtain Rho1:
            eqn=sigmara==sigmaa;
            SolRho = vpasolve(eqn,Rho,a);
            [sz1,sz2]=size(SolRho);
            Rho=double(SolRho(sz1));
            Rho1=Rho
            
            % Calculating again C[1] and C[2] with Rho=Rho1:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
            
            % ua with C[1] and C[2] (Eq. 5.56):
            ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
            fprintf("Case B (II): hard layers reach failure (no out-of-plane failure)")
            
            % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
            rpl=a:0.01:Rho;
            upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
            epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
            epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                A3)/(2.*A1))*C2)./rpl;
            sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
            sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
            
            sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
            sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
            sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
            sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
            sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
            
            %%% Elastic zone (r > Rho1)
            
            % stress, strain and displacement field (Eqs. 5.24 to 5.33):
            rel=Rho:0.01:(Rho+40);
            uel=1/(2*muStar)*(sigma0-sigmarRho1B)*Rho^2./rel;
            sigmarel=sigma0-(sigma0-sigmarRho1B)*(Rho./rel).^2;
            sigmatel=sigma0+(sigma0-sigmarRho1B)*(Rho./rel).^2;
            epsilonrel=(Rho^2*(sigmarRho1B-sigma0))./(2.*rel.^2*muStar);
            epsilontel=(Rho^2*(sigma0-sigmarRho1B))./(2.*rel.^2*muStar);
            sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
            sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
            sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
            sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
            sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
            
            %%% Plot stress, strain and displacement field:
            figure
            set(figure,'units','normalized','outerposition',[0 0 1 1]);
            subplot(2,3,1)
            plot(rel,uel);
            hold on
            plot(rpl,upl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('u [m]');
            
            subplot(2,3,2)
            plot(rel,epsilonrel);
            hold on
            plot(rel,epsilontel);
            hold on
            plot(rpl,epsilonrpl);
            hold on
            plot(rpl,epsilontpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\epsilon [-]');
            
            subplot(2,3,3)
            plot(rel,sigmarel);
            axis([a inf -inf inf])
            hold on
            plot(rel,sigmatel);
            hold on
            plot(rpl,sigmarpl);
            hold on
            plot(rpl,sigmatpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigma [MPa]');
            
            subplot(2,3,4)
            plot(rel,sigmarhel);
            hold on
            plot(rel,sigmathel);
            hold on
            plot(rpl,sigmarhpl);
            hold on
            plot(rpl,sigmathpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmah [MPa]');
            
            subplot(2,3,5)
            plot(rel,sigmarwel);
            hold on
            plot(rel,sigmatwel);
            hold on
            plot(rpl,sigmarwpl);
            hold on
            plot(rpl,sigmatwpl);
            hold on
            plot(rel,sigmazel);
            hold on
            plot(rpl,sigmazpl);
            axis([a inf -inf inf])
            xlabel('r [m]');
            ylabel('\sigmaw [MPa]');
            
            Rho2=a
            
            %% GRC for the elasto-plastic behaviour of the weak or the hard layers (at least one layer: out of plane failure)
        elseif (sigmaa < sigmarRho1oB)
            
            %% Calculation of boundary conditions for r=Rho2
            % Required constants:
            A1 =A1iiio;
            A2 =A2iiio;
            A3 =A3iiio;
            A4 =A4iiio;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1iiio;
            K2=K2iiio;
            K3=K3iiio;
            K4=K4iiio;
            K5=K5iiio;
            K6=K6iiio;
            K7=K7iiio;
            K8=K8iiio;
            sigmarRho=sigmarRho1oB;
            sigmatRho=sigmatRho1oB;
            sigmarwRho=sigmarwRho1oB;
            sigmatwRho=sigmatwRho1oB;
            sigmarhRho=sigmarhRho1oB;
            sigmathRho=sigmathRho1oB;
            epsilonrRho=epsilonrRho1oB;
            epsilontRho=epsilontRho1oB;
            B1=B1iiio;
            B2=B2iiio;
            sigmazRho=sigmazRho1oB;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                A3)/(2*A1)));
            
            % epsilonr(r=a) and epsilont(r=a) with Eqs. (5.57) and (5.58) in function of Rho=Rho1o:
            epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + ...
                A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
            epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            
            % sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
            % in function of Rho = Rho1o:
            sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
            sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
            sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
            sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
            sigmaza=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
            
            % Solving Eq. (5.73), in order to obtain Rho1o:
            eqn=sigmatwa==mw*sigmarwa+sigmadw;
            SolRho = vpasolve(eqn,Rho,a);
            [sz1,sz2]=size(SolRho);
            Rho=double(SolRho(sz1));
            
            % Calculating all factors again with Rho=Rho1o:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                A3)/(2*A1)));
            epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                A3)/(2*A1))*C2)/(2*A1);
            epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            
            % Calculating the boundary conditions with Rho=Rho1o (Eqs. (5.57) to (5.71)):
            sigmarRho2B=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
            sigmatRho2B=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(-(A*A3*(C1 - a^(A/A1)*C2)) + ...
                (A2*A3 + A3^2 - 2*A1*A4)*(C1 + a^(A/A1)*C2)))/(2*A1);
            sigmarhRho2B=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
            sigmathRho2B=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
            sigmarwRho2B=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
            sigmatwRho2B=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
            epsilonrRho2B=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
                ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
            epsilontRho2B=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            sigmazRho2B=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
            
            %% Calculation of boundary conditions for r=Rho2o
            % Required constants:
            A1 =A1ivo2;
            A2 =A2ivo2;
            A3 =A3ivo2;
            A4 =A4ivo2;
            A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
            K1=K1ivo2;
            K2=K2ivo2;
            K3=K3ivo2;
            K4=K4ivo2;
            K5=K5ivo2;
            K6=K6ivo2;
            K7=K7ivo2;
            K8=K8ivo2;
            sigmarRho=sigmarRho2B;
            sigmatRho=sigmatRho2B;
            sigmarwRho=sigmarwRho2B;
            sigmatwRho=sigmatwRho2B;
            sigmarhRho=sigmarhRho2B;
            sigmathRho=sigmathRho2B;
            epsilonrRho=epsilonrRho2B;
            epsilontRho=epsilontRho2B;
            B1=B1ivo2;
            B2=B2ivo2;
            sigmazRho=sigmazRho2B;
            
            reset(symengine)
            clear Rho
            syms Rho
            % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
            C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
            C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                A3)/(2*A1)));
            
            % epsilonr(r=a) and epsilont(r=a) with Eqs. (5.57) and (5.58) in function of Rho=Rho2:
            epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + ...
                A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
            epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
            
            % sigmarw(r=a), sigmatw(r=a), sigmarh(r=a) and sigmath(r=a) with Eqs. (5.67) to (5.70)
            % in function of Rho = Rho2:
            sigmarha=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
            sigmatha=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
            sigmarwa=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
            sigmatwa=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
            sigmaza=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
            
            % Solving Eq. ((sigmatw(r=a)=sigmaz(r=a))), in order to obtain Rho=Rho2:
            eqn=sigmatwa==sigmaza;
            SolRho = vpasolve(eqn,Rho,a);
            sigmarRho2oB3=0;
            
            if isempty(SolRho)
                Rho3o=inf;
            else
                [sz1,sz2]=size(SolRho);
                Rho3o=double(SolRho(sz1));
                if isreal(Rho3o)
                    Rho3o=Rho3o;
                    Rho = Rho3o;
                    
                    % Calculating all factors again with Rho=Rho2:
                    C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                        2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                        epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                        4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                    C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                        A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                        sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                        A3)/(2*A1)));
                    epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                        A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                        A3)/(2*A1))*C2)/(2*A1);
                    epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                        sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                    
                    % Calculating sigmar,Rho2o with Rho=Rho2 (Eq. A-98):
                    sigmarRho2oB3=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                        A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                        (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                else
                    Rho3o=inf;
                end
            end
            
            % Solving Eq. ((sigmarw(r=a)=sigmaz(r=a))), in order to obtain Rho=Rho2:
            clear Rho
            syms Rho
            eqn=sigmarwa==sigmaza;
            SolRho = vpasolve(eqn,Rho,a);
            sigmarRho2oB4=0;
            if isempty(SolRho)
                Rho4o=inf;
            else
                [sz1,sz2]=size(SolRho);
                Rho4o=double(SolRho(sz1));
                
                if isreal(Rho4o)
                    Rho4o=Rho4o;
                    Rho = Rho4o;
                    % Calculating all factors again with Rho=Rho2:
                    C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                        2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                        epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                        4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                    C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                        A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                        sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                        A3)/(2*A1)));
                    epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                        A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                        A3)/(2*A1))*C2)/(2*A1);
                    epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                        sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                    
                    % Calculating sigmar,Rho2o with Rho=Rho2 (Eq. 5.59):
                    sigmarRho2oB4=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                        A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                        (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                else
                    Rho4o=inf;
                end
            end
            
            % Verification that sigmarRho2oB < sigmarRho2B:
            if sigmarRho2oB3 > sigmarRho2B
                sigmarRho2oB3=0;
                Rho3o=inf;
            else
                sigmarRho2oB3=sigmarRho2oB3;
            end
            
            % Verification that sigmarRho2oB < sigmarRho2B:
            if sigmarRho2oB4 > sigmarRho2B
                sigmarRho2oB4=0;
                Rho4o=inf;
            else
                sigmarRho2oB4=sigmarRho2oB4;
            end
            
            % Out-of-plane failure of the weak layers in triaxial
            % extension:
            if sigmarRho2oB3 > sigmarRho2oB4
                Rho=Rho3o; % i.e. both layers out-of-plane failure (sigmat=sigmaz)
                A1iv2o =A1ivo3;
                A2iv2o =A2ivo3;
                A3iv2o =A3ivo3;
                A4iv2o =A4ivo3;
                K1iv2o=K1ivo3;
                K2iv2o=K2ivo3;
                K3iv2o=K3ivo3;
                K4iv2o=K4ivo3;
                K5iv2o=K5ivo3;
                K6iv2o=K6ivo3;
                K7iv2o=K7ivo3;
                K8iv2o=K8ivo3;
                B1iv2o=B1ivo3;
                B2iv2o=B2ivo3;
                % Out-of-plane failure of the weak layers in triaxial
                % compression:
            else
                Rho=Rho4o; 
                A1iv2o =A1ivo4;
                A2iv2o =A2ivo4;
                A3iv2o =A3ivo4;
                A4iv2o =A4ivo4;
                K1iv2o=K1ivo4;
                K2iv2o=K2ivo4;
                K3iv2o=K3ivo4;
                K4iv2o=K4ivo4;
                K5iv2o=K5ivo4;
                K6iv2o=K6ivo4;
                K7iv2o=K7ivo4;
                K8iv2o=K8ivo4;
                B1iv2o=B1ivo4;
                B2iv2o=B2ivo4;
            end
            
            if isinf(Rho)
                sigmarRho2oB = 0;
            else
                
                % Calculating all factors again with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + epsilontRho) + ...
                    A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + ...
                    sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + ...
                    A3)/(2*A1)));
                epsilonra=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + sigmatRho)/(A1 - A2 - A3 + ...
                    A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ((A + A2 + A3)*a^(-1 + (A + A2 + ...
                    A3)/(2*A1))*C2)/(2*A1);
                epsilonta=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                
                % Calculating the boundary conditions with Rho=Rho2 (Eqs. (5.57) to (5.71)):
                sigmarRho2oB=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + a^(A/A1)*C2) - ...
                    (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                sigmatRho2oB=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(-(A*A3*(C1 - a^(A/A1)*C2)) + ...
                    (A2*A3 + A3^2 - 2*A1*A4)*(C1 + a^(A/A1)*C2)))/(2*A1);
                sigmarhRho2oB=sigmarhRho+K1*(epsilonra-epsilonrRho)+K2*(epsilonta-epsilontRho);
                sigmathRho2oB=sigmathRho+K3*(epsilonra-epsilonrRho)+K4*(epsilonta-epsilontRho);
                sigmarwRho2oB=sigmarwRho+K5*(epsilonra-epsilonrRho)+K6*(epsilonta-epsilontRho);
                sigmatwRho2oB=sigmatwRho+K7*(epsilonra-epsilonrRho)+K8*(epsilonta-epsilontRho);
                epsilonrRho2oB=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*a^(-1 + (-A + A2 + A3)/(2*A1))*C1)/(2*A1) + ...
                    ((A + A2 + A3)*a^(-1 + (A + A2 + A3)/(2*A1))*C2)/(2*A1);
                epsilontRho2oB=((a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2*A1))*C1 + a^((A + A2 + A3)/(2*A1))*C2)/a;
                sigmazRho2oB=sigmazRho+B1*(epsilonra-epsilonrRho)+B2*(epsilonta-epsilontRho);
                
                
            end
            
            if (sigmaa < sigmarRho1oB) && (sigmaa >= sigmarRho2B)
                %% GRC for the elasto-plastic behaviour of the hard layers (out-of-plane failure of the hard layers)
                
                %%% Plastic zone (a < r < Rho1o)
                % Required constants:
                A1 =A1iiio;
                A2 =A2iiio;
                A3 =A3iiio;
                A4 =A4iiio;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iiio;
                K2=K2iiio;
                K3=K3iiio;
                K4=K4iiio;
                K5=K5iiio;
                K6=K6iiio;
                K7=K7iiio;
                K8=K8iiio;
                sigmarRho=sigmarRho1oB;
                sigmatRho=sigmatRho1oB;
                sigmarwRho=sigmarwRho1oB;
                sigmatwRho=sigmatwRho1oB;
                sigmarhRho=sigmarhRho1oB;
                sigmathRho=sigmathRho1oB;
                epsilonrRho=epsilonrRho1oB;
                epsilontRho=epsilontRho1oB;
                B1=B1iiio;
                B2=B2iiio;
                sigmazRho=sigmazRho1oB;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.78), in order to obtain Rho=Rho2:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1o=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                fprintf("Case B (II): hard layers reach failure (out-of-plane failure)")
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.70) with Rho=Rho2:
                rpl2=a:0.01:Rho;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho1o < r < Rho1)
                
                % Required constants:
                A1 =A1iii;
                A2 =A2iii;
                A3 =A3iii;
                A4 =A4iii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iii;
                K2=K2iii;
                K3=K3iii;
                K4=K4iii;
                K5=K5iii;
                K6=K6iii;
                K7=K7iii;
                K8=K8iii;
                sigmarRho=sigmarRho1B;
                sigmatRho=sigmatRho1B;
                sigmarwRho=sigmarwRho1B;
                sigmatwRho=sigmatwRho1B;
                sigmarhRho=sigmarhRho1B;
                sigmathRho=sigmathRho1B;
                epsilonrRho=epsilonrRho1B;
                epsilontRho=epsilontRho1B;
                B1=B1iii;
                B2=B2iii;
                sigmazRho=sigmazRho1B;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho1o) with Eq. (5.59):
                sigmarRho1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho1o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho1o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho1o^(A/A1)*C2)))/2;
                
                % Solving Eq. (sigmar(r=Rho1o)=sigmarRho1o), in order to obtain Rho=Rho1:
                eqn=sigmarRho1o==sigmarRho1oB;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho1o:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1B)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1B)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1B)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1B-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1B))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
            elseif (sigmaa < sigmarRho2B) && (sigmaa >= sigmarRho2oB)
                %% GRC for the elasto-plastic behaviour of both, the weak and the hard layers (hard layers: out-of-plane failure, weak layers: in-plane failure)
                %%% Plastic zone (a < r < Rho2)
                % Required constants:
                A1 =A1ivo2;
                A2 =A2ivo2;
                A3 =A3ivo2;
                A4 =A4ivo2;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ivo2;
                K2=K2ivo2;
                K3=K3ivo2;
                K4=K4ivo2;
                K5=K5ivo2;
                K6=K6ivo2;
                K7=K7ivo2;
                K8=K8ivo2;
                sigmarRho=sigmarRho2B;
                sigmatRho=sigmatRho2B;
                sigmarwRho=sigmarwRho2B;
                sigmatwRho=sigmatwRho2B;
                sigmarhRho=sigmarhRho2B;
                sigmathRho=sigmathRho2B;
                epsilonrRho=epsilonrRho2B;
                epsilontRho=epsilontRho2B;
                B1=B1ivo2;
                B2=B2ivo2;
                sigmazRho=sigmazRho2B;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                fprintf("Case B (II): weak and hard layers reach failure (hard layers: out-of-plane failure)")
                
                % Solving Eq. (5.78), in order to obtain Rho=Rho2:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2:
                rpl1o=a:0.01:Rho2;
                upl1o=(rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl1o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl1o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl1o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl1o=((rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl1o;
                sigmarpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl1o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl1o.^(A/A1)*C2)))/2;
                sigmatpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl1o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl1o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl1o=sigmarhRho+K1*(epsilonrpl1o-epsilonrRho)+K2*(epsilontpl1o-epsilontRho);
                sigmathpl1o=sigmathRho+K3*(epsilonrpl1o-epsilonrRho)+K4*(epsilontpl1o-epsilontRho);
                sigmarwpl1o=sigmarwRho+K5*(epsilonrpl1o-epsilonrRho)+K6*(epsilontpl1o-epsilontRho);
                sigmatwpl1o=sigmatwRho+K7*(epsilonrpl1o-epsilonrRho)+K8*(epsilontpl1o-epsilontRho);
                sigmazpl1o=sigmazRho+B1.*(epsilonrpl1o-epsilonrRho)+B2.*(epsilontpl1o-epsilontRho);
                
                
                %%% Plastic zone (Rho2 < r < Rho1o)
                % Required constants:
                A1 =A1iiio;
                A2 =A2iiio;
                A3 =A3iiio;
                A4 =A4iiio;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iiio;
                K2=K2iiio;
                K3=K3iiio;
                K4=K4iiio;
                K5=K5iiio;
                K6=K6iiio;
                K7=K7iiio;
                K8=K8iiio;
                sigmarRho=sigmarRho1oB;
                sigmatRho=sigmatRho1oB;
                sigmarwRho=sigmarwRho1oB;
                sigmatwRho=sigmatwRho1oB;
                sigmarhRho=sigmarhRho1oB;
                sigmathRho=sigmathRho1oB;
                epsilonrRho=epsilonrRho1oB;
                epsilontRho=epsilontRho1oB;
                B1=B1iiio;
                B2=B2iiio;
                sigmazRho=sigmazRho1oB;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2) with Eq. (5.59):
                sigmarRho2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.74), in order to obtain Rho1o:
                eqn=sigmarRho2==sigmarRho2B;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1o=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1o:
                rpl2=Rho2:0.01:Rho1o;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho1o < r < Rho1)
                
                % Required constants:
                A1 =A1iii;
                A2 =A2iii;
                A3 =A3iii;
                A4 =A4iii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iii;
                K2=K2iii;
                K3=K3iii;
                K4=K4iii;
                K5=K5iii;
                K6=K6iii;
                K7=K7iii;
                K8=K8iii;
                sigmarRho=sigmarRho1B;
                sigmatRho=sigmatRho1B;
                sigmarwRho=sigmarwRho1B;
                sigmatwRho=sigmatwRho1B;
                sigmarhRho=sigmarhRho1B;
                sigmathRho=sigmathRho1B;
                epsilonrRho=epsilonrRho1B;
                epsilontRho=epsilontRho1B;
                B1=B1iii;
                B2=B2iii;
                sigmazRho=sigmazRho1B;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % Solving Equation (sigmar(r=Rho1o)=sigmarRho1o), in order to obtain Rho1:
                sigmarRho1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho1o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho1o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho1o^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.76), in order to obtain Rho1:
                eqn=sigmarRho1o==sigmarRho1oB;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho1o:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1B)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1B)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1B)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1B-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1B))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                hold on
                plot(rpl1o,upl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                hold on
                plot(rpl1o,epsilonrpl1o);
                hold on
                plot(rpl1o,epsilontpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarpl1o);
                hold on
                plot(rpl1o,sigmatpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarhpl1o);
                hold on
                plot(rpl1o,sigmathpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarwpl1o);
                hold on
                plot(rpl1o,sigmatwpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
            elseif (sigmaa < sigmarRho2oB)
                %% GRC for the elasto-plastic behaviour of both, the weak and the hard layers (both: out-of-plane failure)
                
                %%% Plastic zone (a < r < Rho2o)
                % Required constants:
                A1 =A1iv2o;
                A2 =A2iv2o;
                A3 =A3iv2o;
                A4 =A4iv2o;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iv2o;
                K2=K2iv2o;
                K3=K3iv2o;
                K4=K4iv2o;
                K5=K5iv2o;
                K6=K6iv2o;
                K7=K7iv2o;
                K8=K8iv2o;
                sigmarRho=sigmarRho2oB;
                sigmatRho=sigmatRho2oB;
                sigmarwRho=sigmarwRho2oB;
                sigmatwRho=sigmatwRho2oB;
                sigmarhRho=sigmarhRho2oB;
                sigmathRho=sigmathRho2oB;
                epsilonrRho=epsilonrRho2oB;
                epsilontRho=epsilontRho2oB;
                B1=B1iv2o;
                B2=B2iv2o;
                sigmazRho=sigmazRho2oB;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eq. (5.63) and (5.64) in function of Rho=Rho2o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=a) with Eq. (5.59):
                sigmara=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (a^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    a^(A/A1)*C2) - (A2 - A3)*(C1 + a^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.78), in order to obtain Rho=Rho2o:
                eqn=sigmara==sigmaa;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2o=Rho
                fprintf("Case B (II): weak and hard layers reach failure (both: out-of-plane failure)")
                
               % Calculating again C[1] and C[2] with Rho=Rho2o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % ua with C[1] and C[2] (Eq. 5.56):
                ua=(a*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + a^((-A + A2 + A3)/(2.*A1))*C1 + a^((A + A2 + A3)/(2.*A1))*C2
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2o:
                rpl2o=a:0.01:Rho2o;
                upl2o=(rpl2o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2o=((rpl2o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2o;
                sigmarpl2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2o.^(A/A1)*C2)))/2;
                sigmatpl2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2o=sigmarhRho+K1*(epsilonrpl2o-epsilonrRho)+K2*(epsilontpl2o-epsilontRho);
                sigmathpl2o=sigmathRho+K3*(epsilonrpl2o-epsilonrRho)+K4*(epsilontpl2o-epsilontRho);
                sigmarwpl2o=sigmarwRho+K5*(epsilonrpl2o-epsilonrRho)+K6*(epsilontpl2o-epsilontRho);
                sigmatwpl2o=sigmatwRho+K7*(epsilonrpl2o-epsilonrRho)+K8*(epsilontpl2o-epsilontRho);
                sigmazpl2o=sigmazRho+B1.*(epsilonrpl2o-epsilonrRho)+B2.*(epsilontpl2o-epsilontRho);
                
                
                %%% Plastic zone (Rho2o < r < Rho2)
                % Required constants:
                A1 =A1ivo2;
                A2 =A2ivo2;
                A3 =A3ivo2;
                A4 =A4ivo2;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1ivo2;
                K2=K2ivo2;
                K3=K3ivo2;
                K4=K4ivo2;
                K5=K5ivo2;
                K6=K6ivo2;
                K7=K7ivo2;
                K8=K8ivo2;
                sigmarRho=sigmarRho2B;
                sigmatRho=sigmatRho2B;
                sigmarwRho=sigmarwRho2B;
                sigmatwRho=sigmatwRho2B;
                sigmarhRho=sigmarhRho2B;
                sigmathRho=sigmathRho2B;
                epsilonrRho=epsilonrRho2B;
                epsilontRho=epsilontRho2B;
                B1=B1ivo2;
                B2=B2ivo2;
                sigmazRho=sigmazRho2B;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2o) with Eq. (5.59):
                sigmarRho2o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2o^(A/A1)*C2)))/2;
                
                % Solving Eq. (sigmar(r=Rho2o)=sigmarRho2o), in order to obtain Rho=Rho2:
                eqn=sigmarRho2o==sigmarRho2oB;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho2=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho2:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho2:
                rpl1o=Rho2o:0.01:Rho2;
                upl1o=(rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl1o=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl1o.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl1o.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl1o=((rpl1o.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl1o.^((-A + A2 + A3)/(2.*A1))*C1 + rpl1o.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl1o;
                sigmarpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl1o.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl1o.^(A/A1)*C2)))/2;
                sigmatpl1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl1o.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl1o.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl1o.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl1o=sigmarhRho+K1*(epsilonrpl1o-epsilonrRho)+K2*(epsilontpl1o-epsilontRho);
                sigmathpl1o=sigmathRho+K3*(epsilonrpl1o-epsilonrRho)+K4*(epsilontpl1o-epsilontRho);
                sigmarwpl1o=sigmarwRho+K5*(epsilonrpl1o-epsilonrRho)+K6*(epsilontpl1o-epsilontRho);
                sigmatwpl1o=sigmatwRho+K7*(epsilonrpl1o-epsilonrRho)+K8*(epsilontpl1o-epsilontRho);
                sigmazpl1o=sigmazRho+B1.*(epsilonrpl1o-epsilonrRho)+B2.*(epsilontpl1o-epsilontRho);
                
                
                %%% Plastic zone (Rho2 < r < Rho1o)
                % Required constants:
                A1 =A1iiio;
                A2 =A2iiio;
                A3 =A3iiio;
                A4 =A4iiio;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iiio;
                K2=K2iiio;
                K3=K3iiio;
                K4=K4iiio;
                K5=K5iiio;
                K6=K6iiio;
                K7=K7iiio;
                K8=K8iiio;
                sigmarRho=sigmarRho1oB;
                sigmatRho=sigmatRho1oB;
                sigmarwRho=sigmarwRho1oB;
                sigmatwRho=sigmatwRho1oB;
                sigmarhRho=sigmarhRho1oB;
                sigmathRho=sigmathRho1oB;
                epsilonrRho=epsilonrRho1oB;
                epsilontRho=epsilontRho1oB;
                B1=B1iiio;
                B2=B2iiio;
                sigmazRho=sigmazRho1oB;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho2) with Eq. (5.59):
                sigmarRho2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho2^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho2^(A/A1)*C2) - (A2 - A3)*(C1 + Rho2^(A/A1)*C2)))/2;
                
                % Solving Eq. (5.74), in order to obtain Rho=Rho1o:
                eqn=sigmarRho2==sigmarRho2B;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1o=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1o:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1o:
                rpl2=Rho2:0.01:Rho1o;
                upl2=(rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl2=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl2.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl2.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl2=((rpl2.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl2.^((-A + A2 + A3)/(2.*A1))*C1 + rpl2.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl2;
                sigmarpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl2.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl2.^(A/A1)*C2)))/2;
                sigmatpl2=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl2.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl2.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl2.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl2=sigmarhRho+K1*(epsilonrpl2-epsilonrRho)+K2*(epsilontpl2-epsilontRho);
                sigmathpl2=sigmathRho+K3*(epsilonrpl2-epsilonrRho)+K4*(epsilontpl2-epsilontRho);
                sigmarwpl2=sigmarwRho+K5*(epsilonrpl2-epsilonrRho)+K6*(epsilontpl2-epsilontRho);
                sigmatwpl2=sigmatwRho+K7*(epsilonrpl2-epsilonrRho)+K8*(epsilontpl2-epsilontRho);
                sigmazpl2=sigmazRho+B1.*(epsilonrpl2-epsilonrRho)+B2.*(epsilontpl2-epsilontRho);
                
                %%% Plastic zone (Rho1o < r < Rho1)
                
                % Required constants:
                A1 =A1iii;
                A2 =A2iii;
                A3 =A3iii;
                A4 =A4iii;
                A = sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4);
                K1=K1iii;
                K2=K2iii;
                K3=K3iii;
                K4=K4iii;
                K5=K5iii;
                K6=K6iii;
                K7=K7iii;
                K8=K8iii;
                sigmarRho=sigmarRho1B;
                sigmatRho=sigmatRho1B;
                sigmarwRho=sigmarwRho1B;
                sigmatwRho=sigmatwRho1B;
                sigmarhRho=sigmarhRho1B;
                sigmathRho=sigmathRho1B;
                epsilonrRho=epsilonrRho1B;
                epsilontRho=epsilontRho1B;
                B1=B1iii;
                B2=B2iii;
                sigmazRho=sigmazRho1B;
                
                reset(symengine)
                clear Rho
                syms Rho
                % Calculation of C[1] and C[2] with Eqs. (5.63) and (5.64) in function of Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - ...
                    4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + A*(-epsilonrRho + ...
                    epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + (A - A2 - ...
                    A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % sigmar(r=Rho1o) with Eq. (5.59):
                sigmarRho1o=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (Rho1o^((-A - 2*A1 + A2 + A3)/(2*A1))*(A*(-C1 + ...
                    Rho1o^(A/A1)*C2) - (A2 - A3)*(C1 + Rho1o^(A/A1)*C2)))/2;
                
                % Solving Eq. (sigmar(r=Rho1o)=sigmarRho1o), in order to obtain Rho1:
                eqn=sigmarRho1o==sigmarRho1oB;
                SolRho = vpasolve(eqn,Rho,a);
                [sz1,sz2]=size(SolRho);
                Rho=double(SolRho(sz1));
                Rho1=Rho
                
                % Calculating again C[1] and C[2] with Rho=Rho1:
                C1= -((A + A2 + A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho) + A1*(-(A3*epsilonrRho) - ...
                    2*A4*epsilonrRho + A2*(epsilonrRho - epsilontRho) + A3*epsilontRho + 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) - 2*sigmarRho + 2*sigmatRho))/(2*(-A1 + A2 + A3 - A4)*sqrt(A2^2 + ...
                    2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((-A - 2*A1 + A2 + A3)/(2*A1)));
                C2= -(A1*(A3*epsilonrRho + 2*A4*epsilonrRho - A3*epsilontRho - 2*A4*epsilontRho + ...
                    A*(-epsilonrRho + epsilontRho) + A2*(-epsilonrRho + epsilontRho) + 2*sigmarRho - 2*sigmatRho) + ...
                    (A - A2 - A3)*(A3*(epsilonrRho - epsilontRho) + sigmarRho - sigmatRho))/ (2*(-A1 + A2 + A3 - ...
                    A4)*sqrt(A2^2 + 2*A2*A3 + A3^2 - 4*A1*A4)*Rho^((A - 2*A1 + A2 + A3)/(2*A1)));
                
                % stress, strain and displacement field (Eqs. 5.56 to 5.71) with Rho=Rho1:
                rpl=Rho1o:0.01:Rho;
                upl=(rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + A3)/(2.*A1))*C2;
                epsilonrpl=(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho)/(A1 - A2 - A3 + A4) + ((-A + A2 + A3)*rpl.^(-1 + (-A + A2 + A3)/(2.*A1))*C1)/(2.*A1) + ...
                    ((A + A2 + A3)*rpl.^(-1 + (A + A2 + A3)/(2.*A1))*C2)/(2.*A1);
                epsilontpl=((rpl.*(A1*epsilonrRho - A3*epsilonrRho - A2*epsilontRho + A4*epsilontRho - sigmarRho + ...
                    sigmatRho))/(A1 - A2 - A3 + A4) + rpl.^((-A + A2 + A3)/(2.*A1))*C1 + rpl.^((A + A2 + ...
                    A3)/(2.*A1))*C2)./rpl;
                sigmarpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(A*(-C1 + ...
                    rpl.^(A/A1)*C2) - (A2 - A3)*(C1 + rpl.^(A/A1)*C2)))/2;
                sigmatpl=((-A3 + A4)*sigmarRho + A2*(A3*(epsilonrRho - epsilontRho) - sigmatRho) + A1*(-(A4*epsilonrRho) + ...
                    A4*epsilontRho + sigmatRho))/(A1 - A2 - A3 + A4) + (rpl.^((-A - 2*A1 + A2 + A3)/(2*A1)).*(-(A*A3*(C1 - ...
                    rpl.^(A/A1)*C2)) + (A2*A3 + A3^2 - 2*A1*A4)*(C1 + rpl.^(A/A1)*C2)))/(2*A1);
                
                sigmarhpl=sigmarhRho+K1*(epsilonrpl-epsilonrRho)+K2*(epsilontpl-epsilontRho);
                sigmathpl=sigmathRho+K3*(epsilonrpl-epsilonrRho)+K4*(epsilontpl-epsilontRho);
                sigmarwpl=sigmarwRho+K5*(epsilonrpl-epsilonrRho)+K6*(epsilontpl-epsilontRho);
                sigmatwpl=sigmatwRho+K7*(epsilonrpl-epsilonrRho)+K8*(epsilontpl-epsilontRho);
                sigmazpl=sigmazRho+B1.*(epsilonrpl-epsilonrRho)+B2.*(epsilontpl-epsilontRho);
                
                %%% Elastic zone (r > Rho1)
                
                % stress, strain and displacement field (Eqs. 5.24 to 5.33):
                rel=Rho:0.01:(Rho+40);
                uel=1/(2*muStar)*(sigma0-sigmarRho1B)*Rho^2./rel;
                sigmarel=sigma0-(sigma0-sigmarRho1B)*(Rho./rel).^2;
                sigmatel=sigma0+(sigma0-sigmarRho1B)*(Rho./rel).^2;
                epsilonrel=(Rho^2*(sigmarRho1B-sigma0))./(2.*rel.^2*muStar);
                epsilontel=(Rho^2*(sigma0-sigmarRho1B))./(2.*rel.^2*muStar);
                sigmarwel=sigma0-Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmatwel=sigma0+Rho^2./rel.^2*muw/muStar*(sigma0-sigmarRho1B);
                sigmarhel=sigma0-Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmathel=sigma0+Rho^2./rel.^2*muh/muStar*(sigma0-sigmarRho1B);
                sigmazel=sigma0+B1i.*epsilonrel+B2i.*epsilontel;
                
                %%% Plot stress, strain and displacement field:
                figure
                set(figure,'units','normalized','outerposition',[0 0 1 1]);
                subplot(2,3,1)
                plot(rel,uel);
                hold on
                plot(rpl,upl);
                hold on
                plot(rpl2,upl2);
                hold on
                plot(rpl1o,upl1o);
                hold on
                plot(rpl2o,upl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('u [m]');
                
                subplot(2,3,2)
                plot(rel,epsilonrel);
                hold on
                plot(rel,epsilontel);
                hold on
                plot(rpl,epsilonrpl);
                hold on
                plot(rpl,epsilontpl);
                hold on
                plot(rpl2,epsilonrpl2);
                hold on
                plot(rpl2,epsilontpl2);
                hold on
                plot(rpl1o,epsilonrpl1o);
                hold on
                plot(rpl1o,epsilontpl1o);
                hold on
                plot(rpl2o,epsilonrpl2o);
                hold on
                plot(rpl2o,epsilontpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\epsilon [-]');
                
                subplot(2,3,3)
                plot(rel,sigmarel);
                axis([a inf -inf inf])
                hold on
                plot(rel,sigmatel);
                hold on
                plot(rpl,sigmarpl);
                hold on
                plot(rpl,sigmatpl);
                hold on
                plot(rpl2,sigmarpl2);
                hold on
                plot(rpl2,sigmatpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarpl1o);
                hold on
                plot(rpl1o,sigmatpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarpl2o);
                hold on
                plot(rpl2o,sigmatpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigma [MPa]');
                
                subplot(2,3,4)
                plot(rel,sigmarhel);
                hold on
                plot(rel,sigmathel);
                hold on
                plot(rpl,sigmarhpl);
                hold on
                plot(rpl,sigmathpl);
                hold on
                plot(rpl2,sigmarhpl2);
                hold on
                plot(rpl2,sigmathpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarhpl1o);
                hold on
                plot(rpl1o,sigmathpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarhpl2o);
                hold on
                plot(rpl2o,sigmathpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmah [MPa]');
                
                subplot(2,3,5)
                plot(rel,sigmarwel);
                hold on
                plot(rel,sigmatwel);
                hold on
                plot(rpl,sigmarwpl);
                hold on
                plot(rpl,sigmatwpl);
                hold on
                plot(rpl2,sigmarwpl2);
                hold on
                plot(rpl2,sigmatwpl2);
                hold on
                plot(rel,sigmazel);
                hold on
                plot(rpl,sigmazpl);
                hold on
                plot(rpl2,sigmazpl2);
                hold on
                plot(rpl1o,sigmarwpl1o);
                hold on
                plot(rpl1o,sigmatwpl1o);
                hold on
                plot(rpl1o,sigmazpl1o);
                hold on
                plot(rpl2o,sigmarwpl2o);
                hold on
                plot(rpl2o,sigmatwpl2o);
                hold on
                plot(rpl2o,sigmazpl2o);
                axis([a inf -inf inf])
                xlabel('r [m]');
                ylabel('\sigmaw [MPa]');
                
                
            end
        end
    end
end

%% GRC for uw,2D

csigma0w=sigma0+sigmadw/(mw-1);

A1w=(1+nuw).*(1-2.*nuw);
A2w=(1+nuw).*(1-nuw+mw.*kw-nuw.*mw-nuw.*kw-nuw.*kw.*mw)./(mw+kw);
A4w=(kw+1)./(mw-1);
A5w=2.*(1-nuw.^2).*(mw-1)./(mw+kw).*(2./(mw+1)).^(A4w);

sigmarhow=(2.*sigma0-sigmadw)./(mw+1);

csigmaa=sigmaa+sigmadw/(mw-1);
uaplw=csigma0w./Ew.*a.*(-A1w+A2w*(csigmaa/csigma0w)+A5w*(csigmaa/csigma0w)^(-A4w));
uaelw=(1+nuw)./Ew.*(sigma0-sigmaa).*a;
if (sigmaa < sigmarhow)
    uaw=uaplw;
else
    uaw=uaelw;
end

uanormw=ua/uaw

%% GRC for uh,2D

csigma0h=sigma0+sigmadh/(mh-1);

A1h=(1+nuh).*(1-2.*nuh);
A2h=(1+nuh).*(1-nuh+mh.*kh-nuh.*mh-nuh.*kh-nuh.*kh.*mh)./(mh+kh);
A4h=(kh+1)./(mh-1);
A5h=2.*(1-nuh.^2).*(mh-1)./(mh+kh).*(2./(mh+1)).^(A4h);

sigmarhoh=(2.*sigma0-sigmadh)./(mh+1);

csigmaa=sigmaa+sigmadh/(mh-1);
uaplh=csigma0h./Eh.*a.*(-A1h+A2h*(csigmaa/csigma0h)+A5h*(csigmaa/csigma0h)^(-A4h));
uaelh=(1+nuh)./Eh.*(sigma0-sigmaa).*a;
if (sigmaa < sigmarhoh)
    uah=uaplh;
else
    uah=uaelh;
end

uanormh=ua/uah

